# This file was auto-generated by Fern from our API Definition.

ConnectionJwksUri = str
"""
URL of the identity provider's JSON Web Key Set (JWKS) endpoint containing public keys for signature verification. Auth0 retrieves these keys to validate ID token signatures.
"""
