# This file was auto-generated by Fern from our API Definition.

import typing

from .event_stream_cloud_event_group_member_deleted_object_group_0 import (
    EventStreamCloudEventGroupMemberDeletedObjectGroup0,
)
from .event_stream_cloud_event_group_member_deleted_object_group_1 import (
    EventStreamCloudEventGroupMemberDeletedObjectGroup1,
)
from .event_stream_cloud_event_group_member_deleted_object_group_2 import (
    EventStreamCloudEventGroupMemberDeletedObjectGroup2,
)

EventStreamCloudEventGroupMemberDeletedObjectGroup = typing.Union[
    EventStreamCloudEventGroupMemberDeletedObjectGroup0,
    EventStreamCloudEventGroupMemberDeletedObjectGroup1,
    EventStreamCloudEventGroupMemberDeletedObjectGroup2,
]
