# This file was auto-generated by Fern from our API Definition.

import typing

from .connection_upstream_additional_properties import ConnectionUpstreamAdditionalProperties

ConnectionUpstreamParamsFacebook = typing.Dict[str, ConnectionUpstreamAdditionalProperties]
"""
Options for adding parameters in the request to the upstream IdP. See https://auth0.com/docs/authenticate/identity-providers/pass-parameters-to-idps
"""
