# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .event_stream_cloud_event_context import EventStreamCloudEventContext
from .event_stream_cloud_event_group_created_object import EventStreamCloudEventGroupCreatedObject


class EventStreamCloudEventGroupCreatedData(UniversalBaseModel):
    """
    The event payload.
    """

    object: EventStreamCloudEventGroupCreatedObject
    context: typing.Optional[EventStreamCloudEventContext] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
