# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class CimdMappedPrivateKeyJwtCredential(UniversalBaseModel):
    credential_type: str = pydantic.Field()
    """
    Type of credential (e.g., public_key)
    """

    kid: str = pydantic.Field()
    """
    Key identifier from JWKS or calculated thumbprint
    """

    alg: str = pydantic.Field()
    """
    Algorithm (e.g., RS256, RS384, PS256)
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
