# This file was auto-generated by Fern from our API Definition.

import typing

FlowsVaultConnectionSetupTypeOauthClientCredentialsEnum = typing.Union[
    typing.Literal["OAUTH_CLIENT_CREDENTIALS"], typing.Any
]
