# This file was auto-generated by Fern from our API Definition.

import typing

from .event_stream_cloud_event_user_updated_object_identities_item_custom import (
    EventStreamCloudEventUserUpdatedObjectIdentitiesItemCustom,
)
from .event_stream_cloud_event_user_updated_object_identities_item_database import (
    EventStreamCloudEventUserUpdatedObjectIdentitiesItemDatabase,
)
from .event_stream_cloud_event_user_updated_object_identities_item_enterprise import (
    EventStreamCloudEventUserUpdatedObjectIdentitiesItemEnterprise,
)
from .event_stream_cloud_event_user_updated_object_identities_item_passwordless import (
    EventStreamCloudEventUserUpdatedObjectIdentitiesItemPasswordless,
)
from .event_stream_cloud_event_user_updated_object_identities_item_social import (
    EventStreamCloudEventUserUpdatedObjectIdentitiesItemSocial,
)

EventStreamCloudEventUserUpdatedObjectIdentitiesItem = typing.Union[
    EventStreamCloudEventUserUpdatedObjectIdentitiesItemCustom,
    EventStreamCloudEventUserUpdatedObjectIdentitiesItemDatabase,
    EventStreamCloudEventUserUpdatedObjectIdentitiesItemEnterprise,
    EventStreamCloudEventUserUpdatedObjectIdentitiesItemPasswordless,
    EventStreamCloudEventUserUpdatedObjectIdentitiesItemSocial,
]
