# This file was auto-generated by Fern from our API Definition.

ConnectionClientIdGoogleOAuth2 = str
"""
Your Google OAuth 2.0 client ID. You can find this in your [Google Cloud Console](https://console.cloud.google.com/apis/credentials) under the OAuth 2.0 Client IDs section.
"""
