# This file was auto-generated by Fern from our API Definition.

ConnectionAdminAccessTokenGoogleApps = str
"""
Google Workspace admin access token used to retrieve extended user attributes (such as group memberships, admin status, and suspension state) from the [Google Directory API](https://developers.google.com/admin-sdk/directory). This token is automatically managed by Auth0.
"""
