# This file was auto-generated by Fern from our API Definition.

ConnectionUserIdAttributeSaml = str
"""
Custom SAML assertion attribute to use as the unique user identifier. When provided, this attribute is prepended to the default user_id mapping list with highest priority. Accepts a string (single SAML attribute name).
"""
