# This file was auto-generated by Fern from our API Definition.

ConnectionDisableSelfServiceChangePassword = bool
"""
Indicates whether to disable self-service change password. Set to true to stop the "Forgot Password" being displayed on login pages
"""
