# This file was auto-generated by Fern from our API Definition.

import typing

ClientAddonDropbox = typing.Dict[str, typing.Any]
"""
Dropbox SSO indicator (no configuration settings needed for Dropbox SSO).
"""
