# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class ConnectionCustomScripts(UniversalBaseModel):
    """
    A map of scripts used to integrate with a custom database.
    """

    login: typing.Optional[str] = None
    get_user: typing.Optional[str] = None
    delete: typing.Optional[str] = None
    change_password: typing.Optional[str] = None
    verify: typing.Optional[str] = None
    create: typing.Optional[str] = None
    change_username: typing.Optional[str] = None
    change_email: typing.Optional[str] = None
    change_phone_number: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
