# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .event_stream_cloud_event_group_deleted_object_0_type_enum import EventStreamCloudEventGroupDeletedObject0TypeEnum


class EventStreamCloudEventGroupDeletedObject0(UniversalBaseModel):
    """
    Connection group with updated_at timestamp
    """

    id: str = pydantic.Field()
    """
    The unique identifier for the group.
    """

    name: str = pydantic.Field()
    """
    The name of the group.
    """

    external_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    The external identifier for the group.
    """

    created_at: dt.datetime = pydantic.Field()
    """
    Date and time when this entity was created (ISO_8601 format).
    """

    type: EventStreamCloudEventGroupDeletedObject0TypeEnum
    connection_id: str = pydantic.Field()
    """
    The connection ID associated with the group.
    """

    updated_at: dt.datetime = pydantic.Field()
    """
    Date and time when this entity was last updated/modified (ISO_8601 format).
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
