# This file was auto-generated by Fern from our API Definition.

import typing

FormFieldFileConfigCategoryEnum = typing.Union[
    typing.Literal["AUDIO", "VIDEO", "IMAGE", "DOCUMENT", "ARCHIVE"], typing.Any
]
