# This file was auto-generated by Fern from our API Definition.

import typing

PartialGroupsEnum = typing.Union[
    typing.Literal[
        "login",
        "login-id",
        "login-password",
        "login-passwordless",
        "signup",
        "signup-id",
        "signup-password",
        "customized-consent",
        "passkeys",
        "confirmation",
    ],
    typing.Any,
]
