# This file was auto-generated by Fern from our API Definition.

import typing

EventStreamCloudEventConnectionUpdatedObject2OptionsSignatureAlgorithmEnum = typing.Union[
    typing.Literal["rsa-sha1", "rsa-sha256"], typing.Any
]
