# This file was auto-generated by Fern from our API Definition.

import typing

ActionExecutionStatusEnum = typing.Union[
    typing.Literal["unspecified", "pending", "final", "partial", "canceled", "suspended"], typing.Any
]
