# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .action_binding_ref import ActionBindingRef
from .action_secret_request import ActionSecretRequest


class ActionBindingWithRef(UniversalBaseModel):
    ref: ActionBindingRef
    display_name: typing.Optional[str] = pydantic.Field(default=None)
    """
    The name of the binding.
    """

    secrets: typing.Optional[typing.List[ActionSecretRequest]] = pydantic.Field(default=None)
    """
    The list of secrets that are included in an action or a version of an action.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
