# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.create_event_stream_action_request_content import CreateEventStreamActionRequestContent
from ...types.create_event_stream_event_bridge_request_content import CreateEventStreamEventBridgeRequestContent
from ...types.create_event_stream_web_hook_request_content import CreateEventStreamWebHookRequestContent

EventStreamsCreateRequest = typing.Union[
    CreateEventStreamWebHookRequestContent,
    CreateEventStreamEventBridgeRequestContent,
    CreateEventStreamActionRequestContent,
]
