# This file was auto-generated by Fern from our API Definition.

import typing

ConnectionsDiscoveryUrl = typing.Optional[str]
"""
URL of the identity provider's OIDC Discovery endpoint (/.well-known/openid-configuration). When provided and oidc_metadata is empty, Auth0 automatically retrieves the provider's configuration including endpoints and supported features. Only applicable when strategy=oidc, okta, or samlp.
"""
