# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .connection_profile_strategy_overrides_connection_config import ConnectionProfileStrategyOverridesConnectionConfig
from .connection_profile_strategy_overrides_enabled_features import ConnectionProfileStrategyOverridesEnabledFeatures


class ConnectionProfileStrategyOverride(UniversalBaseModel):
    """
    Connection Profile Strategy Override
    """

    enabled_features: typing.Optional[ConnectionProfileStrategyOverridesEnabledFeatures] = None
    connection_config: typing.Optional[ConnectionProfileStrategyOverridesConnectionConfig] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
