# This file was auto-generated by Fern from our API Definition.

ConnectionOptionsClientSecretTwitter = str
"""
OAuth 2.0 client secret issued by the identity provider during application registration. This value is used to authenticate your Auth0 connection to the identity provider.
"""
