# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .phone_template_content import PhoneTemplateContent
from .phone_template_notification_type_enum import PhoneTemplateNotificationTypeEnum


class UpdatePhoneTemplateResponseContent(UniversalBaseModel):
    id: typing.Optional[str] = None
    channel: typing.Optional[str] = None
    customizable: typing.Optional[bool] = None
    tenant: typing.Optional[str] = None
    content: PhoneTemplateContent
    type: PhoneTemplateNotificationTypeEnum
    disabled: bool = pydantic.Field()
    """
    Whether the template is enabled (false) or disabled (true).
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
