# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .email_attribute_identifier import EmailAttributeIdentifier
from .signup_verified import SignupVerified
from .verification_method_enum import VerificationMethodEnum


class EmailAttribute(UniversalBaseModel):
    """
    Configuration for the email attribute for users.
    """

    identifier: typing.Optional[EmailAttributeIdentifier] = None
    unique: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Determines if the attribute is unique in a given connection
    """

    profile_required: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Determines if property should be required for users
    """

    verification_method: typing.Optional[VerificationMethodEnum] = None
    signup: typing.Optional[SignupVerified] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
