# This file was auto-generated by Fern from our API Definition.

ConnectionTenantDomainSaml = str
"""
For SAML connections, the tenant domain used to construct the login endpoint URL. Can be a string for single-tenant or an array of strings for multi-tenant validation.
"""
