# This file was auto-generated by Fern from our API Definition.

ConnectionAppDomainAzureAd = str
"""
The Azure AD application domain (e.g., 'contoso.onmicrosoft.com'). Used primarily with WS-Federation protocol and Azure AD v1 endpoints.
"""
