# This file was auto-generated by Fern from our API Definition.

import typing

ClientAddonConcur = typing.Dict[str, typing.Any]
"""
Concur SSO indicator (no configuration settings needed for Concur SSO).
"""
