# This file was auto-generated by Fern from our API Definition.

import typing

from .create_flows_vault_connection_whatsapp_token import CreateFlowsVaultConnectionWhatsappToken
from .create_flows_vault_connection_whatsapp_uninitialized import CreateFlowsVaultConnectionWhatsappUninitialized

CreateFlowsVaultConnectionWhatsapp = typing.Union[
    CreateFlowsVaultConnectionWhatsappToken, CreateFlowsVaultConnectionWhatsappUninitialized
]
