# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .branding_theme_borders import BrandingThemeBorders
from .branding_theme_colors import BrandingThemeColors
from .branding_theme_fonts import BrandingThemeFonts
from .branding_theme_identifiers import BrandingThemeIdentifiers
from .branding_theme_page_background import BrandingThemePageBackground
from .branding_theme_widget import BrandingThemeWidget


class GetBrandingDefaultThemeResponseContent(UniversalBaseModel):
    borders: BrandingThemeBorders
    colors: BrandingThemeColors
    display_name: typing_extensions.Annotated[
        str, FieldMetadata(alias="displayName"), pydantic.Field(alias="displayName", description="Display Name")
    ]
    """
    Display Name
    """

    fonts: BrandingThemeFonts
    identifiers: typing.Optional[BrandingThemeIdentifiers] = None
    page_background: BrandingThemePageBackground
    theme_id: typing_extensions.Annotated[
        str, FieldMetadata(alias="themeId"), pydantic.Field(alias="themeId", description="Theme Id")
    ]
    """
    Theme Id
    """

    widget: BrandingThemeWidget

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
