# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .event_stream_cloud_event_org_member_role_assigned_object_organization import (
    EventStreamCloudEventOrgMemberRoleAssignedObjectOrganization,
)
from .event_stream_cloud_event_org_member_role_assigned_object_role import (
    EventStreamCloudEventOrgMemberRoleAssignedObjectRole,
)
from .event_stream_cloud_event_org_member_role_assigned_object_user import (
    EventStreamCloudEventOrgMemberRoleAssignedObjectUser,
)


class EventStreamCloudEventOrgMemberRoleAssignedObject(UniversalBaseModel):
    """
    The event content.
    """

    organization: EventStreamCloudEventOrgMemberRoleAssignedObjectOrganization
    user: EventStreamCloudEventOrgMemberRoleAssignedObjectUser
    role: EventStreamCloudEventOrgMemberRoleAssignedObjectRole

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
