# This file was auto-generated by Fern from our API Definition.

import typing

BreachedPasswordDetectionAdminNotificationFrequencyEnum = typing.Union[
    typing.Literal["immediately", "daily", "weekly", "monthly"], typing.Any
]
