# This file was auto-generated by Fern from our API Definition.

import typing

ConnectionIpsAd = typing.List[str]
"""
Array of IP address ranges in CIDR notation used to determine if authentication requests originate from the corporate network for Kerberos or certificate authentication.
"""
