# This file was auto-generated by Fern from our API Definition.

ConnectionGatewayAuthenticationAudienceSms = str
"""
`aud` claim value in the JWT sent to the SMS gateway. Identifies the gateway service (e.g., 'urn:MySmsGateway').
"""
