# This file was auto-generated by Fern from our API Definition.

import typing

ConnectionProfileOrganizationAssignMembershipOnLoginEnum = typing.Union[
    typing.Literal["none", "optional", "required"], typing.Any
]
