# This file was auto-generated by Fern from our API Definition.

import typing

from .client_signing_key import ClientSigningKey

ClientSigningKeys = typing.Optional[typing.List[ClientSigningKey]]
"""
Signing certificates associated with this client.
"""
