# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .action_module_list_item import ActionModuleListItem


class GetActionModulesResponseContent(UniversalBaseModel):
    modules: typing.Optional[typing.List[ActionModuleListItem]] = pydantic.Field(default=None)
    """
    A list of ActionsModule objects.
    """

    total: typing.Optional[int] = pydantic.Field(default=None)
    """
    The total number of modules in the tenant.
    """

    page: typing.Optional[int] = pydantic.Field(default=None)
    """
    The page index of the returned results.
    """

    per_page: typing.Optional[int] = pydantic.Field(default=None)
    """
    The number of results requested per page.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
