# This file was auto-generated by Fern from our API Definition.

import typing

from .csp_report_to_endpoint import CspReportToEndpoint

CspReportToEndpoints = typing.List[CspReportToEndpoint]
"""
Array of reporting endpoints.
"""
