# This file was auto-generated by Fern from our API Definition.

import typing

from .flows_vault_connectio_setup_api_key import FlowsVaultConnectioSetupApiKey
from .flows_vault_connectio_setup_api_key_with_base_url import FlowsVaultConnectioSetupApiKeyWithBaseUrl
from .flows_vault_connectio_setup_bigquery_oauth_jwt import FlowsVaultConnectioSetupBigqueryOauthJwt
from .flows_vault_connectio_setup_http_bearer import FlowsVaultConnectioSetupHttpBearer
from .flows_vault_connectio_setup_jwt import FlowsVaultConnectioSetupJwt
from .flows_vault_connectio_setup_mailjet_api_key import FlowsVaultConnectioSetupMailjetApiKey
from .flows_vault_connectio_setup_oauth_app import FlowsVaultConnectioSetupOauthApp
from .flows_vault_connectio_setup_oauth_code import FlowsVaultConnectioSetupOauthCode
from .flows_vault_connectio_setup_secret_api_key import FlowsVaultConnectioSetupSecretApiKey
from .flows_vault_connectio_setup_stripe_key_pair import FlowsVaultConnectioSetupStripeKeyPair
from .flows_vault_connectio_setup_token import FlowsVaultConnectioSetupToken
from .flows_vault_connectio_setup_twilio_api_key import FlowsVaultConnectioSetupTwilioApiKey
from .flows_vault_connectio_setup_webhook import FlowsVaultConnectioSetupWebhook
from .flows_vault_connection_http_api_key_setup import FlowsVaultConnectionHttpApiKeySetup
from .flows_vault_connection_http_basic_auth_setup import FlowsVaultConnectionHttpBasicAuthSetup
from .flows_vault_connection_http_oauth_client_credentials_setup import (
    FlowsVaultConnectionHttpOauthClientCredentialsSetup,
)

UpdateFlowsVaultConnectionSetup = typing.Union[
    FlowsVaultConnectioSetupApiKeyWithBaseUrl,
    FlowsVaultConnectioSetupApiKey,
    FlowsVaultConnectioSetupOauthApp,
    FlowsVaultConnectioSetupBigqueryOauthJwt,
    FlowsVaultConnectioSetupSecretApiKey,
    FlowsVaultConnectioSetupHttpBearer,
    FlowsVaultConnectionHttpBasicAuthSetup,
    FlowsVaultConnectionHttpApiKeySetup,
    FlowsVaultConnectionHttpOauthClientCredentialsSetup,
    FlowsVaultConnectioSetupJwt,
    FlowsVaultConnectioSetupMailjetApiKey,
    FlowsVaultConnectioSetupToken,
    FlowsVaultConnectioSetupWebhook,
    FlowsVaultConnectioSetupStripeKeyPair,
    FlowsVaultConnectioSetupOauthCode,
    FlowsVaultConnectioSetupTwilioApiKey,
]
