# This file was auto-generated by Fern from our API Definition.

ConnectionClientIdLine = str
"""
LINE Channel ID issued by LINE during application registration. This value identifies your Auth0 connection to LINE.
"""
