# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class EmailProviderCredentials(UniversalBaseModel):
    """
    Credentials required to use the provider.
    """

    api_user: typing.Optional[str] = pydantic.Field(default=None)
    """
    API User.
    """

    region: typing.Optional[str] = pydantic.Field(default=None)
    """
    AWS or SparkPost region.
    """

    smtp_host: typing.Optional[str] = pydantic.Field(default=None)
    """
    SMTP host.
    """

    smtp_port: typing.Optional[int] = pydantic.Field(default=None)
    """
    SMTP port.
    """

    smtp_user: typing.Optional[str] = pydantic.Field(default=None)
    """
    SMTP username.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
