# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class CreateImportUsersResponseContent(UniversalBaseModel):
    status: str = pydantic.Field()
    """
    Status of this job.
    """

    type: str = pydantic.Field()
    """
    Type of job this is.
    """

    created_at: str = pydantic.Field()
    """
    When this job was created.
    """

    id: str = pydantic.Field()
    """
    ID of this job.
    """

    connection_id: str = pydantic.Field()
    """
    connection_id of the connection to which users will be imported.
    """

    external_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Customer-defined ID.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
