# This file was auto-generated by Fern from our API Definition.

import typing

OauthScope = typing.Union[
    typing.Literal[
        "create:actions",
        "read:actions",
        "update:actions",
        "delete:actions",
        "read:anomaly_blocks",
        "delete:anomaly_blocks",
        "read:attack_protection",
        "update:attack_protection",
        "create:authentication_methods",
        "read:authentication_methods",
        "update:authentication_methods",
        "delete:authentication_methods",
        "read:branding",
        "update:branding",
        "delete:branding",
        "create:client_credentials",
        "read:client_credentials",
        "update:client_credentials",
        "delete:client_credentials",
        "create:client_grants",
        "read:client_grants",
        "update:client_grants",
        "delete:client_grants",
        "read:client_keys",
        "update:client_keys",
        "read:client_summary",
        "update:client_token_vault_privileged_access",
        "create:clients",
        "read:clients",
        "update:clients",
        "delete:clients",
        "create:connection_profiles",
        "read:connection_profiles",
        "update:connection_profiles",
        "delete:connection_profiles",
        "create:connections",
        "read:connections",
        "update:connections",
        "delete:connections",
        "create:connections_keys",
        "read:connections_keys",
        "update:connections_keys",
        "read:current_user",
        "delete:current_user",
        "create:current_user_device_credentials",
        "delete:current_user_device_credentials",
        "update:current_user_identities",
        "update:current_user_metadata",
        "create:custom_domains",
        "read:custom_domains",
        "update:custom_domains",
        "delete:custom_domains",
        "create:custom_signing_keys",
        "read:custom_signing_keys",
        "update:custom_signing_keys",
        "delete:custom_signing_keys",
        "read:device_credentials",
        "delete:device_credentials",
        "create:directory_provisionings",
        "read:directory_provisionings",
        "update:directory_provisionings",
        "delete:directory_provisionings",
        "create:email_provider",
        "read:email_provider",
        "update:email_provider",
        "delete:email_provider",
        "create:email_templates",
        "read:email_templates",
        "update:email_templates",
        "create:encryption_keys",
        "read:encryption_keys",
        "update:encryption_keys",
        "delete:encryption_keys",
        "read:event_deliveries",
        "update:event_deliveries",
        "create:event_streams",
        "read:event_streams",
        "update:event_streams",
        "delete:event_streams",
        "read:events",
        "create:flows",
        "read:flows",
        "update:flows",
        "delete:flows",
        "read:flows_executions",
        "delete:flows_executions",
        "create:flows_vault_connections",
        "read:flows_vault_connections",
        "update:flows_vault_connections",
        "delete:flows_vault_connections",
        "create:forms",
        "read:forms",
        "update:forms",
        "delete:forms",
        "read:grants",
        "delete:grants",
        "read:group_members",
        "create:group_roles",
        "read:group_roles",
        "delete:group_roles",
        "read:groups",
        "delete:groups",
        "create:guardian_enrollment_tickets",
        "read:guardian_enrollments",
        "delete:guardian_enrollments",
        "read:guardian_factors",
        "update:guardian_factors",
        "create:hooks",
        "read:hooks",
        "update:hooks",
        "delete:hooks",
        "create:log_streams",
        "read:log_streams",
        "update:log_streams",
        "delete:log_streams",
        "read:logs",
        "read:logs_users",
        "read:mfa_policies",
        "update:mfa_policies",
        "create:network_acls",
        "read:network_acls",
        "update:network_acls",
        "delete:network_acls",
        "create:organization_client_grants",
        "read:organization_client_grants",
        "delete:organization_client_grants",
        "create:organization_connections",
        "read:organization_connections",
        "update:organization_connections",
        "delete:organization_connections",
        "create:organization_discovery_domains",
        "read:organization_discovery_domains",
        "update:organization_discovery_domains",
        "delete:organization_discovery_domains",
        "create:organization_group_roles",
        "read:organization_group_roles",
        "delete:organization_group_roles",
        "read:organization_groups",
        "create:organization_invitations",
        "read:organization_invitations",
        "delete:organization_invitations",
        "read:organization_member_effective_roles",
        "read:organization_member_role_source_groups",
        "create:organization_member_roles",
        "read:organization_member_roles",
        "delete:organization_member_roles",
        "create:organization_members",
        "read:organization_members",
        "delete:organization_members",
        "create:organizations",
        "read:organizations",
        "update:organizations",
        "delete:organizations",
        "read:organizations_summary",
        "create:phone_providers",
        "read:phone_providers",
        "update:phone_providers",
        "delete:phone_providers",
        "create:phone_templates",
        "read:phone_templates",
        "update:phone_templates",
        "delete:phone_templates",
        "read:prompts",
        "update:prompts",
        "create:rate_limit_policies",
        "read:rate_limit_policies",
        "update:rate_limit_policies",
        "delete:rate_limit_policies",
        "read:refresh_tokens",
        "update:refresh_tokens",
        "delete:refresh_tokens",
        "create:resource_servers",
        "read:resource_servers",
        "update:resource_servers",
        "delete:resource_servers",
        "create:role_members",
        "read:role_members",
        "delete:role_members",
        "create:roles",
        "read:roles",
        "update:roles",
        "delete:roles",
        "create:rules",
        "read:rules",
        "update:rules",
        "delete:rules",
        "read:rules_configs",
        "update:rules_configs",
        "delete:rules_configs",
        "create:scim_config",
        "read:scim_config",
        "update:scim_config",
        "delete:scim_config",
        "create:scim_token",
        "read:scim_token",
        "delete:scim_token",
        "read:self_service_profile_custom_texts",
        "update:self_service_profile_custom_texts",
        "create:self_service_profiles",
        "read:self_service_profiles",
        "update:self_service_profiles",
        "delete:self_service_profiles",
        "read:sessions",
        "update:sessions",
        "delete:sessions",
        "create:signing_keys",
        "read:signing_keys",
        "update:signing_keys",
        "create:sso_access_tickets",
        "delete:sso_access_tickets",
        "read:stats",
        "read:tenant_settings",
        "update:tenant_settings",
        "create:token_exchange_profiles",
        "read:token_exchange_profiles",
        "update:token_exchange_profiles",
        "delete:token_exchange_profiles",
        "create:user_attribute_profiles",
        "read:user_attribute_profiles",
        "update:user_attribute_profiles",
        "delete:user_attribute_profiles",
        "read:user_effective_permissions",
        "read:user_effective_roles",
        "read:user_idp_tokens",
        "read:user_permission_source_roles",
        "read:user_role_source_groups",
        "create:user_tickets",
        "create:users",
        "read:users",
        "update:users",
        "delete:users",
        "update:users_app_metadata",
        "create:vdcs_templates",
        "read:vdcs_templates",
        "update:vdcs_templates",
        "delete:vdcs_templates",
    ],
    typing.Any,
]
