# This file was auto-generated by Fern from our API Definition.

import typing

from .connection_upstream_alias import ConnectionUpstreamAlias
from .connection_upstream_value import ConnectionUpstreamValue

ConnectionUpstreamAdditionalProperties = typing.Union[ConnectionUpstreamAlias, ConnectionUpstreamValue]
