# This file was auto-generated by Fern from our API Definition.

import typing

from .create_log_stream_datadog_request_body import CreateLogStreamDatadogRequestBody
from .create_log_stream_event_bridge_request_body import CreateLogStreamEventBridgeRequestBody
from .create_log_stream_event_grid_request_body import CreateLogStreamEventGridRequestBody
from .create_log_stream_http_request_body import CreateLogStreamHttpRequestBody
from .create_log_stream_mixpanel_request_body import CreateLogStreamMixpanelRequestBody
from .create_log_stream_segment_request_body import CreateLogStreamSegmentRequestBody
from .create_log_stream_splunk_request_body import CreateLogStreamSplunkRequestBody
from .create_log_stream_sumo_request_body import CreateLogStreamSumoRequestBody

CreateLogStreamRequestContent = typing.Union[
    CreateLogStreamHttpRequestBody,
    CreateLogStreamEventBridgeRequestBody,
    CreateLogStreamEventGridRequestBody,
    CreateLogStreamDatadogRequestBody,
    CreateLogStreamSplunkRequestBody,
    CreateLogStreamSumoRequestBody,
    CreateLogStreamSegmentRequestBody,
    CreateLogStreamMixpanelRequestBody,
]
