# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from .connection_options_office_365 import ConnectionOptionsOffice365
from .connection_provisioning_ticket_url import ConnectionProvisioningTicketUrl
from .connection_purposes import ConnectionPurposes
from .connection_response_common import ConnectionResponseCommon
from .connection_response_content_office_365_strategy import ConnectionResponseContentOffice365Strategy
from .connection_show_as_button import ConnectionShowAsButton


class ConnectionResponseContentOffice365(ConnectionPurposes, ConnectionResponseCommon):
    """
    Response for connections with strategy=office365
    """

    strategy: ConnectionResponseContentOffice365Strategy
    options: typing.Optional[ConnectionOptionsOffice365] = None
    provisioning_ticket_url: typing.Optional[ConnectionProvisioningTicketUrl] = None
    show_as_button: typing.Optional[ConnectionShowAsButton] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
