# This file was auto-generated by Fern from our API Definition.

import typing

EventStreamCloudEventOrgMemberDeletedTypeEnum = typing.Union[typing.Literal["organization.member.deleted"], typing.Any]
