# This file was auto-generated by Fern from our API Definition.

import typing

GetHookSecretResponseContent = typing.Dict[str, str]
"""
Hashmap of key-value pairs where the value must be a string.
"""
