# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .client_session_transfer_delegation_device_binding_enum import ClientSessionTransferDelegationDeviceBindingEnum


class ClientSessionTransferDelegationConfiguration(UniversalBaseModel):
    """
    Configuration for delegation (impersonation) access using Session Transfer Tokens
    """

    allow_delegated_access: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Indicates whether delegation (impersonation) access is allowed using Session Transfer Tokens. Default value is `false`.
    """

    enforce_device_binding: typing.Optional[ClientSessionTransferDelegationDeviceBindingEnum] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
