# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class UpdateEnabledClientConnectionsRequestContentItem(UniversalBaseModel):
    client_id: str = pydantic.Field()
    """
    The client_id of the client whose status will be changed. Note that the limit per PATCH request is 50 clients.
    """

    status: bool = pydantic.Field()
    """
    Whether the connection is enabled or not for this client_id
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
