# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .flow_action_auth_0_send_request_params_headers import FlowActionAuth0SendRequestParamsHeaders
from .flow_action_auth_0_send_request_params_method import FlowActionAuth0SendRequestParamsMethod
from .flow_action_auth_0_send_request_params_payload import FlowActionAuth0SendRequestParamsPayload
from .flow_action_auth_0_send_request_params_query_params import FlowActionAuth0SendRequestParamsQueryParams


class FlowActionAuth0SendRequestParams(UniversalBaseModel):
    connection_id: str
    pathname: str
    method: typing.Optional[FlowActionAuth0SendRequestParamsMethod] = None
    headers: typing.Optional[FlowActionAuth0SendRequestParamsHeaders] = None
    params: typing.Optional[FlowActionAuth0SendRequestParamsQueryParams] = None
    payload: typing.Optional[FlowActionAuth0SendRequestParamsPayload] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
