# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .form_flow_config import FormFlowConfig
from .form_node_coordinates import FormNodeCoordinates
from .form_node_type_flow_const import FormNodeTypeFlowConst


class FormFlow(UniversalBaseModel):
    id: str
    type: FormNodeTypeFlowConst
    coordinates: typing.Optional[FormNodeCoordinates] = None
    alias: typing.Optional[str] = None
    config: FormFlowConfig

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
