# This file was auto-generated by Fern from our API Definition.

import typing

ActionVersionBuildStatusEnum = typing.Union[
    typing.Literal["pending", "building", "packaged", "built", "retrying", "failed"], typing.Any
]
