# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .cimd_mapped_client_authentication_methods import CimdMappedClientAuthenticationMethods


class CimdMappedClientFields(UniversalBaseModel):
    """
    Auth0 client fields mapped from the Client ID Metadata Document
    """

    external_client_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    The URL of the Client ID Metadata Document
    """

    name: typing.Optional[str] = pydantic.Field(default=None)
    """
    Client name
    """

    app_type: typing.Optional[str] = pydantic.Field(default=None)
    """
    Application type (e.g., web, native)
    """

    callbacks: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Callback URLs
    """

    logo_uri: typing.Optional[str] = pydantic.Field(default=None)
    """
    Logo URI
    """

    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    Human-readable brief description of this client presentable to the end-user
    """

    grant_types: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    List of grant types
    """

    token_endpoint_auth_method: typing.Optional[str] = pydantic.Field(default=None)
    """
    Token endpoint authentication method
    """

    jwks_uri: typing.Optional[str] = pydantic.Field(default=None)
    """
    URL for the JSON Web Key Set containing the public keys for private_key_jwt authentication
    """

    client_authentication_methods: typing.Optional[CimdMappedClientAuthenticationMethods] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
