# This file was auto-generated by Fern from our API Definition.

import typing

ClientAddonCloudBees = typing.Dict[str, typing.Any]
"""
CloudBees SSO indicator (no configuration settings needed for CloudBees SSO).
"""
