# This file was auto-generated by Fern from our API Definition.

ConnectionServiceDocumentation = str
"""
URL of a page containing human-readable information that developers might want or need to know when using the OpenID Provider. In particular, if the OpenID Provider does not support Dynamic Client Registration, then information on how to register Clients needs to be provided in this documentation.
"""
