# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class ActionModuleReference(UniversalBaseModel):
    """
    Reference to a module and its version used by an action.
    """

    module_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    The unique ID of the module.
    """

    module_name: typing.Optional[str] = pydantic.Field(default=None)
    """
    The name of the module.
    """

    module_version_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    The ID of the specific module version.
    """

    module_version_number: typing.Optional[int] = pydantic.Field(default=None)
    """
    The version number of the module.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
