# This file was auto-generated by Fern from our API Definition.

import typing

from .async_approval_notifications_channels_enum import AsyncApprovalNotificationsChannelsEnum

ClientAsyncApprovalNotificationsChannelsApiPatchConfiguration = typing.Optional[
    typing.List[AsyncApprovalNotificationsChannelsEnum]
]
"""
Array of notification channels for contacting the user when their approval is required. Valid values are `guardian-push`, `email`.
"""
