# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .branding_theme_widget_header_text_alignment_enum import BrandingThemeWidgetHeaderTextAlignmentEnum
from .branding_theme_widget_logo_position_enum import BrandingThemeWidgetLogoPositionEnum
from .branding_theme_widget_social_buttons_layout_enum import BrandingThemeWidgetSocialButtonsLayoutEnum


class BrandingThemeWidget(UniversalBaseModel):
    header_text_alignment: BrandingThemeWidgetHeaderTextAlignmentEnum
    logo_height: float = pydantic.Field()
    """
    Logo height
    """

    logo_position: BrandingThemeWidgetLogoPositionEnum
    logo_url: str = pydantic.Field()
    """
    Logo url
    """

    social_buttons_layout: BrandingThemeWidgetSocialButtonsLayoutEnum

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
