# This file was auto-generated by Fern from our API Definition.

import typing

from .flow_action_auth_0_send_request_params_payload_object import FlowActionAuth0SendRequestParamsPayloadObject

FlowActionAuth0SendRequestParamsPayload = typing.Union[
    str, typing.List[typing.Any], FlowActionAuth0SendRequestParamsPayloadObject
]
