# This file was auto-generated by Fern from our API Definition.

ConnectionGatewayAuthenticationSubjectSms = str
"""
`sub` claim value in the JWT sent to the SMS gateway. Identifies the requester (e.g., 'urn:Auth0').
"""
