# This file was auto-generated by Fern from our API Definition.

import typing

from .create_flows_vault_connection_jwt_jwt import CreateFlowsVaultConnectionJwtJwt
from .create_flows_vault_connection_jwt_uninitialized import CreateFlowsVaultConnectionJwtUninitialized

CreateFlowsVaultConnectionJwt = typing.Union[
    CreateFlowsVaultConnectionJwtJwt, CreateFlowsVaultConnectionJwtUninitialized
]
