# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .xss_protection_mode import XssProtectionMode


class XssProtectionConfig(UniversalBaseModel):
    """
    X-XSS-Protection header configuration (deprecated header, use CSP instead).
    """

    enabled: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether X-XSS-Protection header is enabled.
    """

    mode: typing.Optional[XssProtectionMode] = None
    report_uri: typing.Optional[str] = pydantic.Field(default=None)
    """
    HTTPS endpoint for X-XSS-Protection violation reports.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
