# This file was auto-generated by Fern from our API Definition.

ConnectionExtProfile = bool
"""
When enabled (true), retrieves extended profile attributes from Azure AD via Microsoft Graph API (job title, department, office location, etc.). Requires Graph API permissions. Only available with Azure AD v1 or when explicitly enabled for v2.
"""
