# This file was auto-generated by Fern from our API Definition.

import typing

from .custom_provider_configuration import CustomProviderConfiguration
from .twilio_provider_configuration import TwilioProviderConfiguration

PhoneProviderConfiguration = typing.Union[TwilioProviderConfiguration, CustomProviderConfiguration]
