# This file was auto-generated by Fern from our API Definition.

import typing

EventStreamCloudEventConnectionDeletedObject7OptionsWaadProtocolEnum = typing.Union[
    typing.Literal["ws-federation", "openid-connect"], typing.Any
]
