# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .form_field_payment_config_charge import FormFieldPaymentConfigCharge
from .form_field_payment_config_credentials import FormFieldPaymentConfigCredentials
from .form_field_payment_config_customer import FormFieldPaymentConfigCustomer
from .form_field_payment_config_fields import FormFieldPaymentConfigFields
from .form_field_payment_config_provider_enum import FormFieldPaymentConfigProviderEnum


class FormFieldPaymentConfig(UniversalBaseModel):
    provider: typing.Optional[FormFieldPaymentConfigProviderEnum] = None
    charge: FormFieldPaymentConfigCharge
    credentials: FormFieldPaymentConfigCredentials
    customer: typing.Optional[FormFieldPaymentConfigCustomer] = None
    fields: typing.Optional[FormFieldPaymentConfigFields] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
