# This file was auto-generated by Fern from our API Definition.

import typing

from .create_flows_vault_connection_docusign_oauth_code import CreateFlowsVaultConnectionDocusignOauthCode
from .create_flows_vault_connection_docusign_uninitialized import CreateFlowsVaultConnectionDocusignUninitialized

CreateFlowsVaultConnectionDocusign = typing.Union[
    CreateFlowsVaultConnectionDocusignOauthCode, CreateFlowsVaultConnectionDocusignUninitialized
]
