# This file was auto-generated by Fern from our API Definition.

import typing

from .post_connections_keys_response_content_item import PostConnectionsKeysResponseContentItem

PostConnectionsKeysResponseContent = typing.List[PostConnectionsKeysResponseContentItem]
