# This file was auto-generated by Fern from our API Definition.

import typing

from .flow_action_auth_0_send_request_params_query_params_value import FlowActionAuth0SendRequestParamsQueryParamsValue

FlowActionAuth0SendRequestParamsQueryParams = typing.Dict[
    str, typing.Optional[FlowActionAuth0SendRequestParamsQueryParamsValue]
]
