# This file was auto-generated by Fern from our API Definition.

import typing

ConnectionRequestObjectEncryptionEncValuesSupported = typing.List[str]
"""
JSON array containing a list of the JWE encryption algorithms (enc values) supported by the OP for Request Objects. These algorithms are used both when the Request Object is passed by value and when it is passed by reference.
"""
