# This file was auto-generated by Fern from our API Definition.

ConnectionClientIdBitbucket = str
"""
OAuth 2.0 client identifier issued by the identity provider during application registration. This value identifies your Auth0 connection to the identity provider.
"""
