# This file was auto-generated by Fern from our API Definition.

import typing

EventStreamCloudEventOrgMemberRoleDeletedTypeEnum = typing.Union[
    typing.Literal["organization.member.role.deleted"], typing.Any
]
