# This file was auto-generated by Fern from our API Definition.

import typing

from .event_stream_cloud_event_group_role_deleted_object_group_0 import (
    EventStreamCloudEventGroupRoleDeletedObjectGroup0,
)
from .event_stream_cloud_event_group_role_deleted_object_group_1 import (
    EventStreamCloudEventGroupRoleDeletedObjectGroup1,
)
from .event_stream_cloud_event_group_role_deleted_object_group_2 import (
    EventStreamCloudEventGroupRoleDeletedObjectGroup2,
)

EventStreamCloudEventGroupRoleDeletedObjectGroup = typing.Union[
    EventStreamCloudEventGroupRoleDeletedObjectGroup0,
    EventStreamCloudEventGroupRoleDeletedObjectGroup1,
    EventStreamCloudEventGroupRoleDeletedObjectGroup2,
]
