# This file was auto-generated by Fern from our API Definition.

import typing

from .connection_scope_item import ConnectionScopeItem

ConnectionScopeArray = typing.List[ConnectionScopeItem]
"""
Array of custom OAuth 2.0 scopes to request during authentication.
"""
