# This file was auto-generated by Fern from our API Definition.

import typing

from .user_attribute_profile_user_id import UserAttributeProfileUserId

UserAttributeProfilePatchUserId = typing.Optional[UserAttributeProfileUserId]
