# This file was auto-generated by Fern from our API Definition.

import typing

UserMetadata = typing.Dict[str, typing.Any]
"""
Data related to the user that does not affect the application's core functionality.
"""
