# This file was auto-generated by Fern from our API Definition.

import typing

CustomDomainCustomClientIpHeaderEnum = typing.Union[
    typing.Literal["true-client-ip", "cf-connecting-ip", "x-forwarded-for", "x-azure-clientip", ""], typing.Any
]
