# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .create_client_authentication_method_self_signed_tls_client_auth_credentials import (
    CreateClientAuthenticationMethodSelfSignedTlsClientAuthCredentials,
)


class CreateClientAuthenticationMethodSelfSignedTlsClientAuth(UniversalBaseModel):
    """
    Defines `self_signed_tls_client_auth` client authentication method. If the property is defined, the client is configured to use mTLS authentication method utilizing self-signed certificate.
    """

    credentials: CreateClientAuthenticationMethodSelfSignedTlsClientAuthCredentials

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
