# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .client_token_exchange_type_enum import ClientTokenExchangeTypeEnum


class ClientTokenExchangeConfiguration(UniversalBaseModel):
    """
    Configuration for token exchange.
    """

    allow_any_profile_of_type: typing.Optional[typing.List[ClientTokenExchangeTypeEnum]] = pydantic.Field(default=None)
    """
    List the enabled token exchange types for this client.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
