# This file was auto-generated by Fern from our API Definition.

from .connection_digest_algorithm_enum_saml import ConnectionDigestAlgorithmEnumSaml

ConnectionDigestAlgorithmSaml = ConnectionDigestAlgorithmEnumSaml
"""
Algorithm used for computing digest values when signing SAML requests and logout requests. Defaults to 'sha256'.
"""
