# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .form_field_custom_config_params import FormFieldCustomConfigParams
from .form_field_custom_config_schema import FormFieldCustomConfigSchema


class FormFieldCustomConfig(UniversalBaseModel):
    schema_: typing_extensions.Annotated[
        FormFieldCustomConfigSchema, FieldMetadata(alias="schema"), pydantic.Field(alias="schema")
    ]
    code: str
    css: typing.Optional[str] = None
    params: typing.Optional[FormFieldCustomConfigParams] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
