# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .form_ending_node_after_submit import FormEndingNodeAfterSubmit
from .form_ending_node_redirection import FormEndingNodeRedirection
from .form_ending_node_resume_flow_true_const import FormEndingNodeResumeFlowTrueConst
from .form_node_coordinates import FormNodeCoordinates


class FormEndingNode(UniversalBaseModel):
    redirection: typing.Optional[FormEndingNodeRedirection] = None
    after_submit: typing.Optional[FormEndingNodeAfterSubmit] = None
    coordinates: typing.Optional[FormNodeCoordinates] = None
    resume_flow: typing.Optional[FormEndingNodeResumeFlowTrueConst] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
