# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .client_default_organization_flows_enum import ClientDefaultOrganizationFlowsEnum


class ClientDefaultOrganization(UniversalBaseModel):
    """
    Defines the default Organization ID and flows
    """

    organization_id: str = pydantic.Field()
    """
    The default Organization ID to be used
    """

    flows: typing.List[ClientDefaultOrganizationFlowsEnum] = pydantic.Field()
    """
    The default Organization usage
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
