# This file was auto-generated by Fern from our API Definition.

import typing

from .update_default_canonical_domain_response_content import UpdateDefaultCanonicalDomainResponseContent
from .update_default_custom_domain_response_content import UpdateDefaultCustomDomainResponseContent

UpdateDefaultDomainResponseContent = typing.Union[
    UpdateDefaultCustomDomainResponseContent, UpdateDefaultCanonicalDomainResponseContent
]
