# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class UserBlockIdentifier(UniversalBaseModel):
    identifier: typing.Optional[str] = pydantic.Field(default=None)
    """
    Identifier (should be any of an `email`, `username`, or `phone_number`)
    """

    ip: typing.Optional[str] = pydantic.Field(default=None)
    """
    IP Address
    """

    connection: typing.Optional[str] = pydantic.Field(default=None)
    """
    Connection identifier
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
