# This file was auto-generated by Fern from our API Definition.

import typing

EventStreamCloudEventConnectionDeletedObject1OptionsTypeEnum = typing.Union[typing.Literal["back_channel"], typing.Any]
