# This file was auto-generated by Fern from our API Definition.

import typing

SelfServiceProfileSsoTicketProvisioningScopeEnum = typing.Union[
    typing.Literal[
        "get:users",
        "post:users",
        "put:users",
        "patch:users",
        "delete:users",
        "get:groups",
        "post:groups",
        "put:groups",
        "patch:groups",
        "delete:groups",
    ],
    typing.Any,
]
