# This file was auto-generated by Fern from our API Definition.

import typing

from .acul_configs_item import AculConfigsItem

AculConfigs = typing.List[AculConfigsItem]
"""
Array of screen configurations to update
"""
