# This file was auto-generated by Fern from our API Definition.

import typing

EventStreamCloudEventConnectionDeletedObject1OptionsAttributeMapAttributes = typing.Dict[str, typing.Any]
"""
Object containing mapping details for incoming claims
"""
