# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class LogSecurityContext(UniversalBaseModel):
    """
    Information about security-related signals.
    """

    ja_3: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="ja3"),
        pydantic.Field(alias="ja3", description="JA3 fingerprint value."),
    ] = None
    """
    JA3 fingerprint value.
    """

    ja_4: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="ja4"),
        pydantic.Field(alias="ja4", description="JA4 fingerprint value."),
    ] = None
    """
    JA4 fingerprint value.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
