# This file was auto-generated by Fern from our API Definition.

import typing

from .connection_sha_1_thumbprint import ConnectionSha1Thumbprint

ConnectionThumbprintsSaml = typing.List[ConnectionSha1Thumbprint]
"""
SHA-1 thumbprints (fingerprints) of the identity provider's signing certificates. Automatically computed from signingCert during connection creation. Each thumbprint must be a 40-character hexadecimal string.
"""
