# This file was auto-generated by Fern from our API Definition.

import typing

SelfServiceProfileAllowedStrategyEnum = typing.Union[
    typing.Literal[
        "oidc",
        "samlp",
        "waad",
        "google-apps",
        "adfs",
        "okta",
        "auth0-samlp",
        "okta-samlp",
        "keycloak-samlp",
        "pingfederate",
    ],
    typing.Any,
]
