# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .event_stream_cloud_event_org_created_object_branding import EventStreamCloudEventOrgCreatedObjectBranding
from .event_stream_cloud_event_org_created_object_metadata import EventStreamCloudEventOrgCreatedObjectMetadata


class EventStreamCloudEventOrgCreatedObject(UniversalBaseModel):
    """
    The event content.
    """

    name: typing.Optional[str] = pydantic.Field(default=None)
    """
    The human-readable identifier for the organization that will be used by end-users to direct them to their organization in your application..
    """

    id: str = pydantic.Field()
    """
    ID of the organization.
    """

    display_name: typing.Optional[str] = pydantic.Field(default=None)
    """
    If set, the name that will be displayed to end-users for this organization in any interaction with them.
    """

    metadata: typing.Optional[EventStreamCloudEventOrgCreatedObjectMetadata] = None
    branding: typing.Optional[EventStreamCloudEventOrgCreatedObjectBranding] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
