# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .log_stream_mixpanel_region_enum import LogStreamMixpanelRegionEnum


class LogStreamMixpanelSink(UniversalBaseModel):
    mixpanel_region: typing_extensions.Annotated[
        LogStreamMixpanelRegionEnum, FieldMetadata(alias="mixpanelRegion"), pydantic.Field(alias="mixpanelRegion")
    ]
    mixpanel_project_id: typing_extensions.Annotated[
        str,
        FieldMetadata(alias="mixpanelProjectId"),
        pydantic.Field(alias="mixpanelProjectId", description="Mixpanel Project Id"),
    ]
    """
    Mixpanel Project Id
    """

    mixpanel_service_account_username: typing_extensions.Annotated[
        str,
        FieldMetadata(alias="mixpanelServiceAccountUsername"),
        pydantic.Field(alias="mixpanelServiceAccountUsername", description="Mixpanel Service Account Username"),
    ]
    """
    Mixpanel Service Account Username
    """

    mixpanel_service_account_password: typing_extensions.Annotated[
        str,
        FieldMetadata(alias="mixpanelServiceAccountPassword"),
        pydantic.Field(alias="mixpanelServiceAccountPassword", description="Mixpanel Service Account Password"),
    ]
    """
    Mixpanel Service Account Password
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
