# This file was auto-generated by Fern from our API Definition.

from .connection_scope_array import ConnectionScopeArray

ConnectionScopeGoogleOAuth2 = ConnectionScopeArray
"""
Array of OAuth 2.0 scopes requested during Google authentication.
"""
