# This file was auto-generated by Fern from our API Definition.

import typing

from .get_universal_login_template import GetUniversalLoginTemplate

GetUniversalLoginTemplateResponseContent = typing.Union[GetUniversalLoginTemplate, str]
