# This file was auto-generated by Fern from our API Definition.

ConnectionEntityIdSaml = str
"""
The entity identifier (Issuer) for the SAML Service Provider. When not provided, defaults to 'urn:auth0:{tenant}:{connection}'. This value is included in SAML AuthnRequest messages sent to the identity provider.
"""
