# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .list_aculs_response_content_item import ListAculsResponseContentItem


class ListAculsOffsetPaginatedResponseContent(UniversalBaseModel):
    configs: typing.Optional[typing.List[ListAculsResponseContentItem]] = None
    start: typing.Optional[float] = pydantic.Field(default=None)
    """
    the index of the first configuration in the response (before filtering)
    """

    limit: typing.Optional[float] = pydantic.Field(default=None)
    """
    the maximum number of configurations shown per page (before filtering)
    """

    total: typing.Optional[float] = pydantic.Field(default=None)
    """
    the total number of configurations on this tenant
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
