# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class ConnectionPasswordOptionsHistory(UniversalBaseModel):
    """
    Password history policy configuration to prevent password reuse
    """

    active: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Enables password history checking to prevent users from reusing recent passwords
    """

    size: typing.Optional[int] = pydantic.Field(default=None)
    """
    Number of previous passwords to remember and prevent reuse (1-24)
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
