# This file was auto-generated by Fern from our API Definition.

import typing

from .event_stream_action_destination import EventStreamActionDestination
from .event_stream_webhook_destination import EventStreamWebhookDestination

EventStreamDestinationPatch = typing.Union[EventStreamWebhookDestination, EventStreamActionDestination]
