# This file was auto-generated by Fern from our API Definition.

from .connection_scope_array import ConnectionScopeArray

ConnectionOptionsScopeGithub = ConnectionScopeArray
"""
Scope options for GitHub connections.
"""
