# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class IntegrationSemVer(UniversalBaseModel):
    """
    Semver denotes the major.minor version of an integration release
    """

    major: typing.Optional[int] = pydantic.Field(default=None)
    """
    Major is the major number of a semver
    """

    minor: typing.Optional[int] = pydantic.Field(default=None)
    """
    Minior is the minior number of a semver
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
