# This file was auto-generated by Fern from our API Definition.

import typing

ConnectionDisplayValuesSupported = typing.List[str]
"""
JSON array containing a list of the JWS signing algorithms (alg values) supported by the Token Endpoint for the signature on the JWT [JWT] used to authenticate the Client at the Token Endpoint for the private_key_jwt and client_secret_jwt authentication methods. Servers SHOULD support RS256. The value none MUST NOT be used.
"""
