# This file was auto-generated by Fern from our API Definition.

import typing

CreateConnectionRequestContentSalesforceSandboxStrategy = typing.Union[typing.Literal["salesforce-sandbox"], typing.Any]
