# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .native_social_login_apple_patch import NativeSocialLoginApplePatch
from .native_social_login_facebook_patch import NativeSocialLoginFacebookPatch
from .native_social_login_google_patch import NativeSocialLoginGooglePatch


class NativeSocialLoginPatch(UniversalBaseModel):
    """
    Configure native social settings
    """

    apple: typing.Optional[NativeSocialLoginApplePatch] = None
    facebook: typing.Optional[NativeSocialLoginFacebookPatch] = None
    google: typing.Optional[NativeSocialLoginGooglePatch] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
