# This file was auto-generated by Fern from our API Definition.

import typing

UserAttributeProfileUserIdOidcStrategyOverrideMapping = typing.Union[typing.Literal["sub", "oid", "email"], typing.Any]
