# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .self_service_profile_sso_ticket_idp_initiated_options import SelfServiceProfileSsoTicketIdpInitiatedOptions


class SelfServiceProfileSsoTicketConnectionOptions(UniversalBaseModel):
    """
    The connection's options (depend on the connection strategy)
    """

    icon_url: typing.Optional[str] = pydantic.Field(default=None)
    """
    URL for the icon. Must use HTTPS.
    """

    domain_aliases: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    List of domain_aliases that can be authenticated in the Identity Provider
    """

    idpinitiated: typing.Optional[SelfServiceProfileSsoTicketIdpInitiatedOptions] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
