# This file was auto-generated by Fern from our API Definition.

import typing

from .flow_action_xml_parse_xml import FlowActionXmlParseXml
from .flow_action_xml_serialize_xml import FlowActionXmlSerializeXml

FlowActionXml = typing.Union[FlowActionXmlParseXml, FlowActionXmlSerializeXml]
