# This file was auto-generated by Fern from our API Definition.

import typing

ConnectionAcrValuesSupported = typing.List[str]
"""
A list of the Authentication Context Class References that this OP supports
"""
