# This file was auto-generated by Fern from our API Definition.

from .connection_ext_groups import ConnectionExtGroups

ConnectionExtGroupsGoogleApps = ConnectionExtGroups
"""
Enables enrichment with Google group memberships (required for `ext_groups_extended`).
"""
