# This file was auto-generated by Fern from our API Definition.

import typing

ResourceServerProofOfPossessionRequiredForEnum = typing.Union[
    typing.Literal["public_clients", "all_clients"], typing.Any
]
