# This file was auto-generated by Fern from our API Definition.

import typing

from .csp_policy import CspPolicy

CspPolicies = typing.List[CspPolicy]
"""
Array of CSP policies (enforcing and/or reporting).
"""
