# This file was auto-generated by Fern from our API Definition.

import typing

from .create_flows_vault_connection_stripe_key_pair import CreateFlowsVaultConnectionStripeKeyPair
from .create_flows_vault_connection_stripe_oauth_code import CreateFlowsVaultConnectionStripeOauthCode
from .create_flows_vault_connection_stripe_uninitialized import CreateFlowsVaultConnectionStripeUninitialized

CreateFlowsVaultConnectionStripe = typing.Union[
    CreateFlowsVaultConnectionStripeKeyPair,
    CreateFlowsVaultConnectionStripeOauthCode,
    CreateFlowsVaultConnectionStripeUninitialized,
]
