# This file was auto-generated by Fern from our API Definition.

import typing

from .event_stream_cloud_event_connection_deleted_object_0 import EventStreamCloudEventConnectionDeletedObject0
from .event_stream_cloud_event_connection_deleted_object_1 import EventStreamCloudEventConnectionDeletedObject1
from .event_stream_cloud_event_connection_deleted_object_2 import EventStreamCloudEventConnectionDeletedObject2
from .event_stream_cloud_event_connection_deleted_object_3 import EventStreamCloudEventConnectionDeletedObject3
from .event_stream_cloud_event_connection_deleted_object_4 import EventStreamCloudEventConnectionDeletedObject4
from .event_stream_cloud_event_connection_deleted_object_5 import EventStreamCloudEventConnectionDeletedObject5
from .event_stream_cloud_event_connection_deleted_object_6 import EventStreamCloudEventConnectionDeletedObject6
from .event_stream_cloud_event_connection_deleted_object_7 import EventStreamCloudEventConnectionDeletedObject7

EventStreamCloudEventConnectionDeletedObject = typing.Union[
    EventStreamCloudEventConnectionDeletedObject0,
    EventStreamCloudEventConnectionDeletedObject1,
    EventStreamCloudEventConnectionDeletedObject2,
    EventStreamCloudEventConnectionDeletedObject3,
    EventStreamCloudEventConnectionDeletedObject4,
    EventStreamCloudEventConnectionDeletedObject5,
    EventStreamCloudEventConnectionDeletedObject6,
    EventStreamCloudEventConnectionDeletedObject7,
]
