# This file was auto-generated by Fern from our API Definition.

import typing

from .bot_detection_ip_address_or_cidr_block import BotDetectionIpAddressOrCidrBlock

BotDetectionAllowlist = typing.List[BotDetectionIpAddressOrCidrBlock]
"""
List of IP addresses or CIDR blocks to allowlist
"""
