# This file was auto-generated by Fern from our API Definition.

import typing

EventStreamCloudEventConnectionCreatedObject3OptionsIdpinitiatedClientProtocolEnum = typing.Union[
    typing.Literal["oidc", "samlp", "wsfed"], typing.Any
]
