# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .breached_password_detection_pre_change_password_stage import BreachedPasswordDetectionPreChangePasswordStage
from .breached_password_detection_pre_user_registration_stage import BreachedPasswordDetectionPreUserRegistrationStage


class BreachedPasswordDetectionStage(UniversalBaseModel):
    pre_user_registration: typing_extensions.Annotated[
        typing.Optional[BreachedPasswordDetectionPreUserRegistrationStage],
        FieldMetadata(alias="pre-user-registration"),
        pydantic.Field(alias="pre-user-registration"),
    ] = None
    pre_change_password: typing_extensions.Annotated[
        typing.Optional[BreachedPasswordDetectionPreChangePasswordStage],
        FieldMetadata(alias="pre-change-password"),
        pydantic.Field(alias="pre-change-password"),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
