# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .mdl_presentation_request import MdlPresentationRequest


class CreateVerifiableCredentialTemplateResponseContent(UniversalBaseModel):
    id: typing.Optional[str] = pydantic.Field(default=None)
    """
    The id of the template.
    """

    name: typing.Optional[str] = pydantic.Field(default=None)
    """
    The name of the template.
    """

    type: typing.Optional[str] = pydantic.Field(default=None)
    """
    The type of the template.
    """

    dialect: typing.Optional[str] = pydantic.Field(default=None)
    """
    The dialect of the template.
    """

    presentation: typing.Optional[MdlPresentationRequest] = None
    custom_certificate_authority: typing.Optional[str] = pydantic.Field(default=None)
    """
    The custom certificate authority.
    """

    well_known_trusted_issuers: typing.Optional[str] = pydantic.Field(default=None)
    """
    The well-known trusted issuers, comma separated.
    """

    created_at: typing.Optional[dt.datetime] = pydantic.Field(default=None)
    """
    The date and time the template was created.
    """

    updated_at: typing.Optional[dt.datetime] = pydantic.Field(default=None)
    """
    The date and time the template was created.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
