# This file was auto-generated by Fern from our API Definition.

import typing

from .rate_limit_policy_configuration_action import RateLimitPolicyConfigurationAction
from .rate_limit_policy_configuration_one import RateLimitPolicyConfigurationOne
from .rate_limit_policy_configuration_zero import RateLimitPolicyConfigurationZero

RateLimitPolicyConfiguration = typing.Union[
    RateLimitPolicyConfigurationZero, RateLimitPolicyConfigurationOne, RateLimitPolicyConfigurationAction
]
