# This file was auto-generated by Fern from our API Definition.

ConnectionForwardReqInfoSms = bool
"""
When set to true, the gateway receives HTTP request details including IP address and User Agent from the client.
"""
