# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .branding_theme_borders_buttons_style_enum import BrandingThemeBordersButtonsStyleEnum
from .branding_theme_borders_inputs_style_enum import BrandingThemeBordersInputsStyleEnum


class BrandingThemeBorders(UniversalBaseModel):
    button_border_radius: float = pydantic.Field()
    """
    Button border radius
    """

    button_border_weight: float = pydantic.Field()
    """
    Button border weight
    """

    buttons_style: BrandingThemeBordersButtonsStyleEnum
    input_border_radius: float = pydantic.Field()
    """
    Input border radius
    """

    input_border_weight: float = pydantic.Field()
    """
    Input border weight
    """

    inputs_style: BrandingThemeBordersInputsStyleEnum
    show_widget_shadow: bool = pydantic.Field()
    """
    Show widget shadow
    """

    widget_border_weight: float = pydantic.Field()
    """
    Widget border weight
    """

    widget_corner_radius: float = pydantic.Field()
    """
    Widget corner radius
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
