# This file was auto-generated by Fern from our API Definition.

ConnectionSendBackChannelNonce = bool
"""
When true and type is 'back_channel', includes a cryptographic nonce in authorization requests to prevent replay attacks. The identity provider must include this nonce in the ID token for validation.
"""
