# This file was auto-generated by Fern from our API Definition.

import typing

BotDetectionChallengePolicyPasswordFlowEnum = typing.Union[typing.Literal["never", "when_risky", "always"], typing.Any]
