# This file was auto-generated by Fern from our API Definition.

import typing

from ......core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ......core.pagination import AsyncPager, SyncPager
from ......core.request_options import RequestOptions
from ......types.group import Group
from ......types.list_organization_member_role_source_groups_response_content import (
    ListOrganizationMemberRoleSourceGroupsResponseContent,
)
from .raw_client import AsyncRawGroupsClient, RawGroupsClient


class GroupsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawGroupsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawGroupsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawGroupsClient
        """
        return self._raw_client

    def list(
        self,
        id: str,
        user_id: str,
        *,
        role_id: str,
        from_: typing.Optional[str] = None,
        take: typing.Optional[int] = 50,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SyncPager[Group, ListOrganizationMemberRoleSourceGroupsResponseContent]:
        """
        Lists the groups which grant the org member a given role.

        Parameters
        ----------
        id : str
            Organization identifier.

        user_id : str
            ID of the user to list role source groups for.

        role_id : str
            The role ID to get group sources for.

        from_ : typing.Optional[str]
            Optional Id from which to start selection.

        take : typing.Optional[int]
            Number of results per page. Defaults to 50.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SyncPager[Group, ListOrganizationMemberRoleSourceGroupsResponseContent]
            Organization member role source groups successfully retrieved.

        Examples
        --------
        from auth0 import Auth0

        client = Auth0(
            token="YOUR_TOKEN",
        )
        response = client.organizations.members.effective_roles.sources.groups.list(
            id="id",
            user_id="user_id",
            from_="from",
            take=1,
            role_id="role_id",
        )
        for item in response:
            yield item
        # alternatively, you can paginate page-by-page
        for page in response.iter_pages():
            yield page
        """
        return self._raw_client.list(
            id, user_id, role_id=role_id, from_=from_, take=take, request_options=request_options
        )


class AsyncGroupsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawGroupsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawGroupsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawGroupsClient
        """
        return self._raw_client

    async def list(
        self,
        id: str,
        user_id: str,
        *,
        role_id: str,
        from_: typing.Optional[str] = None,
        take: typing.Optional[int] = 50,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncPager[Group, ListOrganizationMemberRoleSourceGroupsResponseContent]:
        """
        Lists the groups which grant the org member a given role.

        Parameters
        ----------
        id : str
            Organization identifier.

        user_id : str
            ID of the user to list role source groups for.

        role_id : str
            The role ID to get group sources for.

        from_ : typing.Optional[str]
            Optional Id from which to start selection.

        take : typing.Optional[int]
            Number of results per page. Defaults to 50.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncPager[Group, ListOrganizationMemberRoleSourceGroupsResponseContent]
            Organization member role source groups successfully retrieved.

        Examples
        --------
        import asyncio

        from auth0 import AsyncAuth0

        client = AsyncAuth0(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            response = (
                await client.organizations.members.effective_roles.sources.groups.list(
                    id="id",
                    user_id="user_id",
                    from_="from",
                    take=1,
                    role_id="role_id",
                )
            )
            async for item in response:
                yield item

            # alternatively, you can paginate page-by-page
            async for page in response.iter_pages():
                yield page


        asyncio.run(main())
        """
        return await self._raw_client.list(
            id, user_id, role_id=role_id, from_=from_, take=take, request_options=request_options
        )
