# This file was auto-generated by Fern from our API Definition.

import typing

from .event_stream_cloud_event_group_deleted_object_0 import EventStreamCloudEventGroupDeletedObject0
from .event_stream_cloud_event_group_deleted_object_1 import EventStreamCloudEventGroupDeletedObject1
from .event_stream_cloud_event_group_deleted_object_2 import EventStreamCloudEventGroupDeletedObject2

EventStreamCloudEventGroupDeletedObject = typing.Union[
    EventStreamCloudEventGroupDeletedObject0,
    EventStreamCloudEventGroupDeletedObject1,
    EventStreamCloudEventGroupDeletedObject2,
]
