# This file was auto-generated by Fern from our API Definition.

import typing

from .event_stream_cloud_event_group_member_deleted_object_member_0 import (
    EventStreamCloudEventGroupMemberDeletedObjectMember0,
)
from .event_stream_cloud_event_group_member_deleted_object_member_1 import (
    EventStreamCloudEventGroupMemberDeletedObjectMember1,
)

EventStreamCloudEventGroupMemberDeletedObjectMember = typing.Union[
    EventStreamCloudEventGroupMemberDeletedObjectMember0, EventStreamCloudEventGroupMemberDeletedObjectMember1
]
