# This file was auto-generated by Fern from our API Definition.

import typing

GuardianFactorsProviderSmsProviderEnum = typing.Union[
    typing.Literal["auth0", "twilio", "phone-message-hook"], typing.Any
]
