# This file was auto-generated by Fern from our API Definition.

ConnectionSigningCertificatePemPingFederate = str
"""
Base64-encoded X.509 certificate from the identity provider used to validate signatures in SAML responses and assertions. The certificate is decoded and used for cryptographic signature verification.
"""
