# This file was auto-generated by Fern from our API Definition.

import typing

SetSelfServiceProfileCustomTextRequestContent = typing.Dict[str, str]
"""
The list of text keys and values to customize the Self-Service Enterprise Configuration flow page. Values can be plain text or rich HTML content limited to basic styling tags and hyperlinks.
"""
