# This file was auto-generated by Fern from our API Definition.

import typing

FlowActionSlackPostMessageParamsAttachmentColor = typing.Union[typing.Literal["GOOD", "WARNING", "DANGER"], typing.Any]
