# This file was auto-generated by Fern from our API Definition.

import typing

from .flow_action_salesforce_create_lead import FlowActionSalesforceCreateLead
from .flow_action_salesforce_get_lead import FlowActionSalesforceGetLead
from .flow_action_salesforce_search_leads import FlowActionSalesforceSearchLeads
from .flow_action_salesforce_update_lead import FlowActionSalesforceUpdateLead

FlowActionSalesforce = typing.Union[
    FlowActionSalesforceCreateLead,
    FlowActionSalesforceGetLead,
    FlowActionSalesforceSearchLeads,
    FlowActionSalesforceUpdateLead,
]
