# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .log_stream_pii_algorithm_enum import LogStreamPiiAlgorithmEnum
from .log_stream_pii_log_fields_enum import LogStreamPiiLogFieldsEnum
from .log_stream_pii_method_enum import LogStreamPiiMethodEnum


class LogStreamPiiConfig(UniversalBaseModel):
    log_fields: typing.List[LogStreamPiiLogFieldsEnum]
    method: typing.Optional[LogStreamPiiMethodEnum] = None
    algorithm: typing.Optional[LogStreamPiiAlgorithmEnum] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
