# This file was auto-generated by Fern from our API Definition.

import typing

BruteForceProtectionModeEnum = typing.Union[
    typing.Literal["count_per_identifier_and_ip", "count_per_identifier"], typing.Any
]
