# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .event_stream_cloud_event_connection_created_cloud_event import EventStreamCloudEventConnectionCreatedCloudEvent
from .event_stream_cloud_event_connection_deleted_cloud_event import EventStreamCloudEventConnectionDeletedCloudEvent
from .event_stream_cloud_event_connection_updated_cloud_event import EventStreamCloudEventConnectionUpdatedCloudEvent
from .event_stream_cloud_event_error_detail import EventStreamCloudEventErrorDetail
from .event_stream_cloud_event_group_created_cloud_event import EventStreamCloudEventGroupCreatedCloudEvent
from .event_stream_cloud_event_group_deleted_cloud_event import EventStreamCloudEventGroupDeletedCloudEvent
from .event_stream_cloud_event_group_member_added_cloud_event import EventStreamCloudEventGroupMemberAddedCloudEvent
from .event_stream_cloud_event_group_member_deleted_cloud_event import EventStreamCloudEventGroupMemberDeletedCloudEvent
from .event_stream_cloud_event_group_role_assigned_cloud_event import EventStreamCloudEventGroupRoleAssignedCloudEvent
from .event_stream_cloud_event_group_role_deleted_cloud_event import EventStreamCloudEventGroupRoleDeletedCloudEvent
from .event_stream_cloud_event_group_updated_cloud_event import EventStreamCloudEventGroupUpdatedCloudEvent
from .event_stream_cloud_event_org_connection_added_cloud_event import EventStreamCloudEventOrgConnectionAddedCloudEvent
from .event_stream_cloud_event_org_connection_removed_cloud_event import (
    EventStreamCloudEventOrgConnectionRemovedCloudEvent,
)
from .event_stream_cloud_event_org_connection_updated_cloud_event import (
    EventStreamCloudEventOrgConnectionUpdatedCloudEvent,
)
from .event_stream_cloud_event_org_created_cloud_event import EventStreamCloudEventOrgCreatedCloudEvent
from .event_stream_cloud_event_org_deleted_cloud_event import EventStreamCloudEventOrgDeletedCloudEvent
from .event_stream_cloud_event_org_group_role_assigned_cloud_event import (
    EventStreamCloudEventOrgGroupRoleAssignedCloudEvent,
)
from .event_stream_cloud_event_org_group_role_deleted_cloud_event import (
    EventStreamCloudEventOrgGroupRoleDeletedCloudEvent,
)
from .event_stream_cloud_event_org_member_added_cloud_event import EventStreamCloudEventOrgMemberAddedCloudEvent
from .event_stream_cloud_event_org_member_deleted_cloud_event import EventStreamCloudEventOrgMemberDeletedCloudEvent
from .event_stream_cloud_event_org_member_role_assigned_cloud_event import (
    EventStreamCloudEventOrgMemberRoleAssignedCloudEvent,
)
from .event_stream_cloud_event_org_member_role_deleted_cloud_event import (
    EventStreamCloudEventOrgMemberRoleDeletedCloudEvent,
)
from .event_stream_cloud_event_org_updated_cloud_event import EventStreamCloudEventOrgUpdatedCloudEvent
from .event_stream_cloud_event_user_created_cloud_event import EventStreamCloudEventUserCreatedCloudEvent
from .event_stream_cloud_event_user_deleted_cloud_event import EventStreamCloudEventUserDeletedCloudEvent
from .event_stream_cloud_event_user_updated_cloud_event import EventStreamCloudEventUserUpdatedCloudEvent


class EventStreamSubscribeEventsResponseContent_ConnectionCreated(UniversalBaseModel):
    """
    The JSON payload delivered in each SSE data line. The type field is injected from the SSE event field by the SDK. Discriminated by type: an event type name for events, "error" for errors, and "offset-only" for cursor-only heartbeats.
    """

    type: typing.Literal["connection.created"] = "connection.created"
    offset: str
    event: EventStreamCloudEventConnectionCreatedCloudEvent

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class EventStreamSubscribeEventsResponseContent_ConnectionDeleted(UniversalBaseModel):
    """
    The JSON payload delivered in each SSE data line. The type field is injected from the SSE event field by the SDK. Discriminated by type: an event type name for events, "error" for errors, and "offset-only" for cursor-only heartbeats.
    """

    type: typing.Literal["connection.deleted"] = "connection.deleted"
    offset: str
    event: EventStreamCloudEventConnectionDeletedCloudEvent

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class EventStreamSubscribeEventsResponseContent_ConnectionUpdated(UniversalBaseModel):
    """
    The JSON payload delivered in each SSE data line. The type field is injected from the SSE event field by the SDK. Discriminated by type: an event type name for events, "error" for errors, and "offset-only" for cursor-only heartbeats.
    """

    type: typing.Literal["connection.updated"] = "connection.updated"
    offset: str
    event: EventStreamCloudEventConnectionUpdatedCloudEvent

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class EventStreamSubscribeEventsResponseContent_GroupCreated(UniversalBaseModel):
    """
    The JSON payload delivered in each SSE data line. The type field is injected from the SSE event field by the SDK. Discriminated by type: an event type name for events, "error" for errors, and "offset-only" for cursor-only heartbeats.
    """

    type: typing.Literal["group.created"] = "group.created"
    offset: str
    event: EventStreamCloudEventGroupCreatedCloudEvent

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class EventStreamSubscribeEventsResponseContent_GroupDeleted(UniversalBaseModel):
    """
    The JSON payload delivered in each SSE data line. The type field is injected from the SSE event field by the SDK. Discriminated by type: an event type name for events, "error" for errors, and "offset-only" for cursor-only heartbeats.
    """

    type: typing.Literal["group.deleted"] = "group.deleted"
    offset: str
    event: EventStreamCloudEventGroupDeletedCloudEvent

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class EventStreamSubscribeEventsResponseContent_GroupMemberAdded(UniversalBaseModel):
    """
    The JSON payload delivered in each SSE data line. The type field is injected from the SSE event field by the SDK. Discriminated by type: an event type name for events, "error" for errors, and "offset-only" for cursor-only heartbeats.
    """

    type: typing.Literal["group.member.added"] = "group.member.added"
    offset: str
    event: EventStreamCloudEventGroupMemberAddedCloudEvent

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class EventStreamSubscribeEventsResponseContent_GroupMemberDeleted(UniversalBaseModel):
    """
    The JSON payload delivered in each SSE data line. The type field is injected from the SSE event field by the SDK. Discriminated by type: an event type name for events, "error" for errors, and "offset-only" for cursor-only heartbeats.
    """

    type: typing.Literal["group.member.deleted"] = "group.member.deleted"
    offset: str
    event: EventStreamCloudEventGroupMemberDeletedCloudEvent

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class EventStreamSubscribeEventsResponseContent_GroupRoleAssigned(UniversalBaseModel):
    """
    The JSON payload delivered in each SSE data line. The type field is injected from the SSE event field by the SDK. Discriminated by type: an event type name for events, "error" for errors, and "offset-only" for cursor-only heartbeats.
    """

    type: typing.Literal["group.role.assigned"] = "group.role.assigned"
    offset: str
    event: EventStreamCloudEventGroupRoleAssignedCloudEvent

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class EventStreamSubscribeEventsResponseContent_GroupRoleDeleted(UniversalBaseModel):
    """
    The JSON payload delivered in each SSE data line. The type field is injected from the SSE event field by the SDK. Discriminated by type: an event type name for events, "error" for errors, and "offset-only" for cursor-only heartbeats.
    """

    type: typing.Literal["group.role.deleted"] = "group.role.deleted"
    offset: str
    event: EventStreamCloudEventGroupRoleDeletedCloudEvent

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class EventStreamSubscribeEventsResponseContent_GroupUpdated(UniversalBaseModel):
    """
    The JSON payload delivered in each SSE data line. The type field is injected from the SSE event field by the SDK. Discriminated by type: an event type name for events, "error" for errors, and "offset-only" for cursor-only heartbeats.
    """

    type: typing.Literal["group.updated"] = "group.updated"
    offset: str
    event: EventStreamCloudEventGroupUpdatedCloudEvent

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class EventStreamSubscribeEventsResponseContent_OrganizationConnectionAdded(UniversalBaseModel):
    """
    The JSON payload delivered in each SSE data line. The type field is injected from the SSE event field by the SDK. Discriminated by type: an event type name for events, "error" for errors, and "offset-only" for cursor-only heartbeats.
    """

    type: typing.Literal["organization.connection.added"] = "organization.connection.added"
    offset: str
    event: EventStreamCloudEventOrgConnectionAddedCloudEvent

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class EventStreamSubscribeEventsResponseContent_OrganizationConnectionRemoved(UniversalBaseModel):
    """
    The JSON payload delivered in each SSE data line. The type field is injected from the SSE event field by the SDK. Discriminated by type: an event type name for events, "error" for errors, and "offset-only" for cursor-only heartbeats.
    """

    type: typing.Literal["organization.connection.removed"] = "organization.connection.removed"
    offset: str
    event: EventStreamCloudEventOrgConnectionRemovedCloudEvent

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class EventStreamSubscribeEventsResponseContent_OrganizationConnectionUpdated(UniversalBaseModel):
    """
    The JSON payload delivered in each SSE data line. The type field is injected from the SSE event field by the SDK. Discriminated by type: an event type name for events, "error" for errors, and "offset-only" for cursor-only heartbeats.
    """

    type: typing.Literal["organization.connection.updated"] = "organization.connection.updated"
    offset: str
    event: EventStreamCloudEventOrgConnectionUpdatedCloudEvent

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class EventStreamSubscribeEventsResponseContent_OrganizationCreated(UniversalBaseModel):
    """
    The JSON payload delivered in each SSE data line. The type field is injected from the SSE event field by the SDK. Discriminated by type: an event type name for events, "error" for errors, and "offset-only" for cursor-only heartbeats.
    """

    type: typing.Literal["organization.created"] = "organization.created"
    offset: str
    event: EventStreamCloudEventOrgCreatedCloudEvent

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class EventStreamSubscribeEventsResponseContent_OrganizationDeleted(UniversalBaseModel):
    """
    The JSON payload delivered in each SSE data line. The type field is injected from the SSE event field by the SDK. Discriminated by type: an event type name for events, "error" for errors, and "offset-only" for cursor-only heartbeats.
    """

    type: typing.Literal["organization.deleted"] = "organization.deleted"
    offset: str
    event: EventStreamCloudEventOrgDeletedCloudEvent

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class EventStreamSubscribeEventsResponseContent_OrganizationGroupRoleAssigned(UniversalBaseModel):
    """
    The JSON payload delivered in each SSE data line. The type field is injected from the SSE event field by the SDK. Discriminated by type: an event type name for events, "error" for errors, and "offset-only" for cursor-only heartbeats.
    """

    type: typing.Literal["organization.group.role.assigned"] = "organization.group.role.assigned"
    offset: str
    event: EventStreamCloudEventOrgGroupRoleAssignedCloudEvent

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class EventStreamSubscribeEventsResponseContent_OrganizationGroupRoleDeleted(UniversalBaseModel):
    """
    The JSON payload delivered in each SSE data line. The type field is injected from the SSE event field by the SDK. Discriminated by type: an event type name for events, "error" for errors, and "offset-only" for cursor-only heartbeats.
    """

    type: typing.Literal["organization.group.role.deleted"] = "organization.group.role.deleted"
    offset: str
    event: EventStreamCloudEventOrgGroupRoleDeletedCloudEvent

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class EventStreamSubscribeEventsResponseContent_OrganizationMemberAdded(UniversalBaseModel):
    """
    The JSON payload delivered in each SSE data line. The type field is injected from the SSE event field by the SDK. Discriminated by type: an event type name for events, "error" for errors, and "offset-only" for cursor-only heartbeats.
    """

    type: typing.Literal["organization.member.added"] = "organization.member.added"
    offset: str
    event: EventStreamCloudEventOrgMemberAddedCloudEvent

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class EventStreamSubscribeEventsResponseContent_OrganizationMemberDeleted(UniversalBaseModel):
    """
    The JSON payload delivered in each SSE data line. The type field is injected from the SSE event field by the SDK. Discriminated by type: an event type name for events, "error" for errors, and "offset-only" for cursor-only heartbeats.
    """

    type: typing.Literal["organization.member.deleted"] = "organization.member.deleted"
    offset: str
    event: EventStreamCloudEventOrgMemberDeletedCloudEvent

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class EventStreamSubscribeEventsResponseContent_OrganizationMemberRoleAssigned(UniversalBaseModel):
    """
    The JSON payload delivered in each SSE data line. The type field is injected from the SSE event field by the SDK. Discriminated by type: an event type name for events, "error" for errors, and "offset-only" for cursor-only heartbeats.
    """

    type: typing.Literal["organization.member.role.assigned"] = "organization.member.role.assigned"
    offset: str
    event: EventStreamCloudEventOrgMemberRoleAssignedCloudEvent

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class EventStreamSubscribeEventsResponseContent_OrganizationMemberRoleDeleted(UniversalBaseModel):
    """
    The JSON payload delivered in each SSE data line. The type field is injected from the SSE event field by the SDK. Discriminated by type: an event type name for events, "error" for errors, and "offset-only" for cursor-only heartbeats.
    """

    type: typing.Literal["organization.member.role.deleted"] = "organization.member.role.deleted"
    offset: str
    event: EventStreamCloudEventOrgMemberRoleDeletedCloudEvent

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class EventStreamSubscribeEventsResponseContent_OrganizationUpdated(UniversalBaseModel):
    """
    The JSON payload delivered in each SSE data line. The type field is injected from the SSE event field by the SDK. Discriminated by type: an event type name for events, "error" for errors, and "offset-only" for cursor-only heartbeats.
    """

    type: typing.Literal["organization.updated"] = "organization.updated"
    offset: str
    event: EventStreamCloudEventOrgUpdatedCloudEvent

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class EventStreamSubscribeEventsResponseContent_UserCreated(UniversalBaseModel):
    """
    The JSON payload delivered in each SSE data line. The type field is injected from the SSE event field by the SDK. Discriminated by type: an event type name for events, "error" for errors, and "offset-only" for cursor-only heartbeats.
    """

    type: typing.Literal["user.created"] = "user.created"
    offset: str
    event: EventStreamCloudEventUserCreatedCloudEvent

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class EventStreamSubscribeEventsResponseContent_UserDeleted(UniversalBaseModel):
    """
    The JSON payload delivered in each SSE data line. The type field is injected from the SSE event field by the SDK. Discriminated by type: an event type name for events, "error" for errors, and "offset-only" for cursor-only heartbeats.
    """

    type: typing.Literal["user.deleted"] = "user.deleted"
    offset: str
    event: EventStreamCloudEventUserDeletedCloudEvent

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class EventStreamSubscribeEventsResponseContent_UserUpdated(UniversalBaseModel):
    """
    The JSON payload delivered in each SSE data line. The type field is injected from the SSE event field by the SDK. Discriminated by type: an event type name for events, "error" for errors, and "offset-only" for cursor-only heartbeats.
    """

    type: typing.Literal["user.updated"] = "user.updated"
    offset: str
    event: EventStreamCloudEventUserUpdatedCloudEvent

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class EventStreamSubscribeEventsResponseContent_Error(UniversalBaseModel):
    """
    The JSON payload delivered in each SSE data line. The type field is injected from the SSE event field by the SDK. Discriminated by type: an event type name for events, "error" for errors, and "offset-only" for cursor-only heartbeats.
    """

    type: typing.Literal["error"] = "error"
    error: EventStreamCloudEventErrorDetail

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class EventStreamSubscribeEventsResponseContent_OffsetOnly(UniversalBaseModel):
    """
    The JSON payload delivered in each SSE data line. The type field is injected from the SSE event field by the SDK. Discriminated by type: an event type name for events, "error" for errors, and "offset-only" for cursor-only heartbeats.
    """

    type: typing.Literal["offset-only"] = "offset-only"
    offset: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


EventStreamSubscribeEventsResponseContent = typing_extensions.Annotated[
    typing.Union[
        EventStreamSubscribeEventsResponseContent_ConnectionCreated,
        EventStreamSubscribeEventsResponseContent_ConnectionDeleted,
        EventStreamSubscribeEventsResponseContent_ConnectionUpdated,
        EventStreamSubscribeEventsResponseContent_GroupCreated,
        EventStreamSubscribeEventsResponseContent_GroupDeleted,
        EventStreamSubscribeEventsResponseContent_GroupMemberAdded,
        EventStreamSubscribeEventsResponseContent_GroupMemberDeleted,
        EventStreamSubscribeEventsResponseContent_GroupRoleAssigned,
        EventStreamSubscribeEventsResponseContent_GroupRoleDeleted,
        EventStreamSubscribeEventsResponseContent_GroupUpdated,
        EventStreamSubscribeEventsResponseContent_OrganizationConnectionAdded,
        EventStreamSubscribeEventsResponseContent_OrganizationConnectionRemoved,
        EventStreamSubscribeEventsResponseContent_OrganizationConnectionUpdated,
        EventStreamSubscribeEventsResponseContent_OrganizationCreated,
        EventStreamSubscribeEventsResponseContent_OrganizationDeleted,
        EventStreamSubscribeEventsResponseContent_OrganizationGroupRoleAssigned,
        EventStreamSubscribeEventsResponseContent_OrganizationGroupRoleDeleted,
        EventStreamSubscribeEventsResponseContent_OrganizationMemberAdded,
        EventStreamSubscribeEventsResponseContent_OrganizationMemberDeleted,
        EventStreamSubscribeEventsResponseContent_OrganizationMemberRoleAssigned,
        EventStreamSubscribeEventsResponseContent_OrganizationMemberRoleDeleted,
        EventStreamSubscribeEventsResponseContent_OrganizationUpdated,
        EventStreamSubscribeEventsResponseContent_UserCreated,
        EventStreamSubscribeEventsResponseContent_UserDeleted,
        EventStreamSubscribeEventsResponseContent_UserUpdated,
        EventStreamSubscribeEventsResponseContent_Error,
        EventStreamSubscribeEventsResponseContent_OffsetOnly,
    ],
    pydantic.Field(discriminator="type"),
]
