# This file was auto-generated by Fern from our API Definition.

import typing

ResourceServerSubjectTypeAuthorizationClientPolicyEnum = typing.Union[
    typing.Literal["deny_all", "require_client_grant"], typing.Any
]
