# This file was auto-generated by Fern from our API Definition.

import typing

from .flow_action_xml_serialize_xml_params_object_object import FlowActionXmlSerializeXmlParamsObjectObject

FlowActionXmlSerializeXmlParamsObject = typing.Union[str, FlowActionXmlSerializeXmlParamsObjectObject]
