# This file was auto-generated by Fern from our API Definition.

import typing

from .create_flows_vault_connection_salesforce_oauth_code import CreateFlowsVaultConnectionSalesforceOauthCode
from .create_flows_vault_connection_salesforce_uninitialized import CreateFlowsVaultConnectionSalesforceUninitialized

CreateFlowsVaultConnectionSalesforce = typing.Union[
    CreateFlowsVaultConnectionSalesforceOauthCode, CreateFlowsVaultConnectionSalesforceUninitialized
]
