# This file was auto-generated by Fern from our API Definition.

import typing

ConnectionIdTokenEncryptionEncValuesSupported = typing.List[str]
"""
JSON array containing a list of the JWE encryption algorithms (enc values) supported by the OP for the ID Token to encode the Claims in a JWT [JWT].
"""
