# This file was auto-generated by Fern from our API Definition.

import typing

EventStreamCloudEventErrorCodeEnum = typing.Union[
    typing.Literal[
        "invalid_cursor", "cursor_expired", "timeout", "payload_too_large", "processing_error", "connection_timeout"
    ],
    typing.Any,
]
