# This file was auto-generated by Fern from our API Definition.

import typing

EmailTemplateNameEnum = typing.Union[
    typing.Literal[
        "verify_email",
        "verify_email_by_code",
        "auth_email_by_code",
        "reset_email",
        "reset_email_by_code",
        "welcome_email",
        "blocked_account",
        "stolen_credentials",
        "enrollment_email",
        "mfa_oob_code",
        "user_invitation",
        "change_password",
        "password_reset",
        "async_approval",
    ],
    typing.Any,
]
