# This file was auto-generated by Fern from our API Definition.

import typing

from .custom_domain_custom_client_ip_header_enum import CustomDomainCustomClientIpHeaderEnum

CustomDomainCustomClientIpHeader = typing.Optional[CustomDomainCustomClientIpHeaderEnum]
