# This file was auto-generated by Fern from our API Definition.

ConnectionSigningCertificateDerSaml = str
"""
X.509 signing certificate from the identity provider in .der format. Used to validate signatures in SAML Responses and Assertions. This is an alternative to signingCert and is kept for backward compatibility. Prefer using signingCert instead.
"""
