# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .network_acl_rule import NetworkAclRule


class NetworkAclsResponseContent(UniversalBaseModel):
    id: typing.Optional[str] = None
    description: typing.Optional[str] = None
    active: typing.Optional[bool] = None
    priority: typing.Optional[float] = None
    rule: typing.Optional[NetworkAclRule] = None
    created_at: typing.Optional[str] = pydantic.Field(default=None)
    """
    The timestamp when the Network ACL Configuration was created
    """

    updated_at: typing.Optional[str] = pydantic.Field(default=None)
    """
    The timestamp when the Network ACL Configuration was last updated
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
