# This file was auto-generated by Fern from our API Definition.

import typing

from .flow_action_mailjet_send_email_params_content import FlowActionMailjetSendEmailParamsContent
from .flow_action_mailjet_send_email_params_template_id import FlowActionMailjetSendEmailParamsTemplateId

FlowActionMailjetSendEmailParams = typing.Union[
    FlowActionMailjetSendEmailParamsContent, FlowActionMailjetSendEmailParamsTemplateId
]
