# This file was auto-generated by Fern from our API Definition.

import typing

ConnectionScopesSupported = typing.Optional[typing.List[str]]
"""
A list of the OAuth 2.0 [RFC6749] scope values that this server supports. The server MUST support the openid scope value. Servers MAY choose not to advertise some supported scope values even when this parameter is used, although those defined in [OpenID.Core] SHOULD be listed, if supported. RECOMMENDED but not REQUIRED
"""
