# This file was auto-generated by Fern from our API Definition.

import typing

DeviceCredentialTypeEnum = typing.Union[
    typing.Literal["public_key", "refresh_token", "rotating_refresh_token"], typing.Any
]
