# This file was auto-generated by Fern from our API Definition.

import typing

from .event_stream_cloud_event_group_updated_object_0 import EventStreamCloudEventGroupUpdatedObject0
from .event_stream_cloud_event_group_updated_object_1 import EventStreamCloudEventGroupUpdatedObject1
from .event_stream_cloud_event_group_updated_object_2 import EventStreamCloudEventGroupUpdatedObject2

EventStreamCloudEventGroupUpdatedObject = typing.Union[
    EventStreamCloudEventGroupUpdatedObject0,
    EventStreamCloudEventGroupUpdatedObject1,
    EventStreamCloudEventGroupUpdatedObject2,
]
