# This file was auto-generated by Fern from our API Definition.

ConnectionIsDomainConnection = bool
"""
<code>true</code> promotes to a domain-level connection so that third-party applications can use it. <code>false</code> does not promote the connection, so only first-party applications with the connection enabled can use it. (Defaults to <code>false</code>.)
"""
