# This file was auto-generated by Fern from our API Definition.

from .connection_ping_federate_base_url_ping_federate import ConnectionPingFederateBaseUrlPingFederate

ConnectionPingFederateBaseUrl = ConnectionPingFederateBaseUrlPingFederate
"""
URL provided by PingFederate which returns information used for creating the connection
"""
