# This file was auto-generated by Fern from our API Definition.

import typing

from .patch_rate_limit_policy_configuration_request_content_action import (
    PatchRateLimitPolicyConfigurationRequestContentAction,
)
from .patch_rate_limit_policy_configuration_request_content_one import (
    PatchRateLimitPolicyConfigurationRequestContentOne,
)
from .patch_rate_limit_policy_configuration_request_content_zero import (
    PatchRateLimitPolicyConfigurationRequestContentZero,
)

PatchRateLimitPolicyConfigurationRequestContent = typing.Union[
    PatchRateLimitPolicyConfigurationRequestContentZero,
    PatchRateLimitPolicyConfigurationRequestContentOne,
    PatchRateLimitPolicyConfigurationRequestContentAction,
]
