# This file was auto-generated by Fern from our API Definition.

import typing

ClientTokenEndpointAuthMethodOrNullEnum = typing.Union[
    typing.Literal["none", "client_secret_post", "client_secret_basic"], typing.Any
]
