# This file was auto-generated by Fern from our API Definition.

import typing

from .flow_action_http_send_request_params_query_params_value import FlowActionHttpSendRequestParamsQueryParamsValue

FlowActionHttpSendRequestParamsQueryParams = typing.Dict[
    str, typing.Optional[FlowActionHttpSendRequestParamsQueryParamsValue]
]
