# This file was auto-generated by Fern from our API Definition.

import typing

DomainCertificateStatusEnum = typing.Union[
    typing.Literal["provisioning", "provisioning_failed", "provisioned", "renewing_failed"], typing.Any
]
