# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .form_block_resend_button_config import FormBlockResendButtonConfig
from .form_block_type_resend_button_const import FormBlockTypeResendButtonConst
from .form_component_category_block_const import FormComponentCategoryBlockConst


class FormBlockResendButton(UniversalBaseModel):
    id: str
    category: FormComponentCategoryBlockConst
    type: FormBlockTypeResendButtonConst
    config: FormBlockResendButtonConfig

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
