# This file was auto-generated by Fern from our API Definition.

import typing

CreateConnectionRequestContentSalesforceCommunityStrategy = typing.Union[
    typing.Literal["salesforce-community"], typing.Any
]
