# This file was auto-generated by Fern from our API Definition.

import typing

BreachedPasswordDetectionPreChangePasswordShieldsEnum = typing.Union[
    typing.Literal["block", "admin_notification"], typing.Any
]
