# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .form_block_resend_button_config_text_alignment_enum import FormBlockResendButtonConfigTextAlignmentEnum


class FormBlockResendButtonConfig(UniversalBaseModel):
    active_text: str
    button_text: str
    waiting_text: str
    text_alignment: typing.Optional[FormBlockResendButtonConfigTextAlignmentEnum] = None
    flow_id: str
    max_attempts: typing.Optional[float] = None
    waiting_time: typing.Optional[float] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
