# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .user_attribute_profile_strategy_overrides_user_id_mapping import (
    UserAttributeProfileStrategyOverridesUserIdMapping,
)


class UserAttributeProfileStrategyOverridesUserId(UniversalBaseModel):
    """
    Strategy-specific overrides for user ID
    """

    pingfederate: typing.Optional[UserAttributeProfileStrategyOverridesUserIdMapping] = None
    ad: typing.Optional[UserAttributeProfileStrategyOverridesUserIdMapping] = None
    adfs: typing.Optional[UserAttributeProfileStrategyOverridesUserIdMapping] = None
    waad: typing.Optional[UserAttributeProfileStrategyOverridesUserIdMapping] = None
    google_apps: typing_extensions.Annotated[
        typing.Optional[UserAttributeProfileStrategyOverridesUserIdMapping],
        FieldMetadata(alias="google-apps"),
        pydantic.Field(alias="google-apps"),
    ] = None
    okta: typing.Optional[UserAttributeProfileStrategyOverridesUserIdMapping] = None
    oidc: typing.Optional[UserAttributeProfileStrategyOverridesUserIdMapping] = None
    samlp: typing.Optional[UserAttributeProfileStrategyOverridesUserIdMapping] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
