# This file was auto-generated by Fern from our API Definition.

ConnectionAgentModeAd = bool
"""
When enabled, allows direct username/password authentication through the AD connector agent instead of WS-Federation protocol (managed by the AD Connector agent).
"""
