# This file was auto-generated by Fern from our API Definition.

from .connection_ext_groups import ConnectionExtGroups

ConnectionExtGroupsAzureAd = ConnectionExtGroups
"""
When enabled (true), retrieves and stores Azure AD security group memberships for the user. Requires Microsoft Graph API permissions (Directory.Read.All). Allows configuring max_groups_to_retrieve.
"""
