# This file was auto-generated by Fern from our API Definition.

import typing

from .create_flows_vault_connection_hubspot_api_key import CreateFlowsVaultConnectionHubspotApiKey
from .create_flows_vault_connection_hubspot_oauth_code import CreateFlowsVaultConnectionHubspotOauthCode
from .create_flows_vault_connection_hubspot_uninitialized import CreateFlowsVaultConnectionHubspotUninitialized

CreateFlowsVaultConnectionHubspot = typing.Union[
    CreateFlowsVaultConnectionHubspotApiKey,
    CreateFlowsVaultConnectionHubspotOauthCode,
    CreateFlowsVaultConnectionHubspotUninitialized,
]
