# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .csp_policies import CspPolicies
from .csp_reporting_infrastructure import CspReportingInfrastructure


class ContentSecurityPolicyConfig(UniversalBaseModel):
    """
    Content Security Policy configuration with multi-policy support.
    """

    enabled: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether CSP is enabled.
    """

    policies: typing.Optional[CspPolicies] = None
    reporting_infrastructure: typing.Optional[CspReportingInfrastructure] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
