# This file was auto-generated by Fern from our API Definition.

import typing

ListSelfServiceProfileCustomTextResponseContent = typing.Dict[str, str]
"""
The list of custom text keys and values.
"""
