# This file was auto-generated by Fern from our API Definition.

from .connection_totp_length_passwordless import ConnectionTotpLengthPasswordless

ConnectionTotpLengthEmail = ConnectionTotpLengthPasswordless
"""
Length of the TOTP code
"""
