# This file was auto-generated by Fern from our API Definition.

import typing

EventStreamCloudEventConnectionUpdatedObject1OptionsIdTokenSignedResponseAlgsItemEnum = typing.Union[
    typing.Literal["ES256", "ES384", "PS256", "PS384", "RS256", "RS384", "RS512"], typing.Any
]
