# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .connection_profile_organization_assign_membership_on_login_enum import (
    ConnectionProfileOrganizationAssignMembershipOnLoginEnum,
)
from .connection_profile_organization_show_as_button_enum import ConnectionProfileOrganizationShowAsButtonEnum


class ConnectionProfileOrganization(UniversalBaseModel):
    """
    The organization of the connection profile.
    """

    show_as_button: typing.Optional[ConnectionProfileOrganizationShowAsButtonEnum] = None
    assign_membership_on_login: typing.Optional[ConnectionProfileOrganizationAssignMembershipOnLoginEnum] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
