# This file was auto-generated by Fern from our API Definition.

ConnectionEnableScriptContext = bool
"""
Set to true to inject context into custom DB scripts (warning: cannot be disabled once enabled)
"""
