# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class ClientRefreshTokenPolicy(UniversalBaseModel):
    audience: str = pydantic.Field()
    """
    The identifier of the resource server to which the Multi Resource Refresh Token Policy applies
    """

    scope: typing.List[str] = pydantic.Field()
    """
    The resource server permissions granted under the Multi Resource Refresh Token Policy, defining the context in which an access token can be used
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
