# This file was auto-generated by Fern from our API Definition.

ConnectionAgentIpad = str
"""
IP address of the AD connector agent used to validate that authentication requests originate from the corporate network for Kerberos authentication  (managed by the AD Connector agent).
"""
