# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .form_block_divider_config import FormBlockDividerConfig
from .form_block_type_divider_const import FormBlockTypeDividerConst
from .form_component_category_block_const import FormComponentCategoryBlockConst


class FormBlockDivider(UniversalBaseModel):
    id: str
    category: FormComponentCategoryBlockConst
    type: FormBlockTypeDividerConst
    config: typing.Optional[FormBlockDividerConfig] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
