# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .user_attribute_profile_saml_mapping import UserAttributeProfileSamlMapping
from .user_attribute_profile_user_id_oidc_strategy_override_mapping import (
    UserAttributeProfileUserIdOidcStrategyOverrideMapping,
)


class UserAttributeProfileStrategyOverridesUserIdMapping(UniversalBaseModel):
    oidc_mapping: typing.Optional[UserAttributeProfileUserIdOidcStrategyOverrideMapping] = None
    saml_mapping: typing.Optional[UserAttributeProfileSamlMapping] = None
    scim_mapping: typing.Optional[str] = pydantic.Field(default=None)
    """
    SCIM mapping override for this strategy
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
