# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .csp_directives import CspDirectives
from .csp_flags import CspFlags
from .csp_policy_mode import CspPolicyMode
from .csp_policy_reporting import CspPolicyReporting


class CspPolicy(UniversalBaseModel):
    """
    A single CSP policy with mode, directives, flags, and optional reporting.
    """

    mode: typing.Optional[CspPolicyMode] = None
    directives: typing.Optional[CspDirectives] = None
    flags: typing.Optional[CspFlags] = None
    reporting: typing.Optional[CspPolicyReporting] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
