# This file was auto-generated by Fern from our API Definition.

import typing

ClientMyOrganizationConfigurationAllowedStrategiesEnum = typing.Union[
    typing.Literal["pingfederate", "adfs", "waad", "google-apps", "okta", "oidc", "samlp"], typing.Any
]
