# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .phone_template_body import PhoneTemplateBody


class PhoneTemplateContent(UniversalBaseModel):
    syntax: typing.Optional[str] = None
    from_: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="from"),
        pydantic.Field(
            alias="from", description="Default phone number to be used as 'from' when sending a phone notification"
        ),
    ] = None
    """
    Default phone number to be used as 'from' when sending a phone notification
    """

    body: typing.Optional[PhoneTemplateBody] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
