# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .network_acl_action import NetworkAclAction
from .network_acl_match import NetworkAclMatch
from .network_acl_rule_scope_enum import NetworkAclRuleScopeEnum


class NetworkAclRule(UniversalBaseModel):
    action: NetworkAclAction
    match: typing.Optional[NetworkAclMatch] = None
    not_match: typing.Optional[NetworkAclMatch] = None
    scope: NetworkAclRuleScopeEnum

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
