# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .user_authentication_method import UserAuthenticationMethod


class ListUserAuthenticationMethodsOffsetPaginatedResponseContent(UniversalBaseModel):
    start: typing.Optional[float] = pydantic.Field(default=None)
    """
    Index of the starting record. Derived from the page and per_page parameters.
    """

    limit: typing.Optional[float] = pydantic.Field(default=None)
    """
    Maximum amount of records to return.
    """

    total: typing.Optional[float] = pydantic.Field(default=None)
    """
    Total number of pageable records.
    """

    authenticators: typing.Optional[typing.List[UserAuthenticationMethod]] = pydantic.Field(default=None)
    """
    The paginated authentication methods. Returned in this structure when include_totals is true.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
