# This file was auto-generated by Fern from our API Definition.

import typing

from .flow_action_clearbit_find_company import FlowActionClearbitFindCompany
from .flow_action_clearbit_find_person import FlowActionClearbitFindPerson

FlowActionClearbit = typing.Union[FlowActionClearbitFindPerson, FlowActionClearbitFindCompany]
