# This file was auto-generated by Fern from our API Definition.

ConnectionProfileBitbucket = bool
"""
`profile` is a boolean that controls whether basic profile information (name, picture, email) is requested from Bitbucket during authentication. When `true`, the connection requests access to the user's basic profile data.
"""
