# This file was auto-generated by Fern from our API Definition.

import typing

ClientAddonBox = typing.Dict[str, typing.Any]
"""
Box SSO indicator (no configuration settings needed for Box SSO).
"""
