# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .log_stream_event_bridge_sink_region_enum import LogStreamEventBridgeSinkRegionEnum


class LogStreamEventBridgeSink(UniversalBaseModel):
    aws_account_id: typing_extensions.Annotated[
        str, FieldMetadata(alias="awsAccountId"), pydantic.Field(alias="awsAccountId", description="AWS account ID")
    ]
    """
    AWS account ID
    """

    aws_region: typing_extensions.Annotated[
        LogStreamEventBridgeSinkRegionEnum, FieldMetadata(alias="awsRegion"), pydantic.Field(alias="awsRegion")
    ]
    aws_partner_event_source: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="awsPartnerEventSource"),
        pydantic.Field(alias="awsPartnerEventSource", description="AWS EventBridge partner event source"),
    ] = None
    """
    AWS EventBridge partner event source
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
