# This file was auto-generated by Fern from our API Definition.

import typing

from .create_flows_vault_connection_bigquery_jwt import CreateFlowsVaultConnectionBigqueryJwt
from .create_flows_vault_connection_bigquery_uninitialized import CreateFlowsVaultConnectionBigqueryUninitialized

CreateFlowsVaultConnectionBigquery = typing.Union[
    CreateFlowsVaultConnectionBigqueryJwt, CreateFlowsVaultConnectionBigqueryUninitialized
]
