# This file was auto-generated by Fern from our API Definition.

import typing

LogStreamFilterGroupNameEnum = typing.Union[
    typing.Literal[
        "auth.login.fail",
        "auth.login.notification",
        "auth.login.success",
        "auth.logout.fail",
        "auth.logout.success",
        "auth.signup.fail",
        "auth.signup.success",
        "auth.silent_auth.fail",
        "auth.silent_auth.success",
        "auth.token_exchange.fail",
        "auth.token_exchange.success",
        "management.fail",
        "management.success",
        "scim.event",
        "system.notification",
        "user.fail",
        "user.notification",
        "user.success",
        "actions",
        "other",
    ],
    typing.Any,
]
