# This file was auto-generated by Fern from our API Definition.

import typing

AuthenticationMethodTypeEnum = typing.Union[
    typing.Literal[
        "recovery-code",
        "totp",
        "push",
        "phone",
        "email",
        "email-verification",
        "webauthn-roaming",
        "webauthn-platform",
        "guardian",
        "passkey",
        "password",
    ],
    typing.Any,
]
