# This file was auto-generated by Fern from our API Definition.

ConnectionBruteForceProtection = bool
"""
Enables Auth0's brute force protection to prevent credential stuffing attacks. When enabled, blocks suspicious login attempts from specific IP addresses after repeated failures.
"""
