# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class EmailProviderCredentialsSchemaClientId(UniversalBaseModel):
    tenant_id: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="tenantId"),
        pydantic.Field(alias="tenantId", description="Microsoft 365 Tenant ID."),
    ] = None
    """
    Microsoft 365 Tenant ID.
    """

    client_id: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="clientId"),
        pydantic.Field(alias="clientId", description="Microsoft 365 Client ID."),
    ] = None
    """
    Microsoft 365 Client ID.
    """

    client_secret: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="clientSecret"),
        pydantic.Field(alias="clientSecret", description="Microsoft 365 Client Secret."),
    ] = None
    """
    Microsoft 365 Client Secret.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
