# This file was auto-generated by Fern from our API Definition.

import typing

from .form_field_boolean import FormFieldBoolean
from .form_field_cards import FormFieldCards
from .form_field_choice import FormFieldChoice
from .form_field_custom import FormFieldCustom
from .form_field_date import FormFieldDate
from .form_field_dropdown import FormFieldDropdown
from .form_field_email import FormFieldEmail
from .form_field_file import FormFieldFile
from .form_field_legal import FormFieldLegal
from .form_field_number import FormFieldNumber
from .form_field_password import FormFieldPassword
from .form_field_payment import FormFieldPayment
from .form_field_social import FormFieldSocial
from .form_field_tel import FormFieldTel
from .form_field_text import FormFieldText
from .form_field_url import FormFieldUrl

FormField = typing.Union[
    FormFieldBoolean,
    FormFieldCards,
    FormFieldChoice,
    FormFieldCustom,
    FormFieldDate,
    FormFieldDropdown,
    FormFieldEmail,
    FormFieldFile,
    FormFieldLegal,
    FormFieldNumber,
    FormFieldPassword,
    FormFieldPayment,
    FormFieldSocial,
    FormFieldTel,
    FormFieldText,
    FormFieldUrl,
]
