# This file was auto-generated by Fern from our API Definition.

import typing

ActionTriggerTypeEnum = typing.Union[
    typing.Literal[
        "post-login",
        "credentials-exchange",
        "pre-user-registration",
        "post-user-registration",
        "post-change-password",
        "send-phone-message",
        "custom-phone-provider",
        "custom-email-provider",
        "password-reset-post-challenge",
        "custom-token-exchange",
        "event-stream",
        "password-hash-migration",
        "login-post-identifier",
        "signup-post-identifier",
    ],
    typing.Any,
]
