# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .guardian_factor_phone_factor_message_type_enum import GuardianFactorPhoneFactorMessageTypeEnum


class SetGuardianFactorPhoneMessageTypesResponseContent(UniversalBaseModel):
    message_types: typing.Optional[typing.List[GuardianFactorPhoneFactorMessageTypeEnum]] = pydantic.Field(default=None)
    """
    The list of phone factors to enable on the tenant. Can include `sms` and `voice`.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
