# This file was auto-generated by Fern from our API Definition.

import typing

from .flow_action_twilio_make_call import FlowActionTwilioMakeCall
from .flow_action_twilio_send_sms import FlowActionTwilioSendSms

FlowActionTwilio = typing.Union[FlowActionTwilioMakeCall, FlowActionTwilioSendSms]
