# This file was auto-generated by Fern from our API Definition.

ConnectionClientSecretOidc = str
"""
OAuth 2.0 client secret issued by the identity provider during application registration. Used to authenticate your Auth0 connection when exchanging authorization codes for tokens. May be null for public clients.
"""
