# This file was auto-generated by Fern from our API Definition.

import typing

from .event_stream_cloud_event_group_created_object_0 import EventStreamCloudEventGroupCreatedObject0
from .event_stream_cloud_event_group_created_object_1 import EventStreamCloudEventGroupCreatedObject1
from .event_stream_cloud_event_group_created_object_2 import EventStreamCloudEventGroupCreatedObject2

EventStreamCloudEventGroupCreatedObject = typing.Union[
    EventStreamCloudEventGroupCreatedObject0,
    EventStreamCloudEventGroupCreatedObject1,
    EventStreamCloudEventGroupCreatedObject2,
]
