# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from .connection_attribute_map_oidc import ConnectionAttributeMapOidc
from .connection_discovery_url import ConnectionDiscoveryUrl
from .connection_options_common import ConnectionOptionsCommon
from .connection_options_common_oidc import ConnectionOptionsCommonOidc
from .connection_type_enum_oidc import ConnectionTypeEnumOidc


class ConnectionOptionsOidc(ConnectionOptionsCommonOidc, ConnectionOptionsCommon):
    """
    Options for the 'oidc' connection
    """

    attribute_map: typing.Optional[ConnectionAttributeMapOidc] = None
    discovery_url: typing.Optional[ConnectionDiscoveryUrl] = None
    type: typing.Optional[ConnectionTypeEnumOidc] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
