# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .event_stream_event_bridge_aws_region_enum import EventStreamEventBridgeAwsRegionEnum


class EventStreamEventBridgeConfiguration(UniversalBaseModel):
    """
    Configuration specific to an eventbridge destination.
    """

    aws_account_id: str = pydantic.Field()
    """
    AWS Account ID for EventBridge destination.
    """

    aws_region: EventStreamEventBridgeAwsRegionEnum
    aws_partner_event_source: typing.Optional[str] = pydantic.Field(default=None)
    """
    AWS Partner Event Source for EventBridge destination.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
