# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .event_stream_response_content import EventStreamResponseContent


class ListEventStreamsResponseContent(UniversalBaseModel):
    event_streams: typing_extensions.Annotated[
        typing.Optional[typing.List[EventStreamResponseContent]],
        FieldMetadata(alias="eventStreams"),
        pydantic.Field(alias="eventStreams"),
    ] = None
    next: typing.Optional[str] = pydantic.Field(default=None)
    """
    Opaque identifier for use with the <i>from</i> query parameter for the next page of results.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
