# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .event_stream_cloud_event_error_code_enum import EventStreamCloudEventErrorCodeEnum


class EventStreamCloudEventErrorDetail(UniversalBaseModel):
    """
    Error details.
    """

    code: EventStreamCloudEventErrorCodeEnum
    message: str = pydantic.Field()
    """
    Human-readable error message.
    """

    offset: typing.Optional[str] = pydantic.Field(default=None)
    """
    The cursor at the time of the error (when available). Can be used to resume from this position.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
