# This file was auto-generated by Fern from our API Definition.

ConnectionUserinfoEndpoint = str
"""
Optional URL of the identity provider's UserInfo endpoint. When configured with attribute mapping, Auth0 calls this endpoint to retrieve additional user profile claims using the access token.
"""
