# This file was auto-generated by Fern from our API Definition.

import typing

from .get_default_canonical_domain_response_content import GetDefaultCanonicalDomainResponseContent
from .get_default_custom_domain_response_content import GetDefaultCustomDomainResponseContent

GetDefaultDomainResponseContent = typing.Union[
    GetDefaultCustomDomainResponseContent, GetDefaultCanonicalDomainResponseContent
]
