# This file was auto-generated by Fern from our API Definition.

import typing

ConnectionThumbprints = typing.List[str]
"""
Array of certificate thumbprints (SHA-128/SHA-256/SHA-512 hex hashes) for validating SAML signatures. Used with WS-Federation protocol. Maximum 20 thumbprints. Each thumbprint must be a hexadecimal string.
"""
