# This file was auto-generated by Fern from our API Definition.

ConnectionRequiresUsername = bool
"""
Indicates whether the user is required to provide a username in addition to an email address.
"""
