# This file was auto-generated by Fern from our API Definition.

import typing

EventStreamCloudEventConnectionCreatedObject0OptionsAttributeMapMappingModeEnum = typing.Union[
    typing.Literal["bind_all", "use_map"], typing.Any
]
