# This file was auto-generated by Fern from our API Definition.

import typing

from .flow_action_hubspot_enroll_contact import FlowActionHubspotEnrollContact
from .flow_action_hubspot_get_contact import FlowActionHubspotGetContact
from .flow_action_hubspot_upsert_contact import FlowActionHubspotUpsertContact

FlowActionHubspot = typing.Union[
    FlowActionHubspotEnrollContact, FlowActionHubspotGetContact, FlowActionHubspotUpsertContact
]
