# This file was auto-generated by Fern from our API Definition.

import typing

GuardianFactorNameEnum = typing.Union[
    typing.Literal[
        "push-notification", "sms", "email", "duo", "otp", "webauthn-roaming", "webauthn-platform", "recovery-code"
    ],
    typing.Any,
]
