# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .user_attribute_profile_id import UserAttributeProfileId
from .user_attribute_profile_name import UserAttributeProfileName
from .user_attribute_profile_user_attributes import UserAttributeProfileUserAttributes
from .user_attribute_profile_user_id import UserAttributeProfileUserId


class GetUserAttributeProfileResponseContent(UniversalBaseModel):
    id: typing.Optional[UserAttributeProfileId] = None
    name: typing.Optional[UserAttributeProfileName] = None
    user_id: typing.Optional[UserAttributeProfileUserId] = None
    user_attributes: typing.Optional[UserAttributeProfileUserAttributes] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
