# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .phone_attribute_identifier import PhoneAttributeIdentifier
from .signup_verified import SignupVerified


class PhoneAttribute(UniversalBaseModel):
    """
    Configuration for the phone number attribute for users.
    """

    identifier: typing.Optional[PhoneAttributeIdentifier] = None
    profile_required: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Determines if property should be required for users
    """

    signup: typing.Optional[SignupVerified] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
