# This file was auto-generated by Fern from our API Definition.

import typing

from .flow_action_stripe_add_tax_id import FlowActionStripeAddTaxId
from .flow_action_stripe_create_customer import FlowActionStripeCreateCustomer
from .flow_action_stripe_create_portal_session import FlowActionStripeCreatePortalSession
from .flow_action_stripe_delete_tax_id import FlowActionStripeDeleteTaxId
from .flow_action_stripe_find_customers import FlowActionStripeFindCustomers
from .flow_action_stripe_get_customer import FlowActionStripeGetCustomer
from .flow_action_stripe_update_customer import FlowActionStripeUpdateCustomer

FlowActionStripe = typing.Union[
    FlowActionStripeAddTaxId,
    FlowActionStripeCreateCustomer,
    FlowActionStripeCreatePortalSession,
    FlowActionStripeDeleteTaxId,
    FlowActionStripeFindCustomers,
    FlowActionStripeGetCustomer,
    FlowActionStripeUpdateCustomer,
]
