# This file was auto-generated by Fern from our API Definition.

import typing

from .flow_action_activecampaign_list_contacts import FlowActionActivecampaignListContacts
from .flow_action_activecampaign_upsert_contact import FlowActionActivecampaignUpsertContact

FlowActionActivecampaign = typing.Union[FlowActionActivecampaignListContacts, FlowActionActivecampaignUpsertContact]
