# This file was auto-generated by Fern from our API Definition.

import typing

EventStreamCloudEventUserCreatedObjectIdentitiesItemDatabaseProviderEnum = typing.Union[
    typing.Literal["auth0"], typing.Any
]
