# This file was auto-generated by Fern from our API Definition.

from .connection_tenant_domain import ConnectionTenantDomain

ConnectionTenantDomainGoogleApps = ConnectionTenantDomain
"""
The Google Workspace primary domain used to identify the organization during authentication.
"""
