# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .tenant_settings_country_codes_mode_response import TenantSettingsCountryCodesModeResponse


class TenantSettingsCountryCodesResponse(UniversalBaseModel):
    """
    Phone country code configuration for identifier input.
    """

    list_: typing_extensions.Annotated[
        typing.Optional[typing.List[str]],
        FieldMetadata(alias="list"),
        pydantic.Field(alias="list", description="Array of ISO 3166-1 alpha-2 country codes."),
    ] = None
    """
    Array of ISO 3166-1 alpha-2 country codes.
    """

    mode: typing.Optional[TenantSettingsCountryCodesModeResponse] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
