# This file was auto-generated by Fern from our API Definition.

ConnectionSignSamlRequestSaml = bool
"""
When true, Auth0 signs SAML authentication requests using the connection's signing key. The signature includes the request's digest and is validated by the identity provider. Defaults to false (unsigned requests).
"""
