# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class ThirdPartyClientAccessConfig(UniversalBaseModel):
    """
    Configuration for Third Party Client Access during the Self-Service Enterprise Configuration flow.
    """

    allow_configuration: bool = pydantic.Field()
    """
    Whether third-party applications can configure the connection as a domain-level connection during the Self-Service Enterprise Configuration flow.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
