# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .connection_display_name import ConnectionDisplayName
from .connection_enabled_clients import ConnectionEnabledClients
from .connection_is_domain_connection import ConnectionIsDomainConnection
from .connections_metadata import ConnectionsMetadata


class ConnectionCommon(UniversalBaseModel):
    display_name: typing.Optional[ConnectionDisplayName] = None
    enabled_clients: typing.Optional[ConnectionEnabledClients] = None
    is_domain_connection: typing.Optional[ConnectionIsDomainConnection] = None
    metadata: typing.Optional[ConnectionsMetadata] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
