# This file was auto-generated by Fern from our API Definition.

import typing

FlowActionAuth0SendRequestParamsMethod = typing.Union[
    typing.Literal["GET", "POST", "PUT", "PATCH", "DELETE"], typing.Any
]
