# This file was auto-generated by Fern from our API Definition.

from .connection_protocol_binding_enum_saml import ConnectionProtocolBindingEnumSaml

ConnectionProtocolBindingSaml = ConnectionProtocolBindingEnumSaml
"""
SAML protocol binding mechanism for sending authentication requests to the identity provider.
"""
