# This file was auto-generated by Fern from our API Definition.

import typing

from ....types.get_job_error_response_content import GetJobErrorResponseContent
from ....types.get_job_generic_error_response_content import GetJobGenericErrorResponseContent

ErrorsGetResponse = typing.Union[typing.List[GetJobErrorResponseContent], GetJobGenericErrorResponseContent]
