# This file was auto-generated by Fern from our API Definition.

import typing

from .create_flows_vault_connection_mailchimp_api_key import CreateFlowsVaultConnectionMailchimpApiKey
from .create_flows_vault_connection_mailchimp_oauth_code import CreateFlowsVaultConnectionMailchimpOauthCode
from .create_flows_vault_connection_mailchimp_uninitialized import CreateFlowsVaultConnectionMailchimpUninitialized

CreateFlowsVaultConnectionMailchimp = typing.Union[
    CreateFlowsVaultConnectionMailchimpApiKey,
    CreateFlowsVaultConnectionMailchimpOauthCode,
    CreateFlowsVaultConnectionMailchimpUninitialized,
]
