# This file was auto-generated by Fern from our API Definition.

import typing

EventStreamCloudEventConnectionDeletedObject0OptionsConnectionSettingsPkceEnum = typing.Union[
    typing.Literal["auto", "S256", "plain", "disabled"], typing.Any
]
