# This file was auto-generated by Fern from our API Definition.

ConnectionClientSecretLine = str
"""
LINE Channel Secret issued by provider during application registration. This value is used to authenticate your Auth0 connection to the identity provider.
"""
