# This file was auto-generated by Fern from our API Definition.

ConnectionMaxGroupsToRetrieve = str
"""
Maximum number of Azure AD groups to retrieve per user during authentication. Helps prevent performance issues for users in many groups. Only applies when ext_groups is enabled. Leave empty to use platform default.
"""
