# This file was auto-generated by Fern from our API Definition.

import typing

from .log_stream_datadog_sink import LogStreamDatadogSink
from .log_stream_http_sink import LogStreamHttpSink
from .log_stream_mixpanel_sink_patch import LogStreamMixpanelSinkPatch
from .log_stream_segment_sink import LogStreamSegmentSink
from .log_stream_splunk_sink import LogStreamSplunkSink
from .log_stream_sumo_sink import LogStreamSumoSink

LogStreamSinkPatch = typing.Union[
    LogStreamHttpSink,
    LogStreamDatadogSink,
    LogStreamSplunkSink,
    LogStreamSumoSink,
    LogStreamSegmentSink,
    LogStreamMixpanelSinkPatch,
]
