# This file was auto-generated by Fern from our API Definition.

import typing

from .acul_client_filter_by_id import AculClientFilterById
from .acul_client_filter_by_metadata import AculClientFilterByMetadata

AculClientFilter = typing.Union[AculClientFilterById, AculClientFilterByMetadata]
