# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .event_stream_cloud_event_connection_created_object_3_options_assertion_decryption_settings_algorithm_profile_enum import (
    EventStreamCloudEventConnectionCreatedObject3OptionsAssertionDecryptionSettingsAlgorithmProfileEnum,
)


class EventStreamCloudEventConnectionCreatedObject3OptionsAssertionDecryptionSettings(UniversalBaseModel):
    """
    Settings for SAML assertion decryption.
    """

    algorithm_exceptions: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    A list of insecure algorithms to allow for SAML assertion decryption.
    """

    algorithm_profile: (
        EventStreamCloudEventConnectionCreatedObject3OptionsAssertionDecryptionSettingsAlgorithmProfileEnum
    )

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
