# This file was auto-generated by Fern from our API Definition.

import typing

EventStreamCloudEventConnectionCreatedObject1OptionsUpstreamParams = typing.Dict[str, typing.Any]
"""
Additional parameters to include in authorization requests sent to the identity provider. Useful for passing custom claims, selecting specific identity sources, or configuring provider-specific behavior. See https://auth0.com/docs/authenticate/identity-providers/pass-parameters-to-idps
"""
