# This file was auto-generated by Fern from our API Definition.

import typing

EventStreamCloudEventConnectionDeletedObject7OptionsIdentityApiEnum = typing.Union[
    typing.Literal["microsoft-identity-platform-v2.0", "azure-active-directory-v1.0"], typing.Any
]
