# This file was auto-generated by Fern from our API Definition.

import typing

from .acul_context_configuration_item import AculContextConfigurationItem

AculContextConfiguration = typing.Optional[typing.List[AculContextConfigurationItem]]
"""
Context values to make available
"""
