# This file was auto-generated by Fern from our API Definition.

import typing

EventStreamCloudEventUserUpdatedObjectAppMetadata = typing.Dict[str, typing.Any]
"""
User metadata to which this user has read-only access.
"""
