# This file was auto-generated by Fern from our API Definition.

from .connection_scope_array import ConnectionScopeArray

ConnectionFreeformScopesWindowsLive = ConnectionScopeArray
"""
Custom OAuth scopes not predefined in the standard scope list.
"""
