# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel, update_forward_refs
from ..core.serialization import FieldMetadata


class FlowActionFlowBooleanConditionParams(UniversalBaseModel):
    then: typing.Optional[typing.List["FlowAction"]] = None
    else_: typing_extensions.Annotated[
        typing.Optional[typing.List["FlowAction"]], FieldMetadata(alias="else"), pydantic.Field(alias="else")
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


from .flow_action import FlowAction  # noqa: E402, I001
from .flow_action_flow import FlowActionFlow  # noqa: E402, I001
from .flow_action_flow_boolean_condition import FlowActionFlowBooleanCondition  # noqa: E402, I001

update_forward_refs(
    FlowActionFlowBooleanConditionParams,
    FlowAction=FlowAction,
    FlowActionFlow=FlowActionFlow,
    FlowActionFlowBooleanCondition=FlowActionFlowBooleanCondition,
)
