# This file was auto-generated by Fern from our API Definition.

import typing

EmailSpecificProviderSettingsWithAdditionalProperties = typing.Optional[typing.Dict[str, typing.Any]]
"""
Specific provider setting
"""
