# This file was auto-generated by Fern from our API Definition.

import typing

ConnectionAllowedAudiencesGoogleOAuth2 = typing.List[str]
"""
List of allowed audiences in the ID token for Google Native Social Login
"""
