# This file was auto-generated by Fern from our API Definition.

NetworkAclActionRedirectEnum = bool
"""
Indicates the rule will redirect requests that either match or not_match specific criteria
"""
