# This file was auto-generated by Fern from our API Definition.

import typing

EmailProviderNameEnum = typing.Union[
    typing.Literal[
        "mailgun", "mandrill", "sendgrid", "resend", "ses", "sparkpost", "smtp", "azure_cs", "ms365", "custom"
    ],
    typing.Any,
]
