# This file was auto-generated by Fern from our API Definition.

import typing

from .create_flows_vault_connection_mailjet_api_key import CreateFlowsVaultConnectionMailjetApiKey
from .create_flows_vault_connection_mailjet_uninitialized import CreateFlowsVaultConnectionMailjetUninitialized

CreateFlowsVaultConnectionMailjet = typing.Union[
    CreateFlowsVaultConnectionMailjetApiKey, CreateFlowsVaultConnectionMailjetUninitialized
]
