# This file was auto-generated by Fern from our API Definition.

import typing

LogStreamPiiLogFieldsEnum = typing.Union[
    typing.Literal["first_name", "last_name", "username", "email", "phone", "address"], typing.Any
]
