# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from .refresh_token_date_object import RefreshTokenDateObject

RefreshTokenDate = typing.Union[dt.datetime, RefreshTokenDateObject]
