# This file was auto-generated by Fern from our API Definition.

import typing

from .custom_provider_credentials import CustomProviderCredentials
from .twilio_provider_credentials import TwilioProviderCredentials

PhoneProviderCredentials = typing.Union[TwilioProviderCredentials, CustomProviderCredentials]
