# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .suspicious_ip_throttling_allowlist import SuspiciousIpThrottlingAllowlist
from .suspicious_ip_throttling_shields_enum import SuspiciousIpThrottlingShieldsEnum
from .suspicious_ip_throttling_stage import SuspiciousIpThrottlingStage


class UpdateSuspiciousIpThrottlingSettingsResponseContent(UniversalBaseModel):
    enabled: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether or not suspicious IP throttling attack protections are active.
    """

    shields: typing.Optional[typing.List[SuspiciousIpThrottlingShieldsEnum]] = pydantic.Field(default=None)
    """
    Action to take when a suspicious IP throttling threshold is violated.
              Possible values: <code>block</code>, <code>admin_notification</code>.
    """

    allowlist: typing.Optional[SuspiciousIpThrottlingAllowlist] = None
    stage: typing.Optional[SuspiciousIpThrottlingStage] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
