# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .form_component_category_field_const import FormComponentCategoryFieldConst
from .form_field_tel_config import FormFieldTelConfig
from .form_field_type_tel_const import FormFieldTypeTelConst


class FormFieldTel(UniversalBaseModel):
    id: str
    category: FormComponentCategoryFieldConst
    type: FormFieldTypeTelConst
    config: typing.Optional[FormFieldTelConfig] = None
    label: typing.Optional[str] = None
    hint: typing.Optional[str] = None
    required: typing.Optional[bool] = None
    sensitive: typing.Optional[bool] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
