# This file was auto-generated by Fern from our API Definition.

import typing

from .flow_action_airtable_create_record import FlowActionAirtableCreateRecord
from .flow_action_airtable_list_records import FlowActionAirtableListRecords
from .flow_action_airtable_update_record import FlowActionAirtableUpdateRecord

FlowActionAirtable = typing.Union[
    FlowActionAirtableCreateRecord, FlowActionAirtableListRecords, FlowActionAirtableUpdateRecord
]
