# This file was auto-generated by Fern from our API Definition.

import typing

EventStreamCloudEventUserUpdatedObjectIdentitiesItemPasswordlessProviderEnum = typing.Union[
    typing.Literal["email", "sms"], typing.Any
]
