# This file was auto-generated by Fern from our API Definition.

import typing

from .create_flows_vault_connection_google_sheets_oauth_code import CreateFlowsVaultConnectionGoogleSheetsOauthCode
from .create_flows_vault_connection_google_sheets_uninitialized import (
    CreateFlowsVaultConnectionGoogleSheetsUninitialized,
)

CreateFlowsVaultConnectionGoogleSheets = typing.Union[
    CreateFlowsVaultConnectionGoogleSheetsOauthCode, CreateFlowsVaultConnectionGoogleSheetsUninitialized
]
