# This file was auto-generated by Fern from our API Definition.

import typing

from .event_stream_cloud_event_user_deleted_object_identities_item_custom import (
    EventStreamCloudEventUserDeletedObjectIdentitiesItemCustom,
)
from .event_stream_cloud_event_user_deleted_object_identities_item_database import (
    EventStreamCloudEventUserDeletedObjectIdentitiesItemDatabase,
)
from .event_stream_cloud_event_user_deleted_object_identities_item_enterprise import (
    EventStreamCloudEventUserDeletedObjectIdentitiesItemEnterprise,
)
from .event_stream_cloud_event_user_deleted_object_identities_item_passwordless import (
    EventStreamCloudEventUserDeletedObjectIdentitiesItemPasswordless,
)
from .event_stream_cloud_event_user_deleted_object_identities_item_social import (
    EventStreamCloudEventUserDeletedObjectIdentitiesItemSocial,
)

EventStreamCloudEventUserDeletedObjectIdentitiesItem = typing.Union[
    EventStreamCloudEventUserDeletedObjectIdentitiesItemCustom,
    EventStreamCloudEventUserDeletedObjectIdentitiesItemDatabase,
    EventStreamCloudEventUserDeletedObjectIdentitiesItemEnterprise,
    EventStreamCloudEventUserDeletedObjectIdentitiesItemPasswordless,
    EventStreamCloudEventUserDeletedObjectIdentitiesItemSocial,
]
