# This file was auto-generated by Fern from our API Definition.

import typing

BrandingThemeIdentifiersPhoneDisplayMaskingEnum = typing.Union[
    typing.Literal["hide_country_code", "mask_digits", "show_all"], typing.Any
]
