# This file was auto-generated by Fern from our API Definition.

import typing

EventStreamCloudEventConnectionUpdatedObject0OptionsDpopSigningAlgEnum = typing.Union[
    typing.Literal["ES256", "ES384", "ES512", "Ed25519"], typing.Any
]
