# This file was auto-generated by Fern from our API Definition.

import typing

ConnectionRequestObjectSigningAlgValuesSupported = typing.List[str]
"""
JSON array containing a list of the JWS signing algorithms (alg values) supported by the OP for Request Objects, which are described in Section 6.1 of OpenID Connect Core 1.0 [OpenID.Core]. These algorithms are used both when the Request Object is passed by value (using the request parameter) and when it is passed by reference (using the request_uri parameter). Servers SHOULD support none and RS256.
"""
