# This file was auto-generated by Fern from our API Definition.

import typing

from .event_stream_cloud_event_connection_created_object_0 import EventStreamCloudEventConnectionCreatedObject0
from .event_stream_cloud_event_connection_created_object_1 import EventStreamCloudEventConnectionCreatedObject1
from .event_stream_cloud_event_connection_created_object_2 import EventStreamCloudEventConnectionCreatedObject2
from .event_stream_cloud_event_connection_created_object_3 import EventStreamCloudEventConnectionCreatedObject3
from .event_stream_cloud_event_connection_created_object_4 import EventStreamCloudEventConnectionCreatedObject4
from .event_stream_cloud_event_connection_created_object_5 import EventStreamCloudEventConnectionCreatedObject5
from .event_stream_cloud_event_connection_created_object_6 import EventStreamCloudEventConnectionCreatedObject6
from .event_stream_cloud_event_connection_created_object_7 import EventStreamCloudEventConnectionCreatedObject7

EventStreamCloudEventConnectionCreatedObject = typing.Union[
    EventStreamCloudEventConnectionCreatedObject0,
    EventStreamCloudEventConnectionCreatedObject1,
    EventStreamCloudEventConnectionCreatedObject2,
    EventStreamCloudEventConnectionCreatedObject3,
    EventStreamCloudEventConnectionCreatedObject4,
    EventStreamCloudEventConnectionCreatedObject5,
    EventStreamCloudEventConnectionCreatedObject6,
    EventStreamCloudEventConnectionCreatedObject7,
]
