# This file was auto-generated by Fern from our API Definition.

import typing

from .credential_id import CredentialId

ClientAuthenticationMethodPrivateKeyJwtCredentials = typing.List[CredentialId]
"""
A list of unique and previously created credential IDs enabled on the client for Private Key JWT authentication.
"""
