# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .resource_server_subject_type_authorization_client import ResourceServerSubjectTypeAuthorizationClient
from .resource_server_subject_type_authorization_user import ResourceServerSubjectTypeAuthorizationUser


class ResourceServerSubjectTypeAuthorization(UniversalBaseModel):
    """
    Defines application access permission for a resource server
    """

    user: typing.Optional[ResourceServerSubjectTypeAuthorizationUser] = None
    client: typing.Optional[ResourceServerSubjectTypeAuthorizationClient] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
