# This file was auto-generated by Fern from our API Definition.

import typing

from .form_block_divider import FormBlockDivider
from .form_block_html import FormBlockHtml
from .form_block_image import FormBlockImage
from .form_block_jump_button import FormBlockJumpButton
from .form_block_next_button import FormBlockNextButton
from .form_block_previous_button import FormBlockPreviousButton
from .form_block_resend_button import FormBlockResendButton
from .form_block_rich_text import FormBlockRichText

FormBlock = typing.Union[
    FormBlockDivider,
    FormBlockHtml,
    FormBlockImage,
    FormBlockJumpButton,
    FormBlockResendButton,
    FormBlockNextButton,
    FormBlockPreviousButton,
    FormBlockRichText,
]
