# This file was auto-generated by Fern from our API Definition.

import typing

from .user_attribute_profile_user_attribute_additional_properties import (
    UserAttributeProfileUserAttributeAdditionalProperties,
)

UserAttributeProfileUserAttributes = typing.Dict[str, UserAttributeProfileUserAttributeAdditionalProperties]
"""
User attributes configuration map. Keys are attribute names, values are the mapping configuration for each attribute.
"""
