# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .flow_action_salesforce_create_lead_params_payload import FlowActionSalesforceCreateLeadParamsPayload


class FlowActionSalesforceCreateLeadParams(UniversalBaseModel):
    connection_id: str
    first_name: typing.Optional[str] = None
    last_name: str
    company: str
    email: typing.Optional[str] = None
    phone: typing.Optional[str] = None
    payload: typing.Optional[FlowActionSalesforceCreateLeadParamsPayload] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
