# This file was auto-generated by Fern from our API Definition.

ConnectionDomainOkta = str
"""
Domain of the Okta organization (e.g., dev-123456.okta.com). Should be just the domain of the okta server with no scheme or trailing backslash. Discovery runs only when connection.options.oidc_metadata is empty and a domain is provided
"""
