# This file was auto-generated by Fern from our API Definition.

ConnectionOpPolicyUri = str
"""
URL that the OpenID Provider provides to the person registering the Client to read about the OPs requirements on how the Relying Party can use the data provided by the OP. The registration process SHOULD display this URL to the person registering the Client if it is given.
"""
