# This file was auto-generated by Fern from our API Definition.

import typing

LogDetails = typing.Dict[str, typing.Any]
"""
Additional useful details about this event (structure is dependent upon event type).
"""
