# This file was auto-generated by Fern from our API Definition.

ConnectionImportMode = bool
"""
Enables lazy migration mode for importing users from an external database. When a user authenticates, their credentials are validated against the legacy store, then the user is created in Auth0 for future logins.
"""
