# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .client_my_organization_configuration_allowed_strategies_enum import (
    ClientMyOrganizationConfigurationAllowedStrategiesEnum,
)
from .client_my_organization_deletion_behavior_enum import ClientMyOrganizationDeletionBehaviorEnum


class ClientMyOrganizationPostConfiguration(UniversalBaseModel):
    """
    Configuration related to the My Organization Configuration for the client.
    """

    connection_profile_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    The connection profile ID that this client should validate against.
    """

    user_attribute_profile_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    The user attribute profile ID that this client should validate against.
    """

    allowed_strategies: typing.List[ClientMyOrganizationConfigurationAllowedStrategiesEnum] = pydantic.Field()
    """
    The allowed connection strategies for the My Organization Configuration.
    """

    connection_deletion_behavior: ClientMyOrganizationDeletionBehaviorEnum
    invitation_landing_client_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    The client ID this client uses while creating invitations through My Organization API.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
