# This file was auto-generated by Fern from our API Definition.

import typing

ConnectionShouldTrustEmailVerifiedConnectionEnum = typing.Union[
    typing.Literal["never_set_emails_as_verified", "always_set_emails_as_verified"], typing.Any
]
