# This file was auto-generated by Fern from our API Definition.

import typing

from .create_flows_vault_connection_activecampaign import CreateFlowsVaultConnectionActivecampaign
from .create_flows_vault_connection_airtable import CreateFlowsVaultConnectionAirtable
from .create_flows_vault_connection_auth_0 import CreateFlowsVaultConnectionAuth0
from .create_flows_vault_connection_bigquery import CreateFlowsVaultConnectionBigquery
from .create_flows_vault_connection_clearbit import CreateFlowsVaultConnectionClearbit
from .create_flows_vault_connection_docusign import CreateFlowsVaultConnectionDocusign
from .create_flows_vault_connection_google_sheets import CreateFlowsVaultConnectionGoogleSheets
from .create_flows_vault_connection_http import CreateFlowsVaultConnectionHttp
from .create_flows_vault_connection_hubspot import CreateFlowsVaultConnectionHubspot
from .create_flows_vault_connection_jwt import CreateFlowsVaultConnectionJwt
from .create_flows_vault_connection_mailchimp import CreateFlowsVaultConnectionMailchimp
from .create_flows_vault_connection_mailjet import CreateFlowsVaultConnectionMailjet
from .create_flows_vault_connection_pipedrive import CreateFlowsVaultConnectionPipedrive
from .create_flows_vault_connection_salesforce import CreateFlowsVaultConnectionSalesforce
from .create_flows_vault_connection_sendgrid import CreateFlowsVaultConnectionSendgrid
from .create_flows_vault_connection_slack import CreateFlowsVaultConnectionSlack
from .create_flows_vault_connection_stripe import CreateFlowsVaultConnectionStripe
from .create_flows_vault_connection_telegram import CreateFlowsVaultConnectionTelegram
from .create_flows_vault_connection_twilio import CreateFlowsVaultConnectionTwilio
from .create_flows_vault_connection_whatsapp import CreateFlowsVaultConnectionWhatsapp
from .create_flows_vault_connection_zapier import CreateFlowsVaultConnectionZapier

CreateFlowsVaultConnectionRequestContent = typing.Union[
    CreateFlowsVaultConnectionActivecampaign,
    CreateFlowsVaultConnectionAirtable,
    CreateFlowsVaultConnectionAuth0,
    CreateFlowsVaultConnectionBigquery,
    CreateFlowsVaultConnectionClearbit,
    CreateFlowsVaultConnectionDocusign,
    CreateFlowsVaultConnectionGoogleSheets,
    CreateFlowsVaultConnectionHttp,
    CreateFlowsVaultConnectionHubspot,
    CreateFlowsVaultConnectionJwt,
    CreateFlowsVaultConnectionMailchimp,
    CreateFlowsVaultConnectionMailjet,
    CreateFlowsVaultConnectionPipedrive,
    CreateFlowsVaultConnectionSalesforce,
    CreateFlowsVaultConnectionSendgrid,
    CreateFlowsVaultConnectionSlack,
    CreateFlowsVaultConnectionStripe,
    CreateFlowsVaultConnectionTelegram,
    CreateFlowsVaultConnectionTwilio,
    CreateFlowsVaultConnectionWhatsapp,
    CreateFlowsVaultConnectionZapier,
]
