# This file was auto-generated by Fern from our API Definition.

import typing

EventStreamSubscribeEventsEventTypeEnum = typing.Union[
    typing.Literal[
        "connection.created",
        "connection.deleted",
        "connection.updated",
        "group.created",
        "group.deleted",
        "group.member.added",
        "group.member.deleted",
        "group.role.assigned",
        "group.role.deleted",
        "group.updated",
        "organization.connection.added",
        "organization.connection.removed",
        "organization.connection.updated",
        "organization.created",
        "organization.deleted",
        "organization.group.role.assigned",
        "organization.group.role.deleted",
        "organization.member.added",
        "organization.member.deleted",
        "organization.member.role.assigned",
        "organization.member.role.deleted",
        "organization.updated",
        "user.created",
        "user.deleted",
        "user.updated",
    ],
    typing.Any,
]
