# This file was auto-generated by Fern from our API Definition.

ConnectionDebugSaml = bool
"""
When true, enables detailed SAML debugging by issuing 'w' (warning) events in tenant logs containing SAML request/response details. WARNING: Potentially exposes sensitive user information (PII, credentials) and should only be enabled temporarily for debugging purposes.
"""
