# This file was auto-generated by Fern from our API Definition.

import typing

ConnectionDomainAliasesAd = typing.List[str]
"""
List of domain names that can be used with identifier-first authentication flow to route users to this AD connection; each domain must be a valid DNS name up to 256 characters
"""
