# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .flow_action_flow_map_value_params_cases import FlowActionFlowMapValueParamsCases
from .flow_action_flow_map_value_params_fallback import FlowActionFlowMapValueParamsFallback
from .flow_action_flow_map_value_params_input import FlowActionFlowMapValueParamsInput


class FlowActionFlowMapValueParams(UniversalBaseModel):
    input: FlowActionFlowMapValueParamsInput
    cases: typing.Optional[FlowActionFlowMapValueParamsCases] = None
    fallback: typing.Optional[FlowActionFlowMapValueParamsFallback] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
