# This file was auto-generated by Fern from our API Definition.

import typing

from .event_stream_subscribe_events_event_type_enum import EventStreamSubscribeEventsEventTypeEnum

EventStreamSubscribeEventsEventTypeParam = typing.List[EventStreamSubscribeEventsEventTypeEnum]
"""
Event type(s) to listen for. Specify multiple times for multiple types (e.g., ?event_type=user.created&event_type=user.updated). If not provided, all event types will be streamed.
"""
