# This file was auto-generated by Fern from our API Definition.

import typing

EventStreamCloudEventConnectionCreatedObject7OptionsUseridAttributeEnum = typing.Union[
    typing.Literal["oid", "sub"], typing.Any
]
