# This file was auto-generated by Fern from our API Definition.

import typing

SetsCustomTextsByLanguageRequestContent = typing.Dict[str, typing.Any]
"""
An object containing custom dictionaries for a group of screens.
"""
