# This file was auto-generated by Fern from our API Definition.

import typing

ConnectionCertsAd = typing.List[str]
"""
Array of X.509 certificates in PEM format used for validating SAML signatures from the AD identity provider (managed by the AD Connector agent).
"""
