# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .flow_action_stripe_create_portal_session_action import FlowActionStripeCreatePortalSessionAction
from .flow_action_stripe_create_portal_session_params import FlowActionStripeCreatePortalSessionParams
from .flow_action_stripe_create_portal_session_type import FlowActionStripeCreatePortalSessionType


class FlowActionStripeCreatePortalSession(UniversalBaseModel):
    id: str
    alias: typing.Optional[str] = None
    type: FlowActionStripeCreatePortalSessionType
    action: FlowActionStripeCreatePortalSessionAction
    allow_failure: typing.Optional[bool] = None
    mask_output: typing.Optional[bool] = None
    params: FlowActionStripeCreatePortalSessionParams

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
