# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from .connection_attribute_map_okta import ConnectionAttributeMapOkta
from .connection_domain_okta import ConnectionDomainOkta
from .connection_options_common import ConnectionOptionsCommon
from .connection_options_common_oidc import ConnectionOptionsCommonOidc
from .connection_type_enum_okta import ConnectionTypeEnumOkta


class ConnectionOptionsOkta(ConnectionOptionsCommon, ConnectionOptionsCommonOidc):
    """
    Options for the 'okta' connection
    """

    attribute_map: typing.Optional[ConnectionAttributeMapOkta] = None
    domain: typing.Optional[ConnectionDomainOkta] = None
    type: typing.Optional[ConnectionTypeEnumOkta] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
