# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .log_stream_datadog_region_enum import LogStreamDatadogRegionEnum


class LogStreamDatadogSink(UniversalBaseModel):
    datadog_api_key: typing_extensions.Annotated[
        str, FieldMetadata(alias="datadogApiKey"), pydantic.Field(alias="datadogApiKey", description="Datadog API Key")
    ]
    """
    Datadog API Key
    """

    datadog_region: typing_extensions.Annotated[
        LogStreamDatadogRegionEnum, FieldMetadata(alias="datadogRegion"), pydantic.Field(alias="datadogRegion")
    ]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
