# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .email_smtp_host import EmailSmtpHost


class EmailProviderCredentialsSchemaSmtpHost(UniversalBaseModel):
    smtp_host: typing.Optional[EmailSmtpHost] = None
    smtp_port: typing.Optional[int] = pydantic.Field(default=None)
    """
    SMTP port.
    """

    smtp_user: typing.Optional[str] = pydantic.Field(default=None)
    """
    SMTP username.
    """

    smtp_pass: typing.Optional[str] = pydantic.Field(default=None)
    """
    SMTP password.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
