# This file was auto-generated by Fern from our API Definition.

import typing

from .flow_action_json_serialize_json_params_object_object import FlowActionJsonSerializeJsonParamsObjectObject

FlowActionJsonSerializeJsonParamsObject = typing.Union[str, FlowActionJsonSerializeJsonParamsObjectObject]
