# This file was auto-generated by Fern from our API Definition.

import typing

from .form_field_payment_config_charge_one_off import FormFieldPaymentConfigChargeOneOff
from .form_field_payment_config_charge_subscription import FormFieldPaymentConfigChargeSubscription

FormFieldPaymentConfigCharge = typing.Union[
    FormFieldPaymentConfigChargeOneOff, FormFieldPaymentConfigChargeSubscription
]
