# This file was auto-generated by Fern from our API Definition.

import typing

FlowActionWhatsappSendMessageParamsType = typing.Union[
    typing.Literal["AUDIO", "CONTACTS", "DOCUMENT", "IMAGE", "INTERACTIVE", "LOCATION", "STICKER", "TEMPLATE", "TEXT"],
    typing.Any,
]
