# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .flow_action_google_sheets_add_row_action import FlowActionGoogleSheetsAddRowAction
from .flow_action_google_sheets_add_row_params import FlowActionGoogleSheetsAddRowParams
from .flow_action_google_sheets_add_row_type import FlowActionGoogleSheetsAddRowType


class FlowActionGoogleSheetsAddRow(UniversalBaseModel):
    id: str
    alias: typing.Optional[str] = None
    type: FlowActionGoogleSheetsAddRowType
    action: FlowActionGoogleSheetsAddRowAction
    allow_failure: typing.Optional[bool] = None
    mask_output: typing.Optional[bool] = None
    params: FlowActionGoogleSheetsAddRowParams

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
