# This file was auto-generated by Fern from our API Definition.

import typing

ClientOidcBackchannelLogoutInitiatorsEnum = typing.Union[
    typing.Literal[
        "rp-logout",
        "idp-logout",
        "password-changed",
        "session-expired",
        "session-revoked",
        "account-deleted",
        "email-identifier-changed",
        "mfa-phone-unenrolled",
        "account-deactivated",
    ],
    typing.Any,
]
