# This file was auto-generated by Fern from our API Definition.

import typing

from .create_flows_vault_connection_zapier_uninitialized import CreateFlowsVaultConnectionZapierUninitialized
from .create_flows_vault_connection_zapier_webhook import CreateFlowsVaultConnectionZapierWebhook

CreateFlowsVaultConnectionZapier = typing.Union[
    CreateFlowsVaultConnectionZapierWebhook, CreateFlowsVaultConnectionZapierUninitialized
]
