# This file was auto-generated by Fern from our API Definition.

import typing

UserEnrollmentAuthMethodEnum = typing.Union[
    typing.Literal["authenticator", "guardian", "sms", "webauthn-platform", "webauthn-roaming"], typing.Any
]
