# This file was auto-generated by Fern from our API Definition.

import typing

CustomDomainProvisioningTypeEnum = typing.Union[typing.Literal["auth0_managed_certs", "self_managed_certs"], typing.Any]
