# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .client_oidc_backchannel_logout_initiators import ClientOidcBackchannelLogoutInitiators
from .client_oidc_backchannel_logout_session_metadata import ClientOidcBackchannelLogoutSessionMetadata


class ClientOidcBackchannelLogoutSettings(UniversalBaseModel):
    """
    Configuration for OIDC backchannel logout
    """

    backchannel_logout_urls: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Comma-separated list of URLs that are valid to call back from Auth0 for OIDC backchannel logout. Currently only one URL is allowed.
    """

    backchannel_logout_initiators: typing.Optional[ClientOidcBackchannelLogoutInitiators] = None
    backchannel_logout_session_metadata: typing.Optional[ClientOidcBackchannelLogoutSessionMetadata] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
