# This file was auto-generated by Fern from our API Definition.

import typing

from .event_stream_cloud_event_connection_updated_object_0 import EventStreamCloudEventConnectionUpdatedObject0
from .event_stream_cloud_event_connection_updated_object_1 import EventStreamCloudEventConnectionUpdatedObject1
from .event_stream_cloud_event_connection_updated_object_2 import EventStreamCloudEventConnectionUpdatedObject2
from .event_stream_cloud_event_connection_updated_object_3 import EventStreamCloudEventConnectionUpdatedObject3
from .event_stream_cloud_event_connection_updated_object_4 import EventStreamCloudEventConnectionUpdatedObject4
from .event_stream_cloud_event_connection_updated_object_5 import EventStreamCloudEventConnectionUpdatedObject5
from .event_stream_cloud_event_connection_updated_object_6 import EventStreamCloudEventConnectionUpdatedObject6
from .event_stream_cloud_event_connection_updated_object_7 import EventStreamCloudEventConnectionUpdatedObject7

EventStreamCloudEventConnectionUpdatedObject = typing.Union[
    EventStreamCloudEventConnectionUpdatedObject0,
    EventStreamCloudEventConnectionUpdatedObject1,
    EventStreamCloudEventConnectionUpdatedObject2,
    EventStreamCloudEventConnectionUpdatedObject3,
    EventStreamCloudEventConnectionUpdatedObject4,
    EventStreamCloudEventConnectionUpdatedObject5,
    EventStreamCloudEventConnectionUpdatedObject6,
    EventStreamCloudEventConnectionUpdatedObject7,
]
