# This file was auto-generated by Fern from our API Definition.

ConnectionGatewayAuthenticationMethodSms = str
"""
The Authorization header type when calling the SMS gateway. Set to 'bearer' for JWT token authentication.
"""
