# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .acul_head_tag_attributes import AculHeadTagAttributes
from .acul_head_tag_content import AculHeadTagContent


class AculHeadTag(UniversalBaseModel):
    tag: typing.Optional[str] = pydantic.Field(default=None)
    """
    Any HTML element valid for use in the head tag
    """

    attributes: typing.Optional[AculHeadTagAttributes] = None
    content: typing.Optional[AculHeadTagContent] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
