# This file was auto-generated by Fern from our API Definition.

import typing

from .event_stream_cloud_event_group_role_assigned_object_group_0 import (
    EventStreamCloudEventGroupRoleAssignedObjectGroup0,
)
from .event_stream_cloud_event_group_role_assigned_object_group_1 import (
    EventStreamCloudEventGroupRoleAssignedObjectGroup1,
)
from .event_stream_cloud_event_group_role_assigned_object_group_2 import (
    EventStreamCloudEventGroupRoleAssignedObjectGroup2,
)

EventStreamCloudEventGroupRoleAssignedObjectGroup = typing.Union[
    EventStreamCloudEventGroupRoleAssignedObjectGroup0,
    EventStreamCloudEventGroupRoleAssignedObjectGroup1,
    EventStreamCloudEventGroupRoleAssignedObjectGroup2,
]
