# This file was auto-generated by Fern from our API Definition.

import typing

from .log_stream_datadog_response_schema import LogStreamDatadogResponseSchema
from .log_stream_event_bridge_response_schema import LogStreamEventBridgeResponseSchema
from .log_stream_event_grid_response_schema import LogStreamEventGridResponseSchema
from .log_stream_http_response_schema import LogStreamHttpResponseSchema
from .log_stream_mixpanel_response_schema import LogStreamMixpanelResponseSchema
from .log_stream_segment_response_schema import LogStreamSegmentResponseSchema
from .log_stream_splunk_response_schema import LogStreamSplunkResponseSchema
from .log_stream_sumo_response_schema import LogStreamSumoResponseSchema

LogStreamResponseSchema = typing.Union[
    LogStreamHttpResponseSchema,
    LogStreamEventBridgeResponseSchema,
    LogStreamEventGridResponseSchema,
    LogStreamDatadogResponseSchema,
    LogStreamSplunkResponseSchema,
    LogStreamSumoResponseSchema,
    LogStreamSegmentResponseSchema,
    LogStreamMixpanelResponseSchema,
]
