# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .connection_non_persistent_attrs import ConnectionNonPersistentAttrs


class ConnectionOptionsCommon(UniversalBaseModel):
    """
    Common attributes for connection options including non-persistent attributes and Cross App Access
    """

    non_persistent_attrs: typing.Optional[ConnectionNonPersistentAttrs] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
