# This file was auto-generated by Fern from our API Definition.

import typing

EventStreamCloudEventOrgGroupRoleAssignedObjectGroup1TypeEnum = typing.Union[typing.Literal["organization"], typing.Any]
