# This file was auto-generated by Fern from our API Definition.

import typing

SetSelfServiceProfileCustomTextResponseContent = typing.Dict[str, str]
"""
The resulting list of custom text keys and values.
"""
