# This file was auto-generated by Fern from our API Definition.

import typing

EventStreamCloudEventConnectionUpdatedCloudEventTypeEnum = typing.Union[
    typing.Literal["connection.updated"], typing.Any
]
