# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .action_trigger import ActionTrigger


class ActionModuleAction(UniversalBaseModel):
    action_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    The unique ID of the action.
    """

    action_name: typing.Optional[str] = pydantic.Field(default=None)
    """
    The name of the action.
    """

    module_version_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    The ID of the module version this action is using.
    """

    module_version_number: typing.Optional[int] = pydantic.Field(default=None)
    """
    The version number of the module this action is using.
    """

    supported_triggers: typing.Optional[typing.List[ActionTrigger]] = pydantic.Field(default=None)
    """
    The triggers that this action supports.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
