# This file was auto-generated by Fern from our API Definition.

import typing

from .create_flows_vault_connection_airtable_api_key import CreateFlowsVaultConnectionAirtableApiKey
from .create_flows_vault_connection_airtable_uninitialized import CreateFlowsVaultConnectionAirtableUninitialized

CreateFlowsVaultConnectionAirtable = typing.Union[
    CreateFlowsVaultConnectionAirtableApiKey, CreateFlowsVaultConnectionAirtableUninitialized
]
