# This file was auto-generated by Fern from our API Definition.

import typing

BrandingThemeIdentifiersPhoneDisplayFormattingEnum = typing.Union[
    typing.Literal["international", "regional"], typing.Any
]
