# This file was auto-generated by Fern from our API Definition.

import typing

from .set_user_authentication_methods import SetUserAuthenticationMethods

SetUserAuthenticationMethodsRequestContent = typing.List[SetUserAuthenticationMethods]
