# This file was auto-generated by Fern from our API Definition.

import typing

NetworkAclRuleScopeEnum = typing.Union[
    typing.Literal["management", "authentication", "tenant", "dynamic_client_registration"], typing.Any
]
