# This file was auto-generated by Fern from our API Definition.

import typing

from .enabled_features_enum import EnabledFeaturesEnum

ConnectionProfileEnabledFeatures = typing.List[EnabledFeaturesEnum]
"""
Enabled features for the connection profile.
"""
