# This file was auto-generated by Fern from our API Definition.

ConnectionScopeOidc = str
"""
Space-separated list of OAuth 2.0 scopes requested during authorization. Must include 'openid' (required by OIDC spec). Common values: 'openid profile email'. Additional scopes depend on the identity provider.
"""
