# This file was auto-generated by Fern from our API Definition.

ConnectionTokenEndpoint = str
"""
URL of the identity provider's OAuth 2.0 token endpoint where authorization codes are exchanged for access tokens. Must be a valid HTTPS URL. Required for authorization code flow but optional for implicit flow.
"""
