# This file was auto-generated by Fern from our API Definition.

import typing

from .event_stream_cloud_event_org_group_role_assigned_object_group_0 import (
    EventStreamCloudEventOrgGroupRoleAssignedObjectGroup0,
)
from .event_stream_cloud_event_org_group_role_assigned_object_group_1 import (
    EventStreamCloudEventOrgGroupRoleAssignedObjectGroup1,
)
from .event_stream_cloud_event_org_group_role_assigned_object_group_2 import (
    EventStreamCloudEventOrgGroupRoleAssignedObjectGroup2,
)

EventStreamCloudEventOrgGroupRoleAssignedObjectGroup = typing.Union[
    EventStreamCloudEventOrgGroupRoleAssignedObjectGroup0,
    EventStreamCloudEventOrgGroupRoleAssignedObjectGroup1,
    EventStreamCloudEventOrgGroupRoleAssignedObjectGroup2,
]
