# This file was auto-generated by Fern from our API Definition.

import typing

from .create_flows_vault_connection_activecampaign_api_key import CreateFlowsVaultConnectionActivecampaignApiKey
from .create_flows_vault_connection_activecampaign_uninitialized import (
    CreateFlowsVaultConnectionActivecampaignUninitialized,
)

CreateFlowsVaultConnectionActivecampaign = typing.Union[
    CreateFlowsVaultConnectionActivecampaignApiKey, CreateFlowsVaultConnectionActivecampaignUninitialized
]
