# This file was auto-generated by Fern from our API Definition.

import typing

from .scim_token_item import ScimTokenItem

GetScimTokensResponseContent = typing.List[ScimTokenItem]
"""
The list of scim tokens for scim clients
"""
