# This file was auto-generated by Fern from our API Definition.

import typing

AttackProtectionCaptchaProviderId = typing.Union[
    typing.Literal[
        "arkose",
        "auth_challenge",
        "friendly_captcha",
        "hcaptcha",
        "recaptcha_v2",
        "recaptcha_enterprise",
        "simple_captcha",
    ],
    typing.Any,
]
