# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .acul_context_configuration import AculContextConfiguration
from .acul_filters import AculFilters
from .acul_head_tag import AculHeadTag
from .acul_rendering_mode_enum import AculRenderingModeEnum


class GetAculResponseContent(UniversalBaseModel):
    tenant: typing.Optional[str] = pydantic.Field(default=None)
    """
    Tenant ID
    """

    prompt: typing.Optional[str] = pydantic.Field(default=None)
    """
    Name of the prompt
    """

    screen: typing.Optional[str] = pydantic.Field(default=None)
    """
    Name of the screen
    """

    rendering_mode: typing.Optional[AculRenderingModeEnum] = pydantic.Field(default=None)
    """
    Rendering mode
    """

    context_configuration: typing.Optional[AculContextConfiguration] = None
    default_head_tags_disabled: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Override Universal Login default head tags
    """

    use_page_template: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Use page template with ACUL
    """

    head_tags: typing.Optional[typing.List[AculHeadTag]] = pydantic.Field(default=None)
    """
    An array of head tags
    """

    filters: typing.Optional[AculFilters] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
