# This file was auto-generated by Fern from our API Definition.

import typing

IntegrationFeatureTypeEnum = typing.Union[
    typing.Literal["unspecified", "action", "social_connection", "log_stream", "sso_integration", "sms_provider"],
    typing.Any,
]
