# This file was auto-generated by Fern from our API Definition.

ConnectionGlobalTokenRevocationJwtIssSaml = str
"""
Expected 'iss' (Issuer) claim value for JWT tokens in Global Token Revocation requests from the identity provider. When configured, Auth0 validates the JWT issuer matches this value before processing token revocation. Must be used together with global_token_revocation_jwt_sub.
"""
