# This file was auto-generated by Fern from our API Definition.

from .connection_icon_url import ConnectionIconUrl

ConnectionIconUrlAzureAd = ConnectionIconUrl
"""
URL for the connection icon displayed in Auth0 login pages. Accepts HTTPS URLs. Used for visual branding in authentication flows.
"""
