# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .event_stream_cloud_event_user_created_cloud_event import EventStreamCloudEventUserCreatedCloudEvent


class EventStreamCloudEventUserCreated(UniversalBaseModel):
    """
    SSE message for user.created.
    """

    offset: str = pydantic.Field()
    """
    Opaque cursor representing position in the stream. Pass as the `from` query parameter to resume.
    """

    event: EventStreamCloudEventUserCreatedCloudEvent

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
