# This file was auto-generated by Fern from our API Definition.

import typing

from .update_universal_login_template_request_content_template import UpdateUniversalLoginTemplateRequestContentTemplate

UpdateUniversalLoginTemplateRequestContent = typing.Union[str, UpdateUniversalLoginTemplateRequestContentTemplate]
