# This file was auto-generated by Fern from our API Definition.

from .connection_scope_array import ConnectionScopeArray

ConnectionScopeArrayWindowsLive = ConnectionScopeArray
"""
Array of custom OAuth 2.0 scopes to request during authentication.
"""
