# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class SuspiciousIpThrottlingPreUserRegistrationStage(UniversalBaseModel):
    """
    Configuration options that apply before every user registration attempt.
    """

    max_attempts: typing.Optional[int] = pydantic.Field(default=None)
    """
    Total number of attempts allowed.
    """

    rate: typing.Optional[int] = pydantic.Field(default=None)
    """
    Interval of time, given in milliseconds, at which new attempts are granted.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
