# This file was auto-generated by Fern from our API Definition.

import typing

EventStreamCloudEventConnectionCreatedObject3OptionsSetUserRootAttributesEnum = typing.Union[
    typing.Literal["on_each_login", "on_first_login", "never_on_login"], typing.Any
]
