# This file was auto-generated by Fern from our API Definition.

from .connection_options_idp_initiated_client_protocol_enum_saml import (
    ConnectionOptionsIdpInitiatedClientProtocolEnumSaml,
)

ConnectionClientProtocolSaml = ConnectionOptionsIdpInitiatedClientProtocolEnumSaml
"""
The response protocol used to communicate with the default application.
"""
