# This file was auto-generated by Fern from our API Definition.

import typing

CreatedUserAuthenticationMethodTypeEnum = typing.Union[
    typing.Literal["phone", "email", "totp", "webauthn-roaming", "passkey"], typing.Any
]
