# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .connection_password_options_complexity import ConnectionPasswordOptionsComplexity
from .connection_password_options_dictionary import ConnectionPasswordOptionsDictionary
from .connection_password_options_history import ConnectionPasswordOptionsHistory
from .connection_password_options_profile_data import ConnectionPasswordOptionsProfileData


class ConnectionPasswordOptions(UniversalBaseModel):
    """
    Password policy options for flexible password policy configuration
    """

    complexity: typing.Optional[ConnectionPasswordOptionsComplexity] = None
    dictionary: typing.Optional[ConnectionPasswordOptionsDictionary] = None
    history: typing.Optional[ConnectionPasswordOptionsHistory] = None
    profile_data: typing.Optional[ConnectionPasswordOptionsProfileData] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
