# This file was auto-generated by Fern from our API Definition.

from .connection_https_url_with_http_fallback_255 import ConnectionHttpsUrlWithHttpFallback255

ConnectionRecipientUrlSaml = ConnectionHttpsUrlWithHttpFallback255
"""
The URL where Auth0 will send SAML authentication requests (the Identity Provider's SSO URL). Must be a valid HTTPS URL.
"""
