# This file was auto-generated by Fern from our API Definition.

from .connection_metadata_xml import ConnectionMetadataXml

ConnectionMetadataXmlAdfs = ConnectionMetadataXml
"""
Inline XML alternative to 'adfs_server'. Cannot be set together with 'adfs_server'.
"""
