# This file was auto-generated by Fern from our API Definition.

import typing

ResourceServerTokenDialectResponseEnum = typing.Union[
    typing.Literal["access_token", "access_token_authz", "rfc9068_profile", "rfc9068_profile_authz"], typing.Any
]
