# This file was auto-generated by Fern from our API Definition.

import typing

ClientOrganizationRequireBehaviorEnum = typing.Union[
    typing.Literal["no_prompt", "pre_login_prompt", "post_login_prompt"], typing.Any
]
