# This file was auto-generated by Fern from our API Definition.

import typing

ClientTokenExchangeTypeEnum = typing.Union[
    typing.Literal["custom_authentication", "on_behalf_of_token_exchange"], typing.Any
]
