# This file was auto-generated by Fern from our API Definition.

import typing

from .flow_action_pipedrive_add_deal import FlowActionPipedriveAddDeal
from .flow_action_pipedrive_add_organization import FlowActionPipedriveAddOrganization
from .flow_action_pipedrive_add_person import FlowActionPipedriveAddPerson

FlowActionPipedrive = typing.Union[
    FlowActionPipedriveAddDeal, FlowActionPipedriveAddOrganization, FlowActionPipedriveAddPerson
]
