# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class MdlPresentationProperties(UniversalBaseModel):
    family_name: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Family Name
    """

    given_name: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Given Name
    """

    birth_date: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Birth Date
    """

    issue_date: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Issue Date
    """

    expiry_date: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Expiry Date
    """

    issuing_country: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Issuing Country
    """

    issuing_authority: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Issuing Authority
    """

    portrait: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Portrait
    """

    driving_privileges: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Driving Privileges
    """

    resident_address: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Resident Address
    """

    portrait_capture_date: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Portrait Capture Date
    """

    age_in_years: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Age in Years
    """

    age_birth_year: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Age Birth Year
    """

    issuing_jurisdiction: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Issuing Jurisdiction
    """

    nationality: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Nationality
    """

    resident_city: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Resident City
    """

    resident_state: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Resident State
    """

    resident_postal_code: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Resident Postal Code
    """

    resident_country: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Resident Country
    """

    family_name_national_character: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Family Name National Character
    """

    given_name_national_character: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Given Name National Character
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
