# This file was auto-generated by Fern from our API Definition.

from .connection_disable_signup import ConnectionDisableSignup

ConnectionDisableSignupSms = ConnectionDisableSignup
"""
Controls whether new user signups are allowed via SMS authentication
"""
