# This file was auto-generated by Fern from our API Definition.

import typing

EventStreamCloudEventOrgConnectionAddedTypeEnum = typing.Union[
    typing.Literal["organization.connection.added"], typing.Any
]
