# This file was auto-generated by Fern from our API Definition.

import typing

ResourceServerTokenEncryptionAlgorithmEnum = typing.Union[
    typing.Literal["RSA-OAEP-256", "RSA-OAEP-384", "RSA-OAEP-512"], typing.Any
]
