# This file was auto-generated by Fern from our API Definition.

import typing

from .acul_organization_filter_by_id import AculOrganizationFilterById
from .acul_organization_filter_by_metadata import AculOrganizationFilterByMetadata

AculOrganizationFilter = typing.Union[AculOrganizationFilterById, AculOrganizationFilterByMetadata]
