# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .email_attribute import EmailAttribute
from .phone_attribute import PhoneAttribute
from .username_attribute import UsernameAttribute


class ConnectionAttributes(UniversalBaseModel):
    """
    Attribute configuration
    """

    email: typing.Optional[EmailAttribute] = None
    phone_number: typing.Optional[PhoneAttribute] = None
    username: typing.Optional[UsernameAttribute] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
