# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .event_stream_cloud_event_group_role_assigned_object_group import EventStreamCloudEventGroupRoleAssignedObjectGroup
from .event_stream_cloud_event_group_role_assigned_object_role import EventStreamCloudEventGroupRoleAssignedObjectRole


class EventStreamCloudEventGroupRoleAssignedObject(UniversalBaseModel):
    """
    The event content.
    """

    group: EventStreamCloudEventGroupRoleAssignedObjectGroup
    role: EventStreamCloudEventGroupRoleAssignedObjectRole
    created_at: dt.datetime = pydantic.Field()
    """
    The time at which the role was assigned to the group.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
