# This file was auto-generated by Fern from our API Definition.

from .connection_totp_length_passwordless import ConnectionTotpLengthPasswordless

ConnectionTotpLengthSms = ConnectionTotpLengthPasswordless
"""
Number of digits in the verification code
"""
