# This file was auto-generated by Fern from our API Definition.

import typing

ConnectionSubjectTypesSupported = typing.List[str]
"""
A list of the Subject Identifier types that this OP supports. Valid types include pairwise and public
"""
