# This file was auto-generated by Fern from our API Definition.

import typing

EventStreamCloudEventGroupMemberAddedCloudEventTypeEnum = typing.Union[typing.Literal["group.member.added"], typing.Any]
