# This file was auto-generated by Fern from our API Definition.

import typing

ClientJwtConfigurationScopes = typing.Dict[str, typing.Any]
"""
Configuration related to id token claims for the client.
"""
