# This file was auto-generated by Fern from our API Definition.

import typing

ClientComplianceLevelEnum = typing.Union[
    typing.Literal["none", "fapi1_adv_pkj_par", "fapi1_adv_mtls_par", "fapi2_sp_pkj_mtls", "fapi2_sp_mtls_mtls"],
    typing.Any,
]
