# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .organization_member_role import OrganizationMemberRole


class OrganizationMember(UniversalBaseModel):
    user_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    ID of this user.
    """

    picture: typing.Optional[str] = pydantic.Field(default=None)
    """
    URL to a picture for this user.
    """

    name: typing.Optional[str] = pydantic.Field(default=None)
    """
    Name of this user.
    """

    email: typing.Optional[str] = pydantic.Field(default=None)
    """
    Email address of this user.
    """

    roles: typing.Optional[typing.List[OrganizationMemberRole]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
