# This file was auto-generated by Fern from our API Definition.

ConnectionUseCommonEndpointAzureAd = bool
"""
When enabled (true), uses the Azure AD common endpoint for multi-tenant authentication. Allows users from any Azure AD organization to sign in. Requires userid_attribute set to 'sub' (not 'oid'). Cannot be used with SCIM provisioning. Defaults to false.
"""
