# This file was auto-generated by Fern from our API Definition.

import typing

from .flow_action_whatsapp_send_message_params_payload_object import FlowActionWhatsappSendMessageParamsPayloadObject

FlowActionWhatsappSendMessageParamsPayload = typing.Union[FlowActionWhatsappSendMessageParamsPayloadObject, str]
