# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel, update_forward_refs
from .flow_action_flow_boolean_condition_action import FlowActionFlowBooleanConditionAction
from .flow_action_flow_boolean_condition_type import FlowActionFlowBooleanConditionType


class FlowActionFlowBooleanCondition(UniversalBaseModel):
    id: str
    alias: typing.Optional[str] = None
    type: FlowActionFlowBooleanConditionType
    action: FlowActionFlowBooleanConditionAction
    allow_failure: typing.Optional[bool] = None
    mask_output: typing.Optional[bool] = None
    params: "FlowActionFlowBooleanConditionParams"

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


from .flow_action import FlowAction  # noqa: E402, I001
from .flow_action_flow import FlowActionFlow  # noqa: E402, I001
from .flow_action_flow_boolean_condition_params import FlowActionFlowBooleanConditionParams  # noqa: E402, I001

update_forward_refs(
    FlowActionFlowBooleanCondition,
    FlowAction=FlowAction,
    FlowActionFlow=FlowActionFlow,
    FlowActionFlowBooleanConditionParams=FlowActionFlowBooleanConditionParams,
)
