# This file was auto-generated by Fern from our API Definition.

import typing

EventStreamCloudEventConnectionCreatedObject2OptionsDigestAlgorithmEnum = typing.Union[
    typing.Literal["sha1", "sha256"], typing.Any
]
