# This file was auto-generated by Fern from our API Definition.

import typing

from .create_flows_vault_connection_telegram_token import CreateFlowsVaultConnectionTelegramToken
from .create_flows_vault_connection_telegram_uninitialized import CreateFlowsVaultConnectionTelegramUninitialized

CreateFlowsVaultConnectionTelegram = typing.Union[
    CreateFlowsVaultConnectionTelegramToken, CreateFlowsVaultConnectionTelegramUninitialized
]
