# This file was auto-generated by Fern from our API Definition.

from .connection_provider_enum_sms import ConnectionProviderEnumSms

ConnectionProviderSms = ConnectionProviderEnumSms
"""
SMS provider. Set to 'sms_gateway' to use a custom SMS gateway instead of Twilio.
"""
