# This file was auto-generated by Fern from our API Definition.

from .flow_action_mailchimp_upsert_member import FlowActionMailchimpUpsertMember

FlowActionMailchimp = FlowActionMailchimpUpsertMember
