# This file was auto-generated by Fern from our API Definition.

import typing

from .create_flows_vault_connection_slack_oauth_code import CreateFlowsVaultConnectionSlackOauthCode
from .create_flows_vault_connection_slack_uninitialized import CreateFlowsVaultConnectionSlackUninitialized
from .create_flows_vault_connection_slack_webhook import CreateFlowsVaultConnectionSlackWebhook

CreateFlowsVaultConnectionSlack = typing.Union[
    CreateFlowsVaultConnectionSlackWebhook,
    CreateFlowsVaultConnectionSlackOauthCode,
    CreateFlowsVaultConnectionSlackUninitialized,
]
