# This file was auto-generated by Fern from our API Definition.

import typing

HookTriggerIdEnum = typing.Union[
    typing.Literal[
        "credentials-exchange",
        "pre-user-registration",
        "post-user-registration",
        "post-change-password",
        "send-phone-message",
    ],
    typing.Any,
]
