# This file was auto-generated by Fern from our API Definition.

import typing

ConnectionFieldsMap = typing.Dict[str, str]
"""
Mapping of user profile fields returned from the OAuth2 provider to Auth0 user attributes
"""
