# This file was auto-generated by Fern from our API Definition.

import typing

from .form_flow import FormFlow
from .form_router import FormRouter
from .form_step import FormStep

FormNode = typing.Union[FormFlow, FormRouter, FormStep]
