# This file was auto-generated by Fern from our API Definition.

import typing

from .acul_domain_filter_by_id import AculDomainFilterById
from .acul_domain_filter_by_metadata import AculDomainFilterByMetadata

AculDomainFilter = typing.Union[AculDomainFilterById, AculDomainFilterByMetadata]
