# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class LogStreamSplunkSink(UniversalBaseModel):
    splunk_domain: typing_extensions.Annotated[
        str,
        FieldMetadata(alias="splunkDomain"),
        pydantic.Field(alias="splunkDomain", description="Splunk URL Endpoint"),
    ]
    """
    Splunk URL Endpoint
    """

    splunk_port: typing_extensions.Annotated[
        str, FieldMetadata(alias="splunkPort"), pydantic.Field(alias="splunkPort", description="Port")
    ]
    """
    Port
    """

    splunk_token: typing_extensions.Annotated[
        str, FieldMetadata(alias="splunkToken"), pydantic.Field(alias="splunkToken", description="Splunk token")
    ]
    """
    Splunk token
    """

    splunk_secure: typing_extensions.Annotated[
        bool,
        FieldMetadata(alias="splunkSecure"),
        pydantic.Field(alias="splunkSecure", description="Verify TLS certificate"),
    ]
    """
    Verify TLS certificate
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
