# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from .connection_options_dropbox import ConnectionOptionsDropbox
from .create_connection_common import CreateConnectionCommon
from .create_connection_request_content_dropbox_strategy import CreateConnectionRequestContentDropboxStrategy


class CreateConnectionRequestContentDropbox(CreateConnectionCommon):
    """
    Create a connection with strategy=dropbox
    """

    strategy: CreateConnectionRequestContentDropboxStrategy
    options: typing.Optional[ConnectionOptionsDropbox] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
