# This file was auto-generated by Fern from our API Definition.

from .connection_ext_agreed_terms import ConnectionExtAgreedTerms

ConnectionExtAgreedTermsGoogleApps = ConnectionExtAgreedTerms
"""
Fetches the `agreedToTerms` flag from the Google Directory profile.
"""
