# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from .connection_options_box import ConnectionOptionsBox
from .connection_purposes import ConnectionPurposes
from .connection_response_common import ConnectionResponseCommon
from .connection_response_content_box_strategy import ConnectionResponseContentBoxStrategy


class ConnectionResponseContentBox(ConnectionPurposes, ConnectionResponseCommon):
    """
    Response for connections with strategy=box
    """

    strategy: ConnectionResponseContentBoxStrategy
    options: typing.Optional[ConnectionOptionsBox] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
