# This file was auto-generated by Fern from our API Definition.

import typing

from .enabled_features_enum import EnabledFeaturesEnum

ConnectionProfileStrategyOverridesEnabledFeatures = typing.List[EnabledFeaturesEnum]
"""
Enabled features for a connections profile strategy override.
"""
