# This file was auto-generated by Fern from our API Definition.

ConnectionRequestUriParameterSupported = bool
"""
Boolean value specifying whether the OP supports use of the request_uri parameter, with true indicating support. If omitted, the default value is false.
"""
