# This file was auto-generated by Fern from our API Definition.

ConnectionEndSessionEndpoint = str
"""
URL of the identity provider's logout/end session endpoint. When configured as a static URL, users are redirected here after logging out from Auth0. Must use HTTPS scheme.
"""
