# This file was auto-generated by Fern from our API Definition.

ConnectionClientSecretAzureAd = str
"""
The client secret (application password) from your Azure AD app registration. Used to authenticate your application when exchanging authorization codes for tokens.
"""
