# This file was auto-generated by Fern from our API Definition.

ConnectionIdTokenSessionExpirySupported = bool
"""
Indicates whether the identity provider supports session expiry via the id_token. If true, the system will use the session_expiry claim in the id_token to determine session expiry.
"""
