# This file was auto-generated by Fern from our API Definition.

import typing

from .connection_domain_aliases_items_one import ConnectionDomainAliasesItemsOne

ConnectionDomainAliasesSaml = typing.List[ConnectionDomainAliasesItemsOne]
"""
Domain aliases for the connection
"""
