# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .form_ending_node import FormEndingNode
from .form_languages import FormLanguages
from .form_messages import FormMessages
from .form_node_list import FormNodeList
from .form_start_node import FormStartNode
from .form_style import FormStyle
from .form_translations import FormTranslations


class CreateFormResponseContent(UniversalBaseModel):
    id: str
    name: str
    messages: typing.Optional[FormMessages] = None
    languages: typing.Optional[FormLanguages] = None
    translations: typing.Optional[FormTranslations] = None
    nodes: typing.Optional[FormNodeList] = None
    start: typing.Optional[FormStartNode] = None
    ending: typing.Optional[FormEndingNode] = None
    style: typing.Optional[FormStyle] = None
    created_at: dt.datetime
    updated_at: dt.datetime
    embedded_at: typing.Optional[str] = None
    submitted_at: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
