# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .encryption_key import EncryptionKey


class ListEncryptionKeyOffsetPaginatedResponseContent(UniversalBaseModel):
    start: typing.Optional[int] = pydantic.Field(default=None)
    """
    Page index of the results to return. First page is 0.
    """

    limit: typing.Optional[int] = pydantic.Field(default=None)
    """
    Number of results per page.
    """

    total: typing.Optional[int] = pydantic.Field(default=None)
    """
    Total amount of encryption keys.
    """

    keys: typing.Optional[typing.List[EncryptionKey]] = pydantic.Field(default=None)
    """
    Encryption keys.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
