# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .universal_login_experience_enum import UniversalLoginExperienceEnum


class UpdateSettingsResponseContent(UniversalBaseModel):
    universal_login_experience: typing.Optional[UniversalLoginExperienceEnum] = None
    identifier_first: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether identifier first is enabled or not
    """

    webauthn_platform_first_factor: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Use WebAuthn with Device Biometrics as the first authentication factor
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
