# This file was auto-generated by Fern from our API Definition.

from .connection_scope_array import ConnectionScopeArray

ConnectionScopeSalesforce = ConnectionScopeArray
"""
OAuth scopes to request from Salesforce. This is computed from enabled permission options and any additional freeform scopes.
"""
