# This file was auto-generated by Fern from our API Definition.

ConnectionName = str
"""
The name of the connection. Must start and end with an alphanumeric character and can only contain alphanumeric characters and '-'. Max length 128
"""
