# This file was auto-generated by Fern from our API Definition.

import typing

from .create_flows_vault_connection_sendgrid_api_key import CreateFlowsVaultConnectionSendgridApiKey
from .create_flows_vault_connection_sendgrid_uninitialized import CreateFlowsVaultConnectionSendgridUninitialized

CreateFlowsVaultConnectionSendgrid = typing.Union[
    CreateFlowsVaultConnectionSendgridApiKey, CreateFlowsVaultConnectionSendgridUninitialized
]
