# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .action_execution_result import ActionExecutionResult
from .action_execution_status_enum import ActionExecutionStatusEnum
from .action_trigger_type_enum import ActionTriggerTypeEnum


class GetActionExecutionResponseContent(UniversalBaseModel):
    """
    The result of a specific execution of a trigger.
    """

    id: typing.Optional[str] = pydantic.Field(default=None)
    """
    ID identifies this specific execution simulation. These IDs would resemble real executions in production.
    """

    trigger_id: typing.Optional[ActionTriggerTypeEnum] = None
    status: typing.Optional[ActionExecutionStatusEnum] = None
    results: typing.Optional[typing.List[ActionExecutionResult]] = None
    created_at: typing.Optional[dt.datetime] = pydantic.Field(default=None)
    """
    The time that the execution was started.
    """

    updated_at: typing.Optional[dt.datetime] = pydantic.Field(default=None)
    """
    The time that the exeution finished executing.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
