# This file was auto-generated by Fern from our API Definition.

import typing

from .flow_action_flow_map_value_params_fallback_object import FlowActionFlowMapValueParamsFallbackObject

FlowActionFlowMapValueParamsFallback = typing.Union[
    str, float, FlowActionFlowMapValueParamsFallbackObject, typing.List[typing.Any]
]
