# This file was auto-generated by Fern from our API Definition.

import typing

PromptGroupNameEnum = typing.Union[
    typing.Literal[
        "login",
        "login-id",
        "login-password",
        "login-passwordless",
        "login-email-verification",
        "signup",
        "signup-id",
        "signup-password",
        "phone-identifier-enrollment",
        "phone-identifier-challenge",
        "email-identifier-challenge",
        "reset-password",
        "custom-form",
        "consent",
        "customized-consent",
        "logout",
        "mfa-push",
        "mfa-otp",
        "mfa-voice",
        "mfa-phone",
        "mfa-webauthn",
        "mfa-sms",
        "mfa-email",
        "mfa-recovery-code",
        "mfa",
        "status",
        "device-flow",
        "email-verification",
        "email-otp-challenge",
        "organizations",
        "invitation",
        "common",
        "passkeys",
        "captcha",
        "brute-force-protection",
        "async-approval-flow",
        "confirmation",
    ],
    typing.Any,
]
