# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .create_export_users_fields import CreateExportUsersFields
from .job_file_format_enum import JobFileFormatEnum


class CreateExportUsersResponseContent(UniversalBaseModel):
    status: str = pydantic.Field()
    """
    Status of this job.
    """

    type: str = pydantic.Field()
    """
    Type of job this is.
    """

    created_at: typing.Optional[str] = pydantic.Field(default=None)
    """
    When this job was created.
    """

    id: str = pydantic.Field()
    """
    ID of this job.
    """

    connection_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    connection_id of the connection from which users will be exported.
    """

    format: typing.Optional[JobFileFormatEnum] = None
    limit: typing.Optional[int] = pydantic.Field(default=None)
    """
    Limit the number of records.
    """

    fields: typing.Optional[typing.List[CreateExportUsersFields]] = pydantic.Field(default=None)
    """
    List of fields to be included in the CSV. Defaults to a predefined set of fields.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
