# This file was auto-generated by Fern from our API Definition.

import typing

from .public_key_credential import PublicKeyCredential

ClientCreateAuthenticationMethodPrivateKeyJwtCredentials = typing.List[PublicKeyCredential]
"""
Fully defined credentials that will be enabled on the client for Private Key JWT authentication.
"""
