# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .breached_password_detection_pre_user_registration_shields_enum import (
    BreachedPasswordDetectionPreUserRegistrationShieldsEnum,
)


class BreachedPasswordDetectionPreUserRegistrationStage(UniversalBaseModel):
    shields: typing.Optional[typing.List[BreachedPasswordDetectionPreUserRegistrationShieldsEnum]] = pydantic.Field(
        default=None
    )
    """
    Action to take when a breached password is detected during a signup.
                  Possible values: <code>block</code>, <code>admin_notification</code>.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
