# This file was auto-generated by Fern from our API Definition.

ConnectionRegistrationEndpoint = str
"""
URL of the OPs Dynamic Client Registration Endpoint. RECOMMENDED but not REQUIRED. https://openid.net/specs/openid-connect-discovery-1_0.html#OpenID.Registration
"""
