# This file was auto-generated by Fern from our API Definition.

import typing

from .self_service_profile_branding_properties import SelfServiceProfileBrandingProperties

SelfServiceProfileBranding = typing.Optional[SelfServiceProfileBrandingProperties]
