# This file was auto-generated by Fern from our API Definition.

import typing

FormFieldPaymentConfigChargeOneOffCurrencyEnum = typing.Union[
    typing.Literal["AUD", "CAD", "CHF", "EUR", "GBP", "INR", "MXN", "SEK", "USD"], typing.Any
]
