# This file was auto-generated by Fern from our API Definition.

import typing

EventStreamCloudEventGroupMemberAddedObjectMember1MemberTypeEnum = typing.Union[
    typing.Literal["connection"], typing.Any
]
