# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .action import Action


class ListActionsPaginatedResponseContent(UniversalBaseModel):
    total: typing.Optional[float] = pydantic.Field(default=None)
    """
    The total result count.
    """

    page: typing.Optional[float] = pydantic.Field(default=None)
    """
    Page index of the results being returned. First page is 0.
    """

    per_page: typing.Optional[float] = pydantic.Field(default=None)
    """
    Number of results per page.
    """

    actions: typing.Optional[typing.List[Action]] = pydantic.Field(default=None)
    """
    The list of actions.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
