# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class CimdValidationResult(UniversalBaseModel):
    """
    Validation result for the Client ID Metadata Document
    """

    valid: bool = pydantic.Field()
    """
    Whether the metadata document passed validation
    """

    violations: typing.List[str] = pydantic.Field()
    """
    Array of validation violation messages (if any)
    """

    warnings: typing.List[str] = pydantic.Field()
    """
    Array of warning messages (if any)
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
