# This file was auto-generated by Fern from our API Definition.

import typing

from .delete_user_identity_response_content_item import DeleteUserIdentityResponseContentItem

DeleteUserIdentityResponseContent = typing.List[DeleteUserIdentityResponseContentItem]
"""
An array of objects with information about the user's identities.
"""
