# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .synchronized_group_payload import SynchronizedGroupPayload


class ListSynchronizedGroupsResponseContent(UniversalBaseModel):
    groups: typing.List[SynchronizedGroupPayload] = pydantic.Field()
    """
    Array of Google Workspace group ids configured for synchronization.
    """

    next: typing.Optional[str] = pydantic.Field(default=None)
    """
    The cursor to be used as the "from" query parameter for the next page of results.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
