# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .email_mailgun_region_enum import EmailMailgunRegionEnum


class EmailProviderCredentialsSchemaApiKey(UniversalBaseModel):
    api_key: typing.Optional[str] = pydantic.Field(default=None)
    """
    API Key
    """

    domain: typing.Optional[str] = pydantic.Field(default=None)
    """
    Domain
    """

    region: typing.Optional[EmailMailgunRegionEnum] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
