# This file was auto-generated by Fern from our API Definition.

ConnectionTenantIdAzureAd = str
"""
The Azure AD tenant ID as a UUID. The unique identifier for your Azure AD organization. Must be a valid 36-character UUID.
"""
