# This file was auto-generated by Fern from our API Definition.

import typing

from .create_flows_vault_connection_auth_0_oauth_app import CreateFlowsVaultConnectionAuth0OauthApp
from .create_flows_vault_connection_auth_0_uninitialized import CreateFlowsVaultConnectionAuth0Uninitialized

CreateFlowsVaultConnectionAuth0 = typing.Union[
    CreateFlowsVaultConnectionAuth0OauthApp, CreateFlowsVaultConnectionAuth0Uninitialized
]
