# This file was auto-generated by Fern from our API Definition.

import typing

EventStreamCloudEventOrgDeletedObjectMetadata = typing.Dict[str, typing.Any]
"""
The metadata associated with the organization.
"""
