# This file was auto-generated by Fern from our API Definition.

import typing

EventStreamCloudEventConnectionUpdatedObject1OptionsTokenEndpointJwtcaAudFormatEnum = typing.Union[
    typing.Literal["issuer", "token_endpoint"], typing.Any
]
