# This file was auto-generated by Fern from our API Definition.

import typing

from .create_flows_vault_connection_pipedrive_oauth_code import CreateFlowsVaultConnectionPipedriveOauthCode
from .create_flows_vault_connection_pipedrive_token import CreateFlowsVaultConnectionPipedriveToken
from .create_flows_vault_connection_pipedrive_uninitialized import CreateFlowsVaultConnectionPipedriveUninitialized

CreateFlowsVaultConnectionPipedrive = typing.Union[
    CreateFlowsVaultConnectionPipedriveToken,
    CreateFlowsVaultConnectionPipedriveOauthCode,
    CreateFlowsVaultConnectionPipedriveUninitialized,
]
