# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .cimd_mapped_client_fields import CimdMappedClientFields
from .cimd_validation_result import CimdValidationResult


class RegisterCimdClientResponseContent(UniversalBaseModel):
    """
    Response after successfully registering or updating a CIMD client
    """

    client_id: str = pydantic.Field()
    """
    The Auth0 client_id of the created or updated client
    """

    mapped_fields: CimdMappedClientFields
    validation: CimdValidationResult

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
