# This file was auto-generated by Fern from our API Definition.

import typing

from .flow_action_otp_generate_code import FlowActionOtpGenerateCode
from .flow_action_otp_verify_code import FlowActionOtpVerifyCode

FlowActionOtp = typing.Union[FlowActionOtpGenerateCode, FlowActionOtpVerifyCode]
