# This file was auto-generated by Fern from our API Definition.

from .connection_scope_array import ConnectionScopeArray

ConnectionFreeformScopesPaypal = ConnectionScopeArray
"""
Additional OAuth scopes to request from PayPal beyond the standard attribute scopes. Enter valid PayPal scopes from their documentation. Invalid scopes may cause authentication errors.
"""
