# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .cimd_mapped_client_authentication_methods_private_key_jwt import (
    CimdMappedClientAuthenticationMethodsPrivateKeyJwt,
)


class CimdMappedClientAuthenticationMethods(UniversalBaseModel):
    """
    Client authentication methods derived from the JWKS document
    """

    private_key_jwt: typing.Optional[CimdMappedClientAuthenticationMethodsPrivateKeyJwt] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
