# This file was auto-generated by Fern from our API Definition.

ConnectionIssuer = str
"""
The identity provider's unique issuer identifier URL (e.g., https://accounts.google.com). Must match the 'iss' claim in ID tokens from the identity provider.
"""
