# This file was auto-generated by Fern from our API Definition.

from .connection_ext_admin import ConnectionExtAdmin

ConnectionExtIsAdminGoogleApps = ConnectionExtAdmin
"""
Fetches the Google Directory admin flag for the signing-in user.
"""
