# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class ConnectionPasswordOptionsProfileData(UniversalBaseModel):
    """
    Personal information restriction policy to prevent use of profile data in passwords
    """

    active: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Prevents users from including profile data (like name, email) in their passwords
    """

    blocked_fields: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Blocked profile fields. An array of up to 12 entries.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
