# This file was auto-generated by Fern from our API Definition.

import typing

EventStreamCloudEventConnectionDeletedObject0OptionsTypeEnum = typing.Union[
    typing.Literal["back_channel", "front_channel"], typing.Any
]
