# This file was auto-generated by Fern from our API Definition.

import typing

CspDirectives = typing.Dict[str, typing.List[str]]
"""
CSP directives map. Keys are directive names, values are arrays of directive values.
"""
