# This file was auto-generated by Fern from our API Definition.

import typing

from .create_flows_vault_connection_clearbit_api_key import CreateFlowsVaultConnectionClearbitApiKey
from .create_flows_vault_connection_clearbit_uninitialized import CreateFlowsVaultConnectionClearbitUninitialized

CreateFlowsVaultConnectionClearbit = typing.Union[
    CreateFlowsVaultConnectionClearbitApiKey, CreateFlowsVaultConnectionClearbitUninitialized
]
