# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class GetJobSummary(UniversalBaseModel):
    """
    Job execution summary.
    """

    failed: typing.Optional[int] = pydantic.Field(default=None)
    """
    Number of failed operations.
    """

    updated: typing.Optional[int] = pydantic.Field(default=None)
    """
    Number of updated records.
    """

    inserted: typing.Optional[int] = pydantic.Field(default=None)
    """
    Number of inserted records.
    """

    total: typing.Optional[int] = pydantic.Field(default=None)
    """
    Total number of operations.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
