# This file was auto-generated by Fern from our API Definition.

import typing

from .event_stream_cloud_event_org_group_role_deleted_object_group_0 import (
    EventStreamCloudEventOrgGroupRoleDeletedObjectGroup0,
)
from .event_stream_cloud_event_org_group_role_deleted_object_group_1 import (
    EventStreamCloudEventOrgGroupRoleDeletedObjectGroup1,
)
from .event_stream_cloud_event_org_group_role_deleted_object_group_2 import (
    EventStreamCloudEventOrgGroupRoleDeletedObjectGroup2,
)

EventStreamCloudEventOrgGroupRoleDeletedObjectGroup = typing.Union[
    EventStreamCloudEventOrgGroupRoleDeletedObjectGroup0,
    EventStreamCloudEventOrgGroupRoleDeletedObjectGroup1,
    EventStreamCloudEventOrgGroupRoleDeletedObjectGroup2,
]
