# This file was auto-generated by Fern from our API Definition.

import typing

from .update_enabled_client_connections_request_content_item import UpdateEnabledClientConnectionsRequestContentItem

UpdateEnabledClientConnectionsRequestContent = typing.List[UpdateEnabledClientConnectionsRequestContentItem]
