# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class FlowActionStripeAddress(UniversalBaseModel):
    line_1: typing_extensions.Annotated[
        typing.Optional[str], FieldMetadata(alias="line1"), pydantic.Field(alias="line1")
    ] = None
    line_2: typing_extensions.Annotated[
        typing.Optional[str], FieldMetadata(alias="line2"), pydantic.Field(alias="line2")
    ] = None
    postal_code: typing_extensions.Annotated[
        typing.Optional[str], FieldMetadata(alias="postalCode"), pydantic.Field(alias="postalCode")
    ] = None
    city: typing.Optional[str] = None
    state: typing.Optional[str] = None
    country: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
