# This file was auto-generated by Fern from our API Definition.

import typing

CustomSigningKeyAlgorithmEnum = typing.Union[
    typing.Literal["RS256", "RS384", "RS512", "ES256", "ES384", "ES512", "PS256", "PS384", "PS512"], typing.Any
]
