# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .flow_action_salesforce_update_lead_action import FlowActionSalesforceUpdateLeadAction
from .flow_action_salesforce_update_lead_params import FlowActionSalesforceUpdateLeadParams
from .flow_action_salesforce_update_lead_type import FlowActionSalesforceUpdateLeadType


class FlowActionSalesforceUpdateLead(UniversalBaseModel):
    id: str
    alias: typing.Optional[str] = None
    type: FlowActionSalesforceUpdateLeadType
    action: FlowActionSalesforceUpdateLeadAction
    allow_failure: typing.Optional[bool] = None
    mask_output: typing.Optional[bool] = None
    params: FlowActionSalesforceUpdateLeadParams

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
