# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .identity_provider_enum import IdentityProviderEnum


class Identity(UniversalBaseModel):
    """
    This must be provided to verify primary social, enterprise and passwordless email identities. Also, is needed to verify secondary identities.
    """

    user_id: str = pydantic.Field()
    """
    user_id of the identity to be verified.
    """

    provider: IdentityProviderEnum
    connection_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    connection_id of the identity.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
