# This file was auto-generated by Fern from our API Definition.

import typing

from .event_stream_action_response_content import EventStreamActionResponseContent
from .event_stream_event_bridge_response_content import EventStreamEventBridgeResponseContent
from .event_stream_webhook_response_content import EventStreamWebhookResponseContent

GetEventStreamResponseContent = typing.Union[
    EventStreamWebhookResponseContent, EventStreamEventBridgeResponseContent, EventStreamActionResponseContent
]
