# This file was auto-generated by Fern from our API Definition.

import typing

from .form_widget_auth_0_verifiable_credentials import FormWidgetAuth0VerifiableCredentials
from .form_widget_g_maps_address import FormWidgetGMapsAddress
from .form_widget_recaptcha import FormWidgetRecaptcha

FormWidget = typing.Union[FormWidgetAuth0VerifiableCredentials, FormWidgetGMapsAddress, FormWidgetRecaptcha]
