# This file was auto-generated by Fern from our API Definition.

import typing

from .email_provider_credentials_schema_access_key_id import EmailProviderCredentialsSchemaAccessKeyId
from .email_provider_credentials_schema_api_key import EmailProviderCredentialsSchemaApiKey
from .email_provider_credentials_schema_client_id import EmailProviderCredentialsSchemaClientId
from .email_provider_credentials_schema_connection_string import EmailProviderCredentialsSchemaConnectionString
from .email_provider_credentials_schema_smtp_host import EmailProviderCredentialsSchemaSmtpHost
from .email_provider_credentials_schema_three import EmailProviderCredentialsSchemaThree
from .email_provider_credentials_schema_zero import EmailProviderCredentialsSchemaZero
from .extensibility_email_provider_credentials import ExtensibilityEmailProviderCredentials

EmailProviderCredentialsSchema = typing.Union[
    EmailProviderCredentialsSchemaZero,
    EmailProviderCredentialsSchemaAccessKeyId,
    EmailProviderCredentialsSchemaSmtpHost,
    EmailProviderCredentialsSchemaThree,
    EmailProviderCredentialsSchemaApiKey,
    EmailProviderCredentialsSchemaConnectionString,
    EmailProviderCredentialsSchemaClientId,
    ExtensibilityEmailProviderCredentials,
]
