# This file was auto-generated by Fern from our API Definition.

import typing

EventStreamCloudEventGroupMemberDeletedCloudEventTypeEnum = typing.Union[
    typing.Literal["group.member.deleted"], typing.Any
]
