# This file was auto-generated by Fern from our API Definition.

import typing

FormWidgetTypeAuth0VerifiableCredentialsConst = typing.Union[typing.Literal["AUTH0_VERIFIABLE_CREDENTIALS"], typing.Any]
