# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .verifiable_credential_template_response import VerifiableCredentialTemplateResponse


class ListVerifiableCredentialTemplatesPaginatedResponseContent(UniversalBaseModel):
    next: typing.Optional[str] = pydantic.Field(default=None)
    """
    Opaque identifier for use with the <i>from</i> query parameter for the next page of results.<br/>This identifier is valid for 24 hours.
    """

    templates: typing.Optional[typing.List[VerifiableCredentialTemplateResponse]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
