# This file was auto-generated by Fern from our API Definition.

import typing

ConnectionDpopSigningAlgValuesSupported = typing.List[str]
"""
JSON array containing a list of the JWS signing algorithms (alg values) supported for DPoP proof JWT signing.
"""
