# This file was auto-generated by Fern from our API Definition.

import typing

from .suspicious_ip_throttling_allowlist_item import SuspiciousIpThrottlingAllowlistItem

SuspiciousIpThrottlingAllowlist = typing.List[SuspiciousIpThrottlingAllowlistItem]
"""
List of trusted IP addresses that will not have attack protection enforced against them.
"""
