# This file was auto-generated by Fern from our API Definition.

import typing

ConnectionTokenEndpointAuthMethodEnum = typing.Union[
    typing.Literal["client_secret_post", "private_key_jwt"], typing.Any
]
