# This file was auto-generated by Fern from our API Definition.

import typing

from .form_block import FormBlock
from .form_field import FormField
from .form_widget import FormWidget

FormComponent = typing.Union[FormBlock, FormWidget, FormField]
