# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class ClientAddonAws(UniversalBaseModel):
    """
    AWS addon configuration.
    """

    principal: typing.Optional[str] = pydantic.Field(default=None)
    """
    AWS principal ARN, e.g. `arn:aws:iam::010616021751:saml-provider/idpname`
    """

    role: typing.Optional[str] = pydantic.Field(default=None)
    """
    AWS role ARN, e.g. `arn:aws:iam::010616021751:role/foo`
    """

    lifetime_in_seconds: typing.Optional[int] = pydantic.Field(default=None)
    """
    AWS token lifetime in seconds
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
