# This file was auto-generated by Fern from our API Definition.

import typing

GuardianEnrollmentFactorEnum = typing.Union[
    typing.Literal["push-notification", "phone", "email", "otp", "webauthn-roaming", "webauthn-platform"], typing.Any
]
