# This file was auto-generated by Fern from our API Definition.

import typing

from .event_stream_cloud_event_group_member_added_object_member_0 import (
    EventStreamCloudEventGroupMemberAddedObjectMember0,
)
from .event_stream_cloud_event_group_member_added_object_member_1 import (
    EventStreamCloudEventGroupMemberAddedObjectMember1,
)

EventStreamCloudEventGroupMemberAddedObjectMember = typing.Union[
    EventStreamCloudEventGroupMemberAddedObjectMember0, EventStreamCloudEventGroupMemberAddedObjectMember1
]
