# This file was auto-generated by Fern from our API Definition.

AculHeadTagContent = str
"""
Text or markup between the element’s opening and closing tags. 
You can use <a href="https://auth0.com/docs/customize/login-pages/advanced-customizations/getting-started/configure-acul-screens">context variables</a> to display dynamic values.
"""
