# This file was auto-generated by Fern from our API Definition.

ConnectionRequireRequestUriRegistration = bool
"""
Boolean value specifying whether the OP requires use of the request_uri parameter. If omitted, the default value is false.
"""
