# This file was auto-generated by Fern from our API Definition.

import typing

ConnectionEnabledClients = typing.List[str]
"""
DEPRECATED property. Use the PATCH /v2/connections/{id}/clients endpoint to enable the connection for a set of clients.
"""
