# This file was auto-generated by Fern from our API Definition.

import typing

ClientAppTypeEnum = typing.Union[
    typing.Literal[
        "native",
        "spa",
        "regular_web",
        "non_interactive",
        "resource_server",
        "express_configuration",
        "b2b_integration",
        "rms",
        "box",
        "cloudbees",
        "concur",
        "dropbox",
        "mscrm",
        "echosign",
        "egnyte",
        "newrelic",
        "office365",
        "salesforce",
        "sentry",
        "sharepoint",
        "slack",
        "springcm",
        "zendesk",
        "zoom",
        "sso_integration",
        "oag",
    ],
    typing.Any,
]
