# This file was auto-generated by Fern from our API Definition.

import typing

ClientMetadata = typing.Dict[str, typing.Any]
"""
Metadata associated with the client, in the form of an object with string values (max 255 chars).  Maximum of 10 metadata properties allowed.  Field names (max 255 chars) are alphanumeric and may only include the following special characters:  :,-+=_*?"/\()<>@    [Tab] [Space]
"""
