# This file was auto-generated by Fern from our API Definition.

import typing

FlowActionSalesforceSearchLeadsParamsSearchField = typing.Union[
    typing.Literal["email", "name", "phone", "all"], typing.Any
]
