# This file was auto-generated by Fern from our API Definition.

import typing

GuardianFactorsProviderPushNotificationProviderDataEnum = typing.Union[
    typing.Literal["guardian", "sns", "direct"], typing.Any
]
