# This file was auto-generated by Fern from our API Definition.

import typing

ConnectionProfileOrganizationShowAsButtonEnum = typing.Union[typing.Literal["none", "optional", "required"], typing.Any]
