# This file was auto-generated by Fern from our API Definition.

import typing

EventStreamCloudEventUserCreatedObjectIdentitiesItemEnterpriseProviderEnum = typing.Union[
    typing.Literal[
        "ad", "adfs", "google-apps", "ip", "office365", "oidc", "okta", "pingfederate", "samlp", "sharepoint", "waad"
    ],
    typing.Any,
]
