# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .update_branding_page_background import UpdateBrandingPageBackground


class UpdateBrandingColors(UniversalBaseModel):
    """
    Custom color settings.
    """

    primary: typing.Optional[str] = pydantic.Field(default=None)
    """
    Accent color.
    """

    page_background: typing.Optional[UpdateBrandingPageBackground] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
