# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .acul_client_filter import AculClientFilter
from .acul_domain_filter import AculDomainFilter
from .acul_match_type_enum import AculMatchTypeEnum
from .acul_organization_filter import AculOrganizationFilter


class AculFilters(UniversalBaseModel):
    """
    Optional filters to apply rendering rules to specific entities
    """

    match_type: typing.Optional[AculMatchTypeEnum] = None
    clients: typing.Optional[typing.List[AculClientFilter]] = pydantic.Field(default=None)
    """
    Clients filter
    """

    organizations: typing.Optional[typing.List[AculOrganizationFilter]] = pydantic.Field(default=None)
    """
    Organizations filter
    """

    domains: typing.Optional[typing.List[AculDomainFilter]] = pydantic.Field(default=None)
    """
    Domains filter
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
