# This file was auto-generated by Fern from our API Definition.

import typing

from .create_flows_vault_connection_twilio_api_key import CreateFlowsVaultConnectionTwilioApiKey
from .create_flows_vault_connection_twilio_uninitialized import CreateFlowsVaultConnectionTwilioUninitialized

CreateFlowsVaultConnectionTwilio = typing.Union[
    CreateFlowsVaultConnectionTwilioApiKey, CreateFlowsVaultConnectionTwilioUninitialized
]
