# This file was auto-generated by Fern from our API Definition.

import typing

from .flow_action_http_send_request_params_payload_object import FlowActionHttpSendRequestParamsPayloadObject

FlowActionHttpSendRequestParamsPayload = typing.Union[
    str, typing.List[typing.Any], FlowActionHttpSendRequestParamsPayloadObject
]
