# This file was auto-generated by Fern from our API Definition.

import typing

ConnectionUpstreamAliasEnum = typing.Union[
    typing.Literal[
        "acr_values",
        "audience",
        "client_id",
        "display",
        "id_token_hint",
        "login_hint",
        "max_age",
        "prompt",
        "resource",
        "response_mode",
        "response_type",
        "ui_locales",
    ],
    typing.Any,
]
