# This file was auto-generated by Fern from our API Definition.

ConnectionAdminRefreshTokenGoogleApps = str
"""
Google Workspace admin refresh token used to obtain new access tokens for the [Google Directory API](https://developers.google.com/admin-sdk/directory). This token is granted when a Google Workspace admin authorizes Auth0 to access directory data.
"""
