# This file was auto-generated by Fern from our API Definition.

from .connection_ext_is_suspended import ConnectionExtIsSuspended

ConnectionExtIsSuspendedGoogleApps = ConnectionExtIsSuspended
"""
Fetches the Google Directory suspended flag for the signing-in user.
"""
