# This file was auto-generated by Fern from our API Definition.

import typing

EventStreamCloudEventUserCreatedObjectIdentitiesItemSocialProviderEnum = typing.Union[
    typing.Literal[
        "amazon",
        "apple",
        "dropbox",
        "bitbucket",
        "auth0-oidc",
        "baidu",
        "bitly",
        "box",
        "daccount",
        "dwolla",
        "evernote-sandbox",
        "evernote",
        "exact",
        "facebook",
        "fitbit",
        "github",
        "google-oauth2",
        "instagram",
        "line",
        "linkedin",
        "oauth1",
        "oauth2",
        "paypal",
        "paypal-sandbox",
        "planningcenter",
        "salesforce-community",
        "salesforce-sandbox",
        "salesforce",
        "shopify",
        "soundcloud",
        "thirtysevensignals",
        "twitter",
        "untapped",
        "vkontakte",
        "weibo",
        "windowslive",
        "wordpress",
        "yahoo",
        "yandex",
    ],
    typing.Any,
]
