# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

from .flow_action_flow_delay_flow import FlowActionFlowDelayFlow
from .flow_action_flow_do_nothing import FlowActionFlowDoNothing
from .flow_action_flow_error_message import FlowActionFlowErrorMessage
from .flow_action_flow_map_value import FlowActionFlowMapValue
from .flow_action_flow_return_json import FlowActionFlowReturnJson
from .flow_action_flow_store_vars import FlowActionFlowStoreVars

if typing.TYPE_CHECKING:
    from .flow_action_flow_boolean_condition import FlowActionFlowBooleanCondition
FlowActionFlow = typing.Union[
    "FlowActionFlowBooleanCondition",
    FlowActionFlowDelayFlow,
    FlowActionFlowDoNothing,
    FlowActionFlowErrorMessage,
    FlowActionFlowMapValue,
    FlowActionFlowReturnJson,
    FlowActionFlowStoreVars,
]
