# This file was auto-generated by Fern from our API Definition.

import typing

EventStreamCloudEventConnectionDeletedObject1OptionsSchemaVersionEnum = typing.Union[
    typing.Literal["openid-1.0.0", "oidc-v4"], typing.Any
]
