# This file was auto-generated by Fern from our API Definition.

import typing

AculContextEnum = typing.Union[
    typing.Literal[
        "branding.settings",
        "branding.themes.default",
        "client.logo_uri",
        "client.description",
        "organization.display_name",
        "organization.branding",
        "screen.texts",
        "tenant.name",
        "tenant.friendly_name",
        "tenant.logo_url",
        "tenant.enabled_locales",
        "untrusted_data.submitted_form_data",
        "untrusted_data.authorization_params.login_hint",
        "untrusted_data.authorization_params.screen_hint",
        "untrusted_data.authorization_params.ui_locales",
        "user.organizations",
        "transaction.custom_domain.domain",
        "experiment",
    ],
    typing.Any,
]
