# This file was auto-generated by Fern from our API Definition.

import typing

ConnectionResponseModesSupported = typing.List[str]
"""
A list of the OAuth 2.0 response_mode values that this OP supports. If omitted, the default for Dynamic OpenID Providers is ["query", "fragment"]
"""
