# This file was auto-generated by Fern from our API Definition.

ConnectionShowAsButton = bool
"""
Enables showing a button for the connection in the login page (new experience only). If false, it will be usable only by HRD. Defaults to `false`.
"""
