# This file was auto-generated by Fern from our API Definition.

import typing

from .event_stream_cloud_event_user_created_object_identities_item_custom import (
    EventStreamCloudEventUserCreatedObjectIdentitiesItemCustom,
)
from .event_stream_cloud_event_user_created_object_identities_item_database import (
    EventStreamCloudEventUserCreatedObjectIdentitiesItemDatabase,
)
from .event_stream_cloud_event_user_created_object_identities_item_enterprise import (
    EventStreamCloudEventUserCreatedObjectIdentitiesItemEnterprise,
)
from .event_stream_cloud_event_user_created_object_identities_item_passwordless import (
    EventStreamCloudEventUserCreatedObjectIdentitiesItemPasswordless,
)
from .event_stream_cloud_event_user_created_object_identities_item_social import (
    EventStreamCloudEventUserCreatedObjectIdentitiesItemSocial,
)

EventStreamCloudEventUserCreatedObjectIdentitiesItem = typing.Union[
    EventStreamCloudEventUserCreatedObjectIdentitiesItemCustom,
    EventStreamCloudEventUserCreatedObjectIdentitiesItemDatabase,
    EventStreamCloudEventUserCreatedObjectIdentitiesItemEnterprise,
    EventStreamCloudEventUserCreatedObjectIdentitiesItemPasswordless,
    EventStreamCloudEventUserCreatedObjectIdentitiesItemSocial,
]
