# This file was auto-generated by Fern from our API Definition.

from .connection_totp_time_step_passwordless import ConnectionTotpTimeStepPasswordless

ConnectionTotpTimeStepSms = ConnectionTotpTimeStepPasswordless
"""
Code validity duration in seconds
"""
