# This file was auto-generated by Fern from our API Definition.

import typing

PhoneTemplateNotificationTypeEnum = typing.Union[
    typing.Literal["otp_verify", "otp_enroll", "change_password", "blocked_account", "password_breach"], typing.Any
]
