# This file was auto-generated by Fern from our API Definition.

import typing

SelfServiceProfileSsoTicketIdpInitiatedClientProtocolEnum = typing.Union[
    typing.Literal["samlp", "wsfed", "oauth2"], typing.Any
]
