# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .guardian_factor_name_enum import GuardianFactorNameEnum


class GuardianFactor(UniversalBaseModel):
    enabled: bool = pydantic.Field()
    """
    Whether this factor is enabled (true) or disabled (false).
    """

    trial_expired: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether trial limits have been exceeded.
    """

    name: typing.Optional[GuardianFactorNameEnum] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
