# This file was auto-generated by Fern from our API Definition.

import typing

from .connection_decryption_key_saml_cert import ConnectionDecryptionKeySamlCert

ConnectionDecryptionKeySaml = typing.Union[ConnectionDecryptionKeySamlCert, str]
