# This file was auto-generated by Fern from our API Definition.

import typing

ScreenGroupNameEnum = typing.Union[
    typing.Literal[
        "login",
        "login-id",
        "login-password",
        "login-passwordless-email-code",
        "login-passwordless-email-link",
        "login-passwordless-sms-otp",
        "login-email-verification",
        "signup",
        "signup-id",
        "signup-password",
        "phone-identifier-enrollment",
        "phone-identifier-challenge",
        "email-identifier-challenge",
        "reset-password-request",
        "reset-password-email",
        "reset-password",
        "reset-password-success",
        "reset-password-error",
        "reset-password-mfa-email-challenge",
        "reset-password-mfa-otp-challenge",
        "reset-password-mfa-phone-challenge",
        "reset-password-mfa-push-challenge-push",
        "reset-password-mfa-recovery-code-challenge",
        "reset-password-mfa-sms-challenge",
        "reset-password-mfa-voice-challenge",
        "reset-password-mfa-webauthn-platform-challenge",
        "reset-password-mfa-webauthn-roaming-challenge",
        "custom-form",
        "consent",
        "customized-consent",
        "logout",
        "logout-complete",
        "logout-aborted",
        "mfa-push-welcome",
        "mfa-push-enrollment-qr",
        "mfa-push-enrollment-code",
        "mfa-push-success",
        "mfa-push-challenge-push",
        "mfa-push-list",
        "mfa-otp-enrollment-qr",
        "mfa-otp-enrollment-code",
        "mfa-otp-challenge",
        "mfa-voice-enrollment",
        "mfa-voice-challenge",
        "mfa-phone-challenge",
        "mfa-phone-enrollment",
        "mfa-webauthn-platform-enrollment",
        "mfa-webauthn-roaming-enrollment",
        "mfa-webauthn-platform-challenge",
        "mfa-webauthn-roaming-challenge",
        "mfa-webauthn-change-key-nickname",
        "mfa-webauthn-enrollment-success",
        "mfa-webauthn-error",
        "mfa-webauthn-not-available-error",
        "mfa-country-codes",
        "mfa-sms-enrollment",
        "mfa-sms-challenge",
        "mfa-sms-list",
        "mfa-email-challenge",
        "mfa-email-list",
        "mfa-recovery-code-enrollment",
        "mfa-recovery-code-challenge-new-code",
        "mfa-recovery-code-challenge",
        "mfa-detect-browser-capabilities",
        "mfa-enroll-result",
        "mfa-login-options",
        "mfa-begin-enroll-options",
        "status",
        "device-code-activation",
        "device-code-activation-allowed",
        "device-code-activation-denied",
        "device-code-confirmation",
        "email-verification-result",
        "email-otp-challenge",
        "organization-selection",
        "organization-picker",
        "pre-login-organization-picker",
        "accept-invitation",
        "redeem-ticket",
        "passkey-enrollment",
        "passkey-enrollment-local",
        "interstitial-captcha",
        "brute-force-protection-unblock",
        "brute-force-protection-unblock-success",
        "brute-force-protection-unblock-failure",
        "async-approval-error",
        "async-approval-accepted",
        "async-approval-denied",
        "confirmation",
        "async-approval-wrong-user",
    ],
    typing.Any,
]
