# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .event_stream_cloud_event_group_member_deleted_object_member_1_member_type_enum import (
    EventStreamCloudEventGroupMemberDeletedObjectMember1MemberTypeEnum,
)


class EventStreamCloudEventGroupMemberDeletedObjectMember1(UniversalBaseModel):
    """
    A group member of member_type group
    """

    member_type: EventStreamCloudEventGroupMemberDeletedObjectMember1MemberTypeEnum
    id: str = pydantic.Field()
    """
    The connection member's unique identifier
    """

    type: str = pydantic.Field()
    """
    The type of the connection
    """

    connection_id: str = pydantic.Field()
    """
    Connection ID associated with the member
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
