# This file was auto-generated by Fern from our API Definition.

import typing

EventStreamCloudEventGroupRoleDeletedCloudEventTypeEnum = typing.Union[typing.Literal["group.role.deleted"], typing.Any]
