# This file was auto-generated by Fern from our API Definition.

import typing

EncryptionKeyType = typing.Union[
    typing.Literal["customer-provided-root-key", "environment-root-key", "tenant-master-key", "tenant-encryption-key"],
    typing.Any,
]
