# This file was auto-generated by Fern from our API Definition.

ConnectionAgentVersionAd = str
"""
Version identifier of the installed AD connector agent software (managed by the AD Connector agent).
"""
