# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .guardian_enrollment_date import GuardianEnrollmentDate
from .guardian_enrollment_status import GuardianEnrollmentStatus


class GetGuardianEnrollmentResponseContent(UniversalBaseModel):
    id: str = pydantic.Field()
    """
    ID for this enrollment.
    """

    status: typing.Optional[GuardianEnrollmentStatus] = None
    name: typing.Optional[str] = pydantic.Field(default=None)
    """
    Device name (only for push notification).
    """

    identifier: typing.Optional[str] = pydantic.Field(default=None)
    """
    Device identifier. This is usually the phone identifier.
    """

    phone_number: typing.Optional[str] = pydantic.Field(default=None)
    """
    Phone number.
    """

    enrolled_at: typing.Optional[GuardianEnrollmentDate] = None
    last_auth: typing.Optional[GuardianEnrollmentDate] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
