# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .branding_colors import BrandingColors
from .branding_font import BrandingFont


class UpdateBrandingResponseContent(UniversalBaseModel):
    colors: typing.Optional[BrandingColors] = None
    favicon_url: typing.Optional[str] = pydantic.Field(default=None)
    """
    URL for the favicon. Must use HTTPS.
    """

    logo_url: typing.Optional[str] = pydantic.Field(default=None)
    """
    URL for the logo. Must use HTTPS.
    """

    font: typing.Optional[BrandingFont] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
