# This file was auto-generated by Fern from our API Definition.

import typing

CreateEncryptionKeyType = typing.Union[
    typing.Literal["customer-provided-root-key", "tenant-encryption-key"], typing.Any
]
