# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class EventStreamCloudEventOffsetOnlyMessage(UniversalBaseModel):
    """
    An offset-only heartbeat message. Advances the cursor without delivering an event.
    """

    offset: str = pydantic.Field()
    """
    Opaque cursor representing the latest position in the stream. Pass as the `from` query parameter to resume.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
