# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .client_create_authentication_method_private_key_jwt_credentials import (
    ClientCreateAuthenticationMethodPrivateKeyJwtCredentials,
)


class ClientCreateAuthenticationMethodPrivateKeyJwt(UniversalBaseModel):
    """
    Defines `private_key_jwt` client authentication method. If this property is defined, the client is enabled to use the Private Key JWT authentication method.
    """

    credentials: ClientCreateAuthenticationMethodPrivateKeyJwtCredentials

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
