# This file was auto-generated by Fern from our API Definition.

ConnectionBaseUrlExact = str
"""
Base URL override for the Exact Online API endpoint used for OAuth2 authorization and API requests. Defaults to https://start.exactonline.nl.
"""
