# This file was auto-generated by Fern from our API Definition.

import typing

from .flow_action_flow_return_json_params_payload_object import FlowActionFlowReturnJsonParamsPayloadObject

FlowActionFlowReturnJsonParamsPayload = typing.Union[FlowActionFlowReturnJsonParamsPayloadObject, str]
